@@ -9,7 +9,7 @@ export LC_ALL=C.UTF-8
 export CONTAINER_NAME=ci_linux_i386
 export DOCKER_NAME_TAG=ubuntu:20.04
 export HOST=i686-pc-linux-gnu
-export PACKAGES="python3 g++-multilib"
+export PACKAGES="cmake python3 g++-multilib"
 export RUN_UNIT_TESTS=true
 export RUN_FUNCTIONAL_TESTS=false
 # export RUN_SECURITY_TESTS="true"
