@@ -6,6 +6,7 @@
 #define GRIDCOIN_CONTRACT_CONTRACT_H
 
 #include "amount.h"
+#include "gridcoin/contract/handler.h"
 #include "gridcoin/contract/payload.h"
 #include "gridcoin/support/enumbytes.h"
 #include "serialize.h"
@@ -19,6 +20,8 @@ class CBlockIndex;
 class CTransaction;
 
 namespace GRC {
+class RegistryBookmarks;
+
 //!
 //! \brief Represents a Gridcoin contract embedded in a transaction message.
 //!
@@ -45,7 +48,7 @@ public:
     //! ensure that the serialization/deserialization routines also handle all
     //! of the previous versions.
     //!
-    static constexpr uint32_t CURRENT_VERSION = 2;
+    static constexpr uint32_t CURRENT_VERSION = 3;
 
     //!
     //! \brief The amount of coin set for a burn output in a transaction that
@@ -93,6 +96,21 @@ public:
         //! \return The string as it would appear in a legacy transaction message.
         //!
         std::string ToString() const;
+
+        //!
+        //! \brief Get the string representation of the provided contract type.
+        //!
+        //! \return The string as it would appear in a legacy transaction message.
+        //!
+        static std::string ToString(ContractType contract_type);
+
+        //!
+        //! \brief Get the translated string representation of the provided contract type.
+        //!
+        //! \return The string as it would appear in a legacy transaction message.
+        //!
+        static std::string ToTranslatedString(ContractType contract_type);
+
     }; // Contract::Type
 
     //!
@@ -185,7 +203,7 @@ public:
         //!
         //! \return An IContractPayload implementation for the specified type.
         //!
-        ContractPayload ConvertFromLegacy(const ContractType type) const;
+        ContractPayload ConvertFromLegacy(const ContractType type, const uint32_t version) const;
 
         //!
         //! \brief Serialize the object to the provided stream.
@@ -236,6 +254,10 @@ public:
     //! transaction's \c vContracts field. It excludes the legacy signature
     //! and public key from version 1.
     //!
+    //! Version 3: Contract data serializable in binary format as version 2
+    //! but also with remaining payloads that were still legacy in version
+    //! 2 (scraper and protocol) now native.
+    //!
     uint32_t m_version = CURRENT_VERSION;
 
     Type m_type;            //!< Determines how to handle the contract.
@@ -438,6 +460,80 @@ public:
     }
 }; // Contract
 
+//!
+//! \brief A payload parsed from a legacy, version 1 contract.
+//!
+//! Version 2+ contracts provide support for binary representation of payload
+//! data. Legacy contract data exists as strings. This class provides for use
+//! of the contract payload API with legacy string contracts.
+//!
+class LegacyPayload : public IContractPayload
+{
+public:
+    std::string m_key;   //!< Legacy representation of a contract key.
+    std::string m_value; //!< Legacy representation of a contract value.
+
+    //!
+    //! \brief Initialize an empty, invalid legacy payload.
+    //!
+    LegacyPayload()
+    {
+    }
+
+    //!
+    //! \brief Initialize a legacy payload with data from a legacy contract.
+    //!
+    //! \param key   Legacy contract key as it exists in a transaction.
+    //! \param value Legacy contract value as it exists in a transaction.
+    //!
+    LegacyPayload(std::string key, std::string value)
+        : m_key(std::move(key))
+        , m_value(std::move(value))
+    {
+    }
+
+    GRC::ContractType ContractType() const override
+    {
+        return GRC::ContractType::UNKNOWN;
+    }
+
+    bool WellFormed(const ContractAction action) const override
+    {
+        return !m_key.empty()
+            && (action == ContractAction::REMOVE || !m_value.empty());
+    }
+
+    std::string LegacyKeyString() const override
+    {
+        return m_key;
+    }
+
+    std::string LegacyValueString() const override
+    {
+        return m_value;
+    }
+
+    CAmount RequiredBurnAmount() const override
+    {
+        return Contract::STANDARD_BURN_AMOUNT;
+    }
+
+    ADD_CONTRACT_PAYLOAD_SERIALIZE_METHODS;
+
+    template <typename Stream, typename Operation>
+    inline void SerializationOp(
+        Stream& s,
+        Operation ser_action,
+        const ContractAction contract_action)
+    {
+        READWRITE(m_key);
+
+        if (contract_action != ContractAction::REMOVE) {
+            READWRITE(m_value);
+        }
+    }
+}; // LegacyPayload
+
 //!
 //! \brief Initialize a new contract.
 //!
@@ -461,6 +557,31 @@ Contract MakeContract(const ContractAction action, Args&&... args)
     return Contract(type, action, std::move(payload));
 }
 
+//!
+//! \brief Initialize a new contract with the specified contract version.
+//!
+//! \tparam PayloadType A type that implements the IContractPayload interface.
+//!
+//! \param contract_version The version of the contract to create
+//! \param action The action of the contract to publish.
+//! \param body   Arguments to pass to the constructor of the contract payload.
+//!
+//! \return A contract object for submission in a transaction.
+//!
+template <typename PayloadType, typename... Args>
+Contract MakeContract(const uint32_t contract_version, const ContractAction action, Args&&... args)
+{
+    static_assert(
+        std::is_base_of<IContractPayload, PayloadType>::value,
+        "Contract::PullPayloadAs<T>: T not derived from IContractPayload.");
+
+    auto payload = ContractPayload::Make<PayloadType>(std::forward<Args>(args)...);
+    const ContractType type = payload->ContractType();
+
+    return Contract(contract_version, type, action, std::move(payload));
+}
+
+
 //!
 //! \brief Initialize a new legacy contract.
 //!
@@ -494,7 +615,7 @@ void ReplayContracts(CBlockIndex *pindex_end, CBlockIndex *pindex_start = nullpt
 //! \param out_found        Will update to \c true when a block contains a contract.
 //!
 void ApplyContracts(const CBlock& block,
-    const CBlockIndex* const pindex, const int& beacon_db_height,
+    const CBlockIndex* const pindex, const RegistryBookmarks& db_heights,
     bool& out_found_contract);
 
 //!
@@ -505,19 +626,31 @@ void ApplyContracts(const CBlock& block,
 //! \param pindex           Block index for the block that contains the transaction.
 //! \param beacon_db_height Height that db is updated to prior to call
 //!
-void ApplyContracts(
-    const CTransaction& tx,
-    const CBlockIndex* const pindex, const int& beacon_db_height,
+void ApplyContracts(const CTransaction& tx,
+    const CBlockIndex* const pindex, const RegistryBookmarks& db_heights,
     bool& out_found_contract);
 
 //!
 //! \brief Perform contextual validation for the contracts in a transaction.
 //!
 //! \param tx Transaction to validate contracts for.
+//! \param DoS Misbehavior score out parameter
 //!
 //! \return \c false When a contract in the transaction fails validation.
 //!
-bool ValidateContracts(const CTransaction& tx);
+bool ValidateContracts(const CTransaction& tx, int& DoS);
+
+//!
+//! \brief Perform contextual validation for the contracts in a transaction including block context. This is used
+//! in ConnectBlock.
+//!
+//! \param pindex The CBlockIndex of the block context of the transaction.
+//! \param tx The transaction to validate contracts for.
+//! \param DoS Misbehavior score out.
+//!
+//! \return  \c false If the contract fails validation.
+//!
+bool BlockValidateContracts(const CBlockIndex* const pindex, const CTransaction& tx, int& DoS);
 
 //!
 //! \brief Revert previously-applied contracts from a transaction by passing
