@@ -1,12 +1,14 @@
-// Copyright (c) 2014-2021 The Gridcoin developers
+// Copyright (c) 2014-2024 The Gridcoin developers
 // Distributed under the MIT/X11 software license, see the accompanying
 // file COPYING or https://opensource.org/licenses/mit-license.php.
 
 #include "chainparams.h"
+#include "gridcoin/scraper/scraper_registry.h"
 #include "main.h"
 #include "util/threadnames.h"
 #include "gridcoin/backup.h"
 #include "gridcoin/contract/contract.h"
+#include "gridcoin/contract/registry.h"
 #include "gridcoin/gridcoin.h"
 #include "gridcoin/quorum.h"
 #include "gridcoin/researcher.h"
@@ -25,6 +27,7 @@ extern bool fExplorer;
 extern unsigned int nScraperSleep;
 extern unsigned int nActiveBeforeSB;
 extern bool fScraperActive;
+extern bool fQtActive;
 
 void Scraper(bool bSingleShot = false);
 void ScraperSubscriber();
@@ -38,17 +41,29 @@ namespace {
 //!
 void ShowChainCorruptedMessage()
 {
-    uiInterface.ThreadSafeMessageBox(
-        _("WARNING: Blockchain data may be corrupted.\n\n"
-            "Gridcoin detected bad index entries. This may occur because of an "
-            "unexpected exit, a power failure, or a late software upgrade.\n\n"
-            "Please exit Gridcoin, open the data directory, and delete:\n"
-            " - the blk****.dat files\n"
-            " - the txleveldb folder\n\n"
-            "Your wallet will re-download the blockchain. Your balance may "
-            "appear incorrect until the synchronization finishes.\n" ),
-        "Gridcoin",
-        CClientUIInterface::BTN_OK | CClientUIInterface::MODAL);
+    fResetBlockchainRequest = true;
+
+    if (fQtActive) {
+        uiInterface.ThreadSafeMessageBox(
+            _("ERROR: Checkpoint mismatch: Blockchain data may be corrupted.\n\n"
+              "Gridcoin detected bad index entries. This may occur because of a "
+              "late software upgrade, unexpected exit, or a power failure. "
+              "Your blockchain data is being reset and your wallet will resync "
+              "from genesis when you restart. Your balance may appear incorrect "
+              "until the synchronization finishes."),
+            "Gridcoin",
+            CClientUIInterface::BTN_OK | CClientUIInterface::MODAL);
+    } else {
+        uiInterface.ThreadSafeMessageBox(
+            _("ERROR: Checkpoint mismatch: Blockchain data may be corrupted.\n\n"
+              "Gridcoin detected bad index entries. This may occur because of a "
+              "late software upgrade, unexpected exit, or a power failure. "
+              "Please run gridcoinresearchd with the -resetblockchaindata "
+              "parameter. Your wallet will re-download the blockchain. Your "
+              "balance may appear incorrect until the synchronization finishes." ),
+            "Gridcoin",
+            CClientUIInterface::BTN_OK | CClientUIInterface::MODAL);
+    }
 }
 
 //!
@@ -120,7 +135,7 @@ bool InitializeResearchRewardAccounting(CBlockIndex* pindexBest)
 
     const int64_t start_height = Params().GetConsensus().ResearchAgeHeight;
 
-    if (!Tally::Initialize(BlockFinder().FindByHeight(start_height))) {
+    if (!Tally::Initialize(BlockFinder::FindByHeight(start_height))) {
         return error("Failed to initialize tally.");
     }
 
@@ -141,52 +156,83 @@ bool InitializeResearchRewardAccounting(CBlockIndex* pindexBest)
 //!
 void InitializeContracts(CBlockIndex* pindexBest)
 {
-    LogPrintf("Gridcoin: Loading beacon history...");
-    uiInterface.InitMessage(_("Loading beacon history..."));
+    // This loop initializes the registry for each contract type in CONTRACT_TYPES_WITH_REG_DB.
+    for (const auto& contract_type : RegistryBookmarks::CONTRACT_TYPES_WITH_REG_DB) {
+        Registry& registry = RegistryBookmarks::GetRegistryWithDB(contract_type);
 
-    BeaconRegistry& beacons = GetBeaconRegistry();
+        std::string contract_type_string = Contract::Type::ToString(contract_type);
+        std::string tr_contract_type_string = Contract::Type::ToTranslatedString(contract_type);
 
-    // If the clearbeaconhistory argument is provided, then clear everything from the beacon registry,
-    // including the beacon_db and beacon key type elements from LevelDB.
-    if (gArgs.GetBoolArg("-clearbeaconhistory", false))
-    {
-        beacons.Reset();
-    }
+        LogPrintf("INFO: %s: Loading stored history for contract type %s...",
+                  __func__,
+                  contract_type_string);
 
-    LogPrintf("Gridcoin: Initializing beacon registry from stored history...");
-    uiInterface.InitMessage(_("Initializing beacon registry from stored history..."));
-    int beacon_db_height = beacons.Initialize();
+        uiInterface.InitMessage(_("Loading history for contract type ") + tr_contract_type_string + "...");
 
-    if (beacon_db_height > 0)
-    {
-        LogPrintf("Gridcoin: beacon history loaded through height = %i.", beacon_db_height);
-    }
-    else
-    {
-        LogPrintf("Gridcoin: beacon history load not successful. Will initialize from contract replay.");
+        std::string history_arg = "-clear" + GRC::Contract::Type::ToString(contract_type) + "history";
+        if (gArgs.GetBoolArg(history_arg, false) || gArgs.GetBoolArg("-clearallregistryhistory", false)) {
+            registry.Reset();
+        }
+
+        LogPrintf("INFO: %s: Initializing registry from stored history for contract type %s...",
+                  __func__,
+                  contract_type_string);
+
+        uiInterface.InitMessage(_("Initializing registry from stored history for contract type ")
+                                  + tr_contract_type_string + "...");
+
+        int db_height = registry.Initialize();
+
+        if (db_height > 0) {
+            LogPrintf("INFO: %s: History loaded through height %i for contract type %s",
+                      __func__,
+                      db_height,
+                      contract_type_string);
+        } else {
+            LogPrintf("INFO: %s: History load not successful for contract type %s. Will initialize "
+                      "from contract replay.",
+                      __func__,
+                      contract_type_string);
+        }
     }
 
     LogPrintf("Gridcoin: replaying contracts...");
     uiInterface.InitMessage(_("Replaying contracts..."));
 
-    static BlockFinder blockFinder;
-
-    CBlockIndex* pindex_start = blockFinder.FindByMinTime(pindexBest->nTime - Beacon::MAX_AGE);
+    CBlockIndex* pindex_start = GRC::BlockFinder::FindByMinTime(pindexBest->nTime
+                                                                - Params().GetConsensus().StandardContractReplayLookback);
 
     const int& V11_height = Params().GetConsensus().BlockV11Height;
     const int& lookback_window_low_height = pindex_start->nHeight;
 
+    // Gets a registry db height bookmark object with the heights loaded now that the registries are loaded.
+    RegistryBookmarks db_heights;
+
     // This tricky clamp ensures the correct start height for the contract replay. Note that the current
-    // implementation will skip beacon contracts that overlap the already loaded beacon history. See
-    // ReplayContracts. The worst case replay is a window that starts at V11_height and extends to current height.
-    // This is the replay that will be encountered when starting a wallet that was in sync with this code, and the
-    // head of the chain is more than MAX AGE above the V11Height. When the contracts are replayed, the beacon db
-    // will then be initialized and the controlling window will be consistent with MAX_AGE on restarts and reorgs.
-    const int& start_height = std::min(std::max(beacon_db_height, V11_height), lookback_window_low_height);
+    // implementation will skip beacon, scraper entry, project, poll and vote contracts that overlap the already loaded
+    // history. See ReplayContracts. The worst case replay is a window that starts at V11_height and extends to current
+    // height. This is the replay that will be encountered when starting a wallet that was in sync with this code but has
+    // uninitialized registry dbs, and the head of the chain is more than MAX AGE above the V11_height, because
+    // GetLowestRegistryBlockHeight() is 0, and then the maximum of V11_height and GetLowestRegistryBlockHeight() will be
+    // V11_height and the minimum of V11_height and lookback_window_low_height will be V11_height. When the contracts are
+    // replayed, the beacon db and scraper entry db will then be initialized and the controlling window will be either the
+    // GetLowestRegistryBlockHeight() or the lookback_window_low_height, whichever is higher. The MAX_AGE (i.e.
+    // lookback_window_low_height) condition once the contract types that have a backing db are initialized is now driven
+    // by the following remaining contract types which have no registry (backing) db:
+    //
+    // CONTRACT type                      Wallet startup replay requirement           Block reorg replay requirement
+    // POLL/VOTE (polls and voting)               V11 or std lookback                             false
+    //
+    // Note that the handler reset and contract replay forwards from lookback_window_low_height no longer is required
+    // for polls and votes. The reason for this is quite simple. Polls and votes are UNIQUE. The reversion of an add
+    // is simply to delete them. The wallet startup replay requirement is still required for polls and votes, because
+    // the Poll/Vote classes do not have a backing registry db yet.
+    int start_height = std::min(std::max(db_heights.GetLowestRegistryBlockHeight(), V11_height),
+                                lookback_window_low_height);
 
     LogPrintf("Gridcoin: Starting contract replay from height %i.", start_height);
 
-    CBlockIndex* pblock_index = mapBlockIndex[hashBestChain];
+    CBlockIndex* pblock_index = pindexBest;
 
     while (pblock_index->nHeight > start_height)
     {
@@ -196,8 +242,8 @@ void InitializeContracts(CBlockIndex* pindexBest)
     // Reset pindex_start to the index for the block at start_height
     pindex_start = pblock_index;
 
-    // The replay contract window here may overlap with the beacon db coverage. Logic is now included in
-    // the ApplyContracts to ignore beacon contracts that have already been covered by the beacon db.
+    // The replay contract window here may overlap with the registry db coverage for the various registries. Logic
+    // is now included in the ApplyContracts to ignore contracts that have already been covered by the registry dbs.
     ReplayContracts(pindexBest, pindex_start);
 }
 
@@ -328,20 +374,23 @@ void InitializeExplorerFeatures()
 //! whether the index contains invalid state caused by an unclean shutdown.
 //! This condition was originally detected by an assertion in a routine for
 //! stake modifier checksum verification. Because Gridcoin removed modifier
-//! checksums and checkpoints, we reinstate that assertion here as a formal
-//! inspection.
+//! checksums, we reinstate that assertion here as a formal inspection done
+//! at initialization before the VerifyCheckpoints.
 //!
 //! This function checks that no block index entries contain a null pointer
 //! to a previous block. The symptom may indicate a deeper problem that can
 //! be resolved by tuning disk synchronization in LevelDB. Until then, this
 //! heuristic has proven itself to be effective for identifying a corrupted
-//! database.
+//! database. This type of error has not been seen in the wild in several
+//! years as of Gridcoin 5.4.7.0, but is retained for thoroughness.
 //!
-void CheckBlockIndexJob()
+bool CheckBlockIndex()
 {
     LogPrintf("Gridcoin: checking block index...");
+    uiInterface.InitMessage(_("Checking block index..."));
 
-    bool corrupted = false;
+    // Block index integrity status
+    bool status = true;
 
     if (pindexGenesisBlock) {
         LOCK(cs_main);
@@ -350,18 +399,20 @@ void CheckBlockIndexJob()
             const CBlockIndex* const pindex = index_pair.second;
 
             if (!pindex || !(pindex->pprev || pindex == pindexGenesisBlock)) {
-                corrupted = true;
+                status = false;
                 break;
             }
         }
     }
 
-    if (!corrupted) {
+    if (status) {
         LogPrintf("Gridcoin: block index is clean");
-        return;
+        return status;
     }
 
     ShowChainCorruptedMessage();
+
+    return status;
 }
 
 //!
@@ -429,11 +480,12 @@ void ScheduleUpdateChecks(CScheduler& scheduler)
     }, std::chrono::minutes{1});
 }
 
-void ScheduleBeaconDBPassivation(CScheduler& scheduler)
+void ScheduleRegistriesPassivation(CScheduler& scheduler)
 {
-    // Run beacon database passivation every 5 minutes. This is a very thin call most of the time.
+    // Run registry database passivation every 5 minutes. This is a very thin call most of the time.
     // Please see the PassivateDB function and passivate_db.
-    scheduler.scheduleEvery(BeaconRegistry::RunBeaconDBPassivation, std::chrono::minutes{5});
+
+    scheduler.scheduleEvery(RunDBPassivation, std::chrono::minutes{5});
 }
 } // Anonymous namespace
 
@@ -453,6 +505,9 @@ bool GRC::Initialize(ThreadHandlerPtr threads, CBlockIndex* pindexBest)
 {
     LogPrintf("Gridcoin: initializing...");
 
+    if (!CheckBlockIndex()) {
+        return false;
+    }
     if (!VerifyCheckpoints(pindexBest)) {
         return false;
     }
@@ -481,8 +536,6 @@ void GRC::CloseResearcherRegistryFile()
 
 void GRC::ScheduleBackgroundJobs(CScheduler& scheduler)
 {
-    scheduler.schedule(CheckBlockIndexJob, std::chrono::system_clock::now());
-
     // Primitive, but this is what the scraper does in the scraper housekeeping
     // loop. It checks to see if the logs need to be archived by default every
     // 5 mins. Note that passing false to the archive function means that if we
@@ -498,7 +551,7 @@ void GRC::ScheduleBackgroundJobs(CScheduler& scheduler)
 
     ScheduleBackups(scheduler);
     ScheduleUpdateChecks(scheduler);
-    ScheduleBeaconDBPassivation(scheduler);
+    ScheduleRegistriesPassivation(scheduler);
 }
 
 bool GRC::CleanConfig() {
@@ -552,3 +605,13 @@ skip:;
     return true;
 }
 
+void GRC::RunDBPassivation()
+{
+    LOCK(cs_main);
+
+    for (const auto& contract_type : RegistryBookmarks::CONTRACT_TYPES_WITH_REG_DB) {
+        Registry& registry = RegistryBookmarks::GetRegistryWithDB(contract_type);
+
+        registry.PassivateDB();
+    }
+}
