@@ -2,11 +2,12 @@
 // Distributed under the MIT/X11 software license, see the accompanying
 // file COPYING or https://opensource.org/licenses/mit-license.php.
 
-#include "base58.h"
+#include <key_io.h>
 #include "chainparams.h"
 #include "main.h"
 #include "gridcoin/claim.h"
 #include "gridcoin/magnitude.h"
+#include <gridcoin/md5.h>
 #include "gridcoin/quorum.h"
 #include "gridcoin/scraper/scraper_net.h"
 #include "gridcoin/superblock.h"
@@ -14,7 +15,6 @@
 #include "util/reverse_iterator.h"
 #include <util/string.h>
 
-#include <openssl/md5.h>
 #include <unordered_map>
 
 using namespace GRC;
@@ -253,7 +253,7 @@ class QuorumVote
 {
 public:
     const QuorumHash m_hash;           //!< Hash of the superblock to vote for.
-    const CBitcoinAddress m_address;   //!< Address of the voting wallet.
+    const CTxDestination m_address;   //!< Address of the voting wallet.
     const CBlockIndex* const m_pindex; //!< Block that contains the vote.
 
     //!
@@ -263,7 +263,7 @@ public:
     //! \param address Default address of the voting wallet.
     //! \param pindex  Block that contains the vote.
     //!
-    QuorumVote(QuorumHash hash, CBitcoinAddress address, const CBlockIndex* pindex)
+    QuorumVote(QuorumHash hash, CTxDestination address, const CBlockIndex* pindex)
         : m_hash(hash)
         , m_address(std::move(address))
         , m_pindex(pindex)
@@ -313,9 +313,9 @@ public:
         std::string input = grc_address + "_" + ToString(GetDayOfYear(time));
         std::vector<unsigned char> address_day_hash(16);
 
-        MD5(reinterpret_cast<const unsigned char*>(input.data()),
-            input.size(),
-            address_day_hash.data());
+        GRC__MD5(reinterpret_cast<const unsigned char*>(input.data()),
+                 input.size(),
+                 address_day_hash.data());
 
         return arith_uint256("0x" + HexStr(address_day_hash)) < reference_hash;
     }
@@ -374,9 +374,9 @@ public:
             return;
         }
 
-        CBitcoinAddress address(grc_address);
+        CTxDestination address = DecodeDestination(grc_address);
 
-        if (!address.IsValid()) {
+        if (!IsValidDestination(address)) {
             LogPrint(BCLog::LogFlags::VERBOSE,
                      "Quorum::RecordVote: invalid address: %s HASH: %s",
                      grc_address,
@@ -509,7 +509,7 @@ private:
         const int64_t min_height = last_height - STANDARD_LOOKBACK;
 
         PopularityMap popularity_map;
-        std::map<CBitcoinAddress, QuorumHash> addresses_seen;
+        std::map<CTxDestination, QuorumHash> addresses_seen;
 
         for (const auto& vote_pair : reverse_iterate(m_votes)) {
             const int64_t vote_height = vote_pair.first;
@@ -721,7 +721,7 @@ private: // SuperblockValidator classes
         std::vector<ResolvedPart> m_resolved_parts;
 
         //!
-        //! \brief Divisor set by the \c ProjectCombiner for iteraton over each
+        //! \brief Divisor set by the \c ProjectCombiner for iteration over each
         //! convergence combination.
         //!
         size_t m_combiner_mask;
@@ -1329,7 +1329,7 @@ private: // SuperblockValidator methods
                 const uint256& manifest_hash = hashes.second.first;
                 const uint256& content_hash = hashes.second.second;
 
-                if (content_hash.GetUint64() >> 32 == m_superblock->m_manifest_content_hint) {
+                if (content_hash.GetUint64(0) >> 32 == m_superblock->m_manifest_content_hint) {
                     if (!content_hash_tally.emplace(content_hash, 1).second) {
                         content_hash_tally[content_hash]++;
                     }
@@ -1478,7 +1478,7 @@ private: // SuperblockValidator methods
         LOCK(CSplitBlob::cs_mapParts);
 
         for (const auto& part_pair : CSplitBlob::mapParts) {
-            const uint32_t hint = part_pair.first.GetUint64() >> m_hint_shift;
+            const uint32_t hint = part_pair.first.GetUint64(0) >> m_hint_shift;
             const auto hint_range = hints.equal_range(hint);
 
             for (auto i = hint_range.first; i != hint_range.second; ++i) {
@@ -1557,9 +1557,9 @@ bool Quorum::ValidateSuperblockClaim(
         return ValidateSuperblock(superblock);
     }
 
-    const CBitcoinAddress address(claim.m_quorum_address);
+    const CTxDestination address = DecodeDestination(claim.m_quorum_address);
 
-    if (!address.IsValid()) {
+    if (!IsValidDestination(address)) {
         return error("ValidateSuperblockClaim(): "
             "invalid quorum address: %s", claim.m_quorum_address);
     }
@@ -1642,11 +1642,11 @@ std::vector<ExplainMagnitudeProject> Quorum::ExplainMagnitude(const Cpid cpid)
     CreateSuperblock();
 
     const std::string cpid_str = cpid.ToString();
-    const Span<const char> cpid_span = MakeSpan(cpid_str);
+    const Span<const char> cpid_span = Span{cpid_str};
 
     // Compare the stats entry CPID and return the project name if it matches:
     const auto try_item = [&](const std::string& object_id) {
-        const Span<const char> id_span = MakeSpan(object_id);
+        const Span<const char> id_span = Span{object_id};
         const Span<const char> cpid_subspan = id_span.last(32);
 
         if (cpid_subspan != cpid_span) {
