@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2021 The Gridcoin developers
+// Copyright (c) 2014-2023 The Gridcoin developers
 // Distributed under the MIT/X11 software license, see the accompanying
 // file COPYING or https://opensource.org/licenses/mit-license.php.
 
@@ -21,7 +21,7 @@ namespace GRC {
 
 class Beacon;
 class Magnitude;
-class Project;
+class ProjectEntry;
 class WhitelistSnapshot;
 
 //!
@@ -86,6 +86,7 @@ public:
         m_mining_pools.push_back({ "7d0d73fe026d66fd4ab8d5d8da32a611", "grcpool.com", "https://grcpool.com/" });
         m_mining_pools.push_back({ "a914eba952be5dfcf73d926b508fd5fa", "grcpool.com-2", "https://grcpool.com/" });
         m_mining_pools.push_back({ "163f049997e8a2dee054d69a7720bf05", "grcpool.com-3", "https://grcpool.com/" });
+        m_mining_pools.push_back({ "f1f4d4e93b5b319b0a54b09dd47f1486", "grcpool.com-5", "https://grcpool.com/" });
         m_mining_pools.push_back({ "326bb50c0dd0ba9d46e15fae3484af35", "grc.arikado.pool", "https://gridcoinpool.ru/" });
     }
 
@@ -159,7 +160,7 @@ struct MiningProject
     //!
     //! \return A pointer to the whitelist project if it matches.
     //!
-    const Project* TryWhitelist(const WhitelistSnapshot& whitelist) const;
+    const GRC::ProjectEntry* TryWhitelist(const WhitelistSnapshot& whitelist) const;
 
     //!
     //! \brief Determine whether the project is whitelisted.
@@ -305,6 +306,7 @@ enum class BeaconError
     PENDING,            //!< Not enough time elapsed for pending advertisement.
     TX_FAILED,          //!< Beacon contract transacton failed to send.
     WALLET_LOCKED,      //!< Wallet not fully unlocked.
+    ALEADY_IN_MEMPOOL   //!< A beacon contract for this CPID is already in the mempool.
 };
 
 //!
@@ -549,6 +551,12 @@ public:
     //!
     CAmount Accrual() const;
 
+    //!
+    //! \brief Value of account accrual that is near MaxReward() based on accrual rate..
+    //! \return CAmount value. This is implemented in IAccrualComputer::NearRewardLimit().
+    //!
+    std::optional<CAmount> AccrualNearLimit() const;
+
     //!
     //! \brief Get a value that indicates how the wallet participates in the
     //! research reward protocol.
