@@ -7,12 +7,13 @@
 
 #include <memory>
 #include <atomic>
+#include <stdexcept>
 #include "main.h"
 #include "net.h"
 #include "rpc/server.h"
 #include "rpc/protocol.h"
 #ifdef SCRAPER_NET_PK_AS_ADDRESS
-#include "base58.h"
+#include <key_io.h>
 #endif
 #include "gridcoin/appcache.h"
 #include "gridcoin/project.h"
@@ -30,7 +31,6 @@ extern CCriticalSection cs_ScraperGlobals;
 extern unsigned int nScraperSleep;
 extern std::atomic<int64_t> g_nTimeBestReceived;
 extern ConvergedScraperStats ConvergedScraperStatsCache;
-extern CCriticalSection cs_mScrapersExt;
 extern CCriticalSection cs_ConvergedScraperStatsCache;
 extern AppCacheSectionExt GetExtendedScrapersCache();
 extern bool IsScraperMaximumManifestPublishingRateExceeded(int64_t& nTime, CPubKey& PubKey);
@@ -43,7 +43,7 @@ bool CSplitBlob::RecvPart(CNode* pfrom, CDataStream& vRecv)
     * erase from mapAlreadyAskedFor
     */
     auto& ss = vRecv;
-    uint256 hash(Hash(ss.begin(), ss.end()));
+    uint256 hash(Hash(ss));
     mapAlreadyAskedFor.erase(CInv(MSG_PART, hash));
 
     LOCK(cs_mapParts);
@@ -59,7 +59,7 @@ bool CSplitBlob::RecvPart(CNode* pfrom, CDataStream& vRecv)
         {
             LogPrint(BCLog::LogFlags::MANIFEST, "received part %s %u refs", hash.GetHex(), (unsigned) part.refs.size());
 
-            part.data = CSerializeData(vRecv.begin(), vRecv.end());
+            part.data = SerializeData(vRecv.begin(), vRecv.end());
             for (const auto& ref : part.refs)
             {
                 CSplitBlob& split = *ref.first;
@@ -97,14 +97,14 @@ bool CSplitBlob::RecvPart(CNode* pfrom, CDataStream& vRecv)
 
 bool CSplitBlob::isComplete() const EXCLUSIVE_LOCKS_REQUIRED(CSplitBlob::cs_manifest)
 {
-    return cntPartsRcvd == vParts.size();
+    return (!m_publish_in_progress && cntPartsRcvd == vParts.size());
 }
 
 void CSplitBlob::addPart(const uint256& ihash)
 {
     LOCK2(cs_mapParts, cs_manifest);
 
-    assert(ihash != Hash(vParts.end(),vParts.end()));
+    assert(ihash != Hash(MakeByteSpan(vParts)));
 
     unsigned n = vParts.size();
     auto rc = mapParts.emplace(ihash,CPart(ihash));
@@ -119,11 +119,13 @@ void CSplitBlob::addPart(const uint256& ihash)
     part.refs.emplace(this, n);
 }
 
-int CSplitBlob::addPartData(CDataStream&& vData)
+int CSplitBlob::addPartData(CDataStream&& vData, const bool& publish_in_progress)
 {
     LOCK2(cs_mapParts, cs_manifest);
 
-    uint256 hash(Hash(vData.begin(), vData.end()));
+    m_publish_in_progress = publish_in_progress;
+
+    uint256 hash(Hash(vData));
 
     auto it = mapParts.emplace(hash, CPart(hash));
 
@@ -138,11 +140,9 @@ int CSplitBlob::addPartData(CDataStream&& vData)
     if (!part.present())
     {
         /* missing data; use the supplied data */
-        /* prevent calling the Complete callback FIXME: make this look better */
-        cntPartsRcvd--;
         CSplitBlob::RecvPart(nullptr, vData);
-        cntPartsRcvd++;
     }
+
     return n;
 }
 
@@ -184,7 +184,7 @@ bool CSplitBlob::SendPartTo(CNode* pto, const uint256& hash) EXCLUSIVE_LOCKS_REQ
     {
         if (ipart->second.present())
         {
-            pto->PushMessage("part",ipart->second.getReader());
+            pto->PushMessage(NetMsgType::PART,ipart->second.getReader());
             return true;
         }
     }
@@ -275,7 +275,7 @@ EXCLUSIVE_LOCKS_REQUIRED(CSplitBlob::cs_mapParts)
 {
     LOCK(manifest->cs_manifest);
 
-    pto->PushMessage("scraperindex", *manifest);
+    pto->PushMessage(NetMsgType::SCRAPERINDEX, *manifest);
 
     return true;
 }
@@ -352,15 +352,14 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest)
 
     CKeyID ManifestKeyID = PubKey.GetID();
 
-    CBitcoinAddress ManifestAddress;
-    ManifestAddress.Set(ManifestKeyID);
+    CTxDestination ManifestAddress(ManifestKeyID);
 
     // This is the address corresponding to the manifest public key.
-    std::string sManifestAddress = ManifestAddress.ToString();
+    std::string sManifestAddress = EncodeDestination(ManifestAddress);
 
     AppCacheSectionExt mScrapersExtended = GetExtendedScrapersCache();
 
-    // Now mScrapersExt is up to date. Walk and see if there is an entry with a value of true that matches
+    // Now mScrapersExtended is up to date. Walk and see if there is an entry with a value of true that matches
     // manifest address. If so the manifest is authorized. Note that no grace period has to be considered
     // for the authorized case. To prevent islanding in the unauthorized case, we must allow a grace period
     // before we return a banscore > 0. The grace period must extend SCRAPER_DEAUTHORIZED_BANSCORE_GRACE_PERIOD
@@ -521,15 +520,13 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest, CSplitBlob::cs_manife
 
     ss >> nContentHash;
 
-    uint256 hash = Hash(pbegin, ss.begin());
+    uint256 hash = Hash(Span<const std::byte>{(std::byte*)&pbegin[0], (std::byte*)&ss.begin()[0]});
 
     ss >> signature;
     LogPrint(BCLog::LogFlags::MANIFEST, "CScraperManifest::UnserializeCheck: hash of signature = %s",
-             Hash(signature.begin(), signature.end()).GetHex());
+             Hash(signature).GetHex());
 
-    CKey mkey;
-    if (!mkey.SetPubKey(pubkey)) return error("CScraperManifest: Invalid manifest key");
-    if (!mkey.Verify(hash, signature)) return error("CScraperManifest: Invalid manifest signature");
+    if (!pubkey.Verify(hash, signature)) return error("CScraperManifest: Invalid manifest signature");
 
     for (const uint256& ph : vph)
     {
@@ -563,8 +560,8 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest)
                                                                                                iter->second)));
             if (!iter2.second)
             {
-                LogPrint("WARN: %s: Manifest insertion attempt into pending deleted map failed because an entry with the same "
-                         "hash = %s, already exists. This should not happen.", __func__, nHash.GetHex());
+                LogPrintf("WARN: %s: Manifest insertion attempt into pending deleted map failed because an entry with the same "
+                          "hash = %s, already exists. This should not happen.", __func__, nHash.GetHex());
             }
             else
             {
@@ -605,8 +602,8 @@ CScraperManifest::DeleteManifest(std::map<uint256, std::shared_ptr<CScraperManif
                                                                                            iter->second)));
         if (!iter2.second)
         {
-            LogPrint("WARN: %s: Manifest insertion attempt into pending deleted map failed because an entry with the same "
-                     "hash = %s, already exists. This should not happen.", __func__, iter->first.GetHex());
+            LogPrintf("WARN: %s: Manifest insertion attempt into pending deleted map failed because an entry with the same "
+                      "hash = %s, already exists. This should not happen.", __func__, iter->first.GetHex());
         }
         else
         {
@@ -677,7 +674,7 @@ bool CScraperManifest::RecvManifest(CNode* pfrom, CDataStream& vRecv)
     unsigned int banscore = 0;
 
     // hash the object
-    uint256 hash(Hash(vRecv.begin(), vRecv.end()));
+    uint256 hash(Hash(vRecv));
 
     LOCK(cs_mapManifest);
 
@@ -776,13 +773,13 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest, cs_mapParts)
 
         // serialize the content for comparison purposes and put in manifest.
         m->SerializeForManifestCompare(sscomp);
-        m->nContentHash = Hash(sscomp.begin(), sscomp.end());
+        m->nContentHash = Hash(sscomp);
 
         // serialize and hash the object
         m->SerializeWithoutSignature(ss);
 
         // sign the serialized manifest and append the signature
-        hash = Hash(ss.begin(), ss.end());
+        hash = Hash(ss);
         keySign.Sign(hash, m->signature);
 
         LogPrint(BCLog::LogFlags::MANIFEST, "INFO: CScraperManifest::addManifest: hash of manifest contents = %s",
@@ -790,7 +787,7 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest, cs_mapParts)
         LogPrint(BCLog::LogFlags::MANIFEST, "INFO: CScraperManifest::addManifest: hash of manifest = %s",
                  hash.ToString());
         LogPrint(BCLog::LogFlags::MANIFEST, "INFO: CScraperManifest::addManifest: hash of signature = %s",
-                 Hash(m->signature.begin(), m->signature.end()).GetHex());
+                 Hash(m->signature).GetHex());
         LogPrint(BCLog::LogFlags::MANIFEST, "INFO: CScraperManifest::addManifest: datetime = %s",
                  DateTimeStrFormat("%x %H:%M:%S", m->nTime));
 
@@ -804,7 +801,7 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest, cs_mapParts)
     if (it.second == false)
         return false;
 
-    // Release lock on cs_manifest before taking a lonk on cs_ConvergedScraperStatsCache to avoid potential deadlocks.
+    // Release lock on cs_manifest before taking a lock on cs_ConvergedScraperStatsCache to avoid potential deadlocks.
     {
         CScraperManifest& manifest = *it.first->second;
 
@@ -838,6 +835,8 @@ EXCLUSIVE_LOCKS_REQUIRED(CScraperManifest::cs_mapManifest, cs_mapParts)
 
 void CScraperManifest::Complete() EXCLUSIVE_LOCKS_REQUIRED(CSplitBlob::cs_manifest, CSplitBlob::cs_mapParts)
 {
+    m_publish_in_progress = false;
+
     // Notify peers that we have a new manifest
     LogPrint(BCLog::LogFlags::MANIFEST, "manifest %s complete with %u parts", phash->GetHex(), (unsigned)vParts.size());
     {
@@ -857,7 +856,7 @@ UniValue CScraperManifest::ToJson() const EXCLUSIVE_LOCKS_REQUIRED(CSplitBlob::c
     UniValue r(UniValue::VOBJ);
 
 #ifdef SCRAPER_NET_PK_AS_ADDRESS
-    r.pushKV("pubkey", CBitcoinAddress(pubkey.GetID()).ToString());
+    r.pushKV("pubkey", EncodeDestination(pubkey.GetID()));
 #else
     r.pushKV("pubkey", pubkey.GetID().ToString());
 #endif
@@ -950,7 +949,7 @@ UniValue listmanifests(const UniValue& params, bool fHelp)
         else
         {
 #ifdef SCRAPER_NET_PK_AS_ADDRESS
-            subset.pushKV("scraper (manifest) address", CBitcoinAddress(manifest.pubkey.GetID()).ToString());
+            subset.pushKV("scraper (manifest) address", EncodeDestination(manifest.pubkey.GetID()));
 #else
             subset.pushKV("scraper (manifest) pubkey", manifest.pubkey.GetID().ToString());
 #endif
@@ -973,7 +972,7 @@ UniValue listmanifests(const UniValue& params, bool fHelp)
             else
             {
     #ifdef SCRAPER_NET_PK_AS_ADDRESS
-                subset.pushKV("scraper (manifest) address", CBitcoinAddress(manifest.pubkey.GetID()).ToString());
+                subset.pushKV("scraper (manifest) address", EncodeDestination(manifest.pubkey.GetID()));
     #else
                 subset.pushKV("scraper (manifest) pubkey", manifest.pubkey.GetID().ToString());
     #endif
@@ -1007,5 +1006,5 @@ UniValue getmpart(const UniValue& params, bool fHelp)
         throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Object not found");
     }
 
-    return UniValue(HexStr(ipart->second.data.begin(), ipart->second.data.end()));
+    return UniValue(HexStr(ipart->second.data));
 }
