@@ -6,6 +6,7 @@
 #include "compat/endian.h"
 #include "hash.h"
 #include "main.h"
+#include <gridcoin/md5.h>
 #include "gridcoin/superblock.h"
 #include "gridcoin/support/xml.h"
 #include "node/blockstorage.h"
@@ -13,7 +14,6 @@
 #include "util.h"
 #include "util/reverse_iterator.h"
 
-#include <openssl/md5.h>
 
 using namespace GRC;
 
@@ -352,7 +352,7 @@ public:
         , m_averages(ExtractXML(packed, "<AVERAGES>", "</AVERAGES>"))
         , m_zero_mags(0)
     {
-        if (!ParseInt(ExtractXML(packed, "<ZERO>", "</ZERO>"), &m_zero_mags)) {
+        if (!ParseInt32(ExtractXML(packed, "<ZERO>", "</ZERO>"), &m_zero_mags)) {
             error("%s: Failed to parse zero mag CPIDs.", __func__);
         }
     }
@@ -456,8 +456,9 @@ private:
 
         for (size_t x = 0; x < binary_size && binary_size - x >= 18; x += 18) {
             magnitudes.AddLegacy(
-                *reinterpret_cast<const Cpid*>(byte_ptr + x),
-                be16toh(*reinterpret_cast<const int16_t*>(byte_ptr + x + 16)));
+                Cpid(std::vector<unsigned char>(byte_ptr + x, byte_ptr + x + 16)),
+                (((uint16_t)byte_ptr[x + 16] & 0xFF) << 8) | ((uint16_t)byte_ptr[x + 17] & 0xFF)
+            );
         }
 
         return magnitudes;
@@ -548,7 +549,7 @@ struct QuorumHashToStringVisitor
     //!
     std::string operator()(const QuorumHash::Md5Sum& legacy_hash) const
     {
-        return HexStr(legacy_hash.begin(), legacy_hash.end());
+        return HexStr(legacy_hash);
     }
 };
 } // anonymous namespace
@@ -577,11 +578,11 @@ Superblock Superblock::FromConvergence(
 {
     Superblock superblock = Superblock::FromStats(GetScraperStatsAndVerifiedBeacons(stats), version);
 
-    superblock.m_convergence_hint = stats.Convergence.nContentHash.GetUint64() >> 32;
+    superblock.m_convergence_hint = stats.Convergence.nContentHash.GetUint64(0) >> 32;
 
     if (!stats.Convergence.bByParts) {
         superblock.m_manifest_content_hint
-            = stats.Convergence.nUnderlyingManifestContentHash.GetUint64() >> 32;
+            = stats.Convergence.nUnderlyingManifestContentHash.GetUint64(0) >> 32;
 
         return superblock;
     }
@@ -973,8 +974,8 @@ void Superblock::ProjectIndex::SetHint(
         return;
     }
 
-    const uint256 part_hash = Hash(part_data_ptr->data.begin(), part_data_ptr->data.end());
-    iter->second.m_convergence_hint = part_hash.GetUint64() >> 32;
+    const uint256 part_hash = Hash(part_data_ptr->data);
+    iter->second.m_convergence_hint = part_hash.GetUint64(0) >> 32;
 
     m_converged_by_project = true;
 }
@@ -1083,7 +1084,7 @@ QuorumHash QuorumHash::Hash(const Superblock& superblock)
     }
 
     Md5Sum output;
-    MD5((const unsigned char*)input.data(), input.size(), output.data());
+    GRC__MD5((const unsigned char*)input.data(), input.size(), output.data());
 
     return QuorumHash(output);
 }
