@@ -23,21 +23,6 @@ using namespace GRC;
 using LogFlags = BCLog::LogFlags;
 
 namespace {
-//!
-//! \brief Get the string representation of an output destination for logging.
-//!
-//! \param dest Destination to convert to an address string.
-//!
-//! \return Base58-encoded string of the address.
-//!
-std::string DestinationToAddressString(const CTxDestination dest)
-{
-    CBitcoinAddress address;
-    address.Set(dest);
-
-    return address.ToString();
-}
-
 //!
 //! \brief A set of outputs associated with an address for a voting claim.
 //!
@@ -166,7 +151,7 @@ private:
         void operator()(const CKeyID& keyId, const COutput& output) const
         {
             LogPrint(LogFlags::VOTE, "  added output for address: %s",
-                DestinationToAddressString(keyId));
+                EncodeDestination(keyId));
 
             auto result_pair = m_by_address.emplace(keyId, keyId);
             AddressOutputs& address_outputs = result_pair.first->second;
@@ -184,7 +169,7 @@ private:
         {
             // Voting does not support redemption script outputs yet.
             LogPrint(LogFlags::VOTE, "  skipped script address: %s",
-                DestinationToAddressString(scriptId));
+                EncodeDestination(scriptId));
         }
 
     private:
@@ -219,14 +204,14 @@ private:
             //
             if (txo.tx->vout[txo.i].nValue < COIN) {
                 LogPrint(LogFlags::VOTE, "  skipped < 1 GRC outputs for: %s",
-                    DestinationToAddressString(dest));
+                    EncodeDestination(dest));
 
                 break; // The input set is sorted so the rest are too small.
             }
 
             if (!txo.tx->IsTrusted() || !txo.tx->IsConfirmed()) {
                 LogPrint(LogFlags::VOTE, "  skipped unconfirmed output for %s",
-                    DestinationToAddressString(dest));
+                    EncodeDestination(dest));
                 continue;
             }
 
@@ -302,11 +287,17 @@ public:
         if (!m_wallet.GetPubKey(address_outputs.m_key_id, claim.m_public_key)) {
             error("%s: failed to fetch public key for address %s",
                 __func__,
-                DestinationToAddressString(address_outputs.m_key_id));
+                EncodeDestination(address_outputs.m_key_id));
 
             return std::nullopt;
         }
 
+        LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: building address claim for address_outputs.m_key_id %s, "
+                                        "claim.m_public_key address %s.",
+                 __func__,
+                 EncodeDestination(address_outputs.m_key_id),
+                 EncodeDestination(claim.m_public_key.GetID()));
+
         // An address claim must submit outputs in ascending order. This
         // improves the performance of duplicate output validation:
         //
@@ -331,25 +322,25 @@ public:
         if (!m_wallet.GetKey(key_id, private_key)) {
             return error("%s: failed to fetch private key for address %s",
                 __func__,
-                DestinationToAddressString(key_id));
+                EncodeDestination(key_id));
         }
 
         if (!private_key.IsValid()) {
             return error("%s: invalid private key for address %s",
                 __func__,
-                DestinationToAddressString(key_id));
+                EncodeDestination(key_id));
         }
 
         if (!claim.Sign(private_key, message)) {
             return error("%s: failed to sign address claim for address %s",
                 __func__,
-                DestinationToAddressString(key_id));
+                EncodeDestination(key_id));
         }
 
         LogPrint(LogFlags::VOTE,
             "%s: signed address claim for address: %s",
             __func__,
-            DestinationToAddressString(key_id));
+            EncodeDestination(key_id));
 
         return true;
     }
@@ -412,6 +403,11 @@ public:
         const AddressClaimBuilder builder(m_wallet);
 
         for (auto& address_claim : claim.m_address_claims) {
+            LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: signing claim address %s",
+                     __func__,
+                     EncodeDestination(address_claim.m_public_key.GetID())
+                     );
+
             if (!builder.SignClaim(address_claim, message)) {
                 return false;
             }
@@ -448,7 +444,7 @@ private:
 
             LogPrint(LogFlags::VOTE, "%s: trimmed output claim from %s",
                 __func__,
-                DestinationToAddressString(address.m_key_id));
+                EncodeDestination(address.m_key_id));
 
             address.m_outpoints.pop_back();
             bytes_estimate -= txo_bytes;
@@ -456,7 +452,7 @@ private:
             if (address.m_outpoints.empty()) {
                 LogPrint(LogFlags::VOTE, "%s: trimmed address claim %s",
                     __func__,
-                    DestinationToAddressString(address.m_key_id));
+                    EncodeDestination(address.m_key_id));
 
                 by_address.pop_back();
                 bytes_estimate -= address_claim_bytes;
@@ -705,7 +701,7 @@ private:
             if (address.m_total_amount < POLL_REQUIRED_BALANCE) {
                 LogPrint(LogFlags::VOTE, "%s: exceeded max outputs for %s",
                     __func__,
-                    DestinationToAddressString(address.m_key_id));
+                    EncodeDestination(address.m_key_id));
 
                 return false;
             }
@@ -848,7 +844,10 @@ uint256 GRC::SendPollContract(PollBuilder builder)
 
     {
         LOCK2(cs_main, pwalletMain->cs_wallet);
-        result_pair = SendContract(builder.BuildContractTx(pwalletMain));
+
+        uint32_t contract_version = IsV13Enabled(nBestHeight) ? 3 : 2;
+
+        result_pair = SendContract(builder.BuildContractTx(pwalletMain, contract_version));
     }
 
     if (!result_pair.second.empty()) {
@@ -864,7 +863,10 @@ uint256 GRC::SendVoteContract(VoteBuilder builder)
 
     {
         LOCK2(cs_main, pwalletMain->cs_wallet);
-        result_pair = SendContract(builder.BuildContractTx(pwalletMain));
+
+        uint32_t contract_version = IsV13Enabled(nBestHeight) ? 3 : 2;
+
+        result_pair = SendContract(builder.BuildContractTx(pwalletMain, contract_version));
     }
 
     if (!result_pair.second.empty()) {
@@ -886,6 +888,20 @@ PollBuilder::PollBuilder(PollBuilder&& builder) = default;
 PollBuilder::~PollBuilder() = default;
 PollBuilder& PollBuilder::operator=(PollBuilder&& builder) = default;
 
+PollBuilder PollBuilder::SetPayloadVersion(uint32_t version)
+{
+    bool v3_enabled = IsPollV3Enabled(nBestHeight);
+
+    if ((v3_enabled && version < 3)
+            || (!v3_enabled && version >= 3)) {
+        throw VotingError(_("Wrong Payload version specified for current block height."));
+    }
+
+    m_poll_payload_version = version;
+
+    return std::move(*this);
+}
+
 PollBuilder PollBuilder::SetType(const PollType type)
 {
     if (type <= PollType::UNKNOWN || type >= PollType::OUT_OF_BOUND) {
@@ -949,10 +965,13 @@ PollBuilder PollBuilder::SetResponseType(const int64_t type)
 
 PollBuilder PollBuilder::SetDuration(const uint32_t days)
 {
-    if (days < Poll::MIN_DURATION_DAYS) {
+    uint32_t min_duration_days = std::max(Poll::MIN_DURATION_DAYS,
+                                          Poll::POLL_TYPE_RULES[m_poll->m_type.Raw()].m_mininum_duration);
+
+    if (days < min_duration_days) {
         throw VotingError(strprintf(
             _("Poll duration must be at least %s days."),
-            ToString(Poll::MIN_DURATION_DAYS)));
+            ToString(min_duration_days)));
     }
 
     // The protocol allows poll durations up to 180 days. To limit unhelpful
@@ -986,7 +1005,7 @@ PollBuilder PollBuilder::SetTitle(std::string title)
             ToString(Poll::MAX_TITLE_SIZE)));
     }
 
-    m_poll->m_title = std::move(title);
+    m_poll->m_title = title;
 
     return std::move(*this);
 }
@@ -1003,7 +1022,7 @@ PollBuilder PollBuilder::SetUrl(std::string url)
             ToString(Poll::MAX_URL_SIZE)));
     }
 
-    m_poll->m_url = std::move(url);
+    m_poll->m_url = url;
 
     return std::move(*this);
 }
@@ -1016,7 +1035,7 @@ PollBuilder PollBuilder::SetQuestion(std::string question)
             ToString(Poll::MAX_QUESTION_SIZE)));
     }
 
-    m_poll->m_question = std::move(question);
+    m_poll->m_question = question;
 
     return std::move(*this);
 }
@@ -1025,13 +1044,13 @@ PollBuilder PollBuilder::SetChoices(std::vector<std::string> labels)
 {
     m_poll->m_choices = Poll::ChoiceList();
 
-    return AddChoices(std::move(labels));
+    return AddChoices(labels);
 }
 
 PollBuilder PollBuilder::AddChoices(std::vector<std::string> labels)
 {
     for (auto& label : labels) {
-        *this = AddChoice(std::move(label));
+        *this = AddChoice(label);
     }
 
     return std::move(*this);
@@ -1062,12 +1081,93 @@ PollBuilder PollBuilder::AddChoice(std::string label)
         throw VotingError(strprintf(_("Duplicate poll choice: %s"), label));
     }
 
-    m_poll->m_choices.Add(std::move(label));
+    m_poll->m_choices.Add(label);
 
     return std::move(*this);
 }
 
-CWalletTx PollBuilder::BuildContractTx(CWallet* const pwallet)
+PollBuilder PollBuilder::SetAdditionalFields(std::vector<Poll::AdditionalField> fields)
+{
+    m_poll->m_additional_fields = Poll::AdditionalFieldList();
+
+    return AddAdditionalFields(fields);
+}
+
+PollBuilder PollBuilder::SetAdditionalFields(Poll::AdditionalFieldList fields)
+{
+    m_poll->m_additional_fields = Poll::AdditionalFieldList();
+
+    return AddAdditionalFields(fields);
+}
+
+PollBuilder PollBuilder::AddAdditionalFields(std::vector<Poll::AdditionalField> fields)
+{
+    for (auto& field : fields) {
+        *this = AddAdditionalField(field);
+    }
+
+    if (!m_poll->m_additional_fields.WellFormed(m_poll->m_type.Value())) {
+        throw VotingError(_("The field list is not well-formed."));
+    }
+
+    return std::move(*this);
+}
+
+PollBuilder PollBuilder::AddAdditionalFields(Poll::AdditionalFieldList fields)
+{
+    for (auto& field : fields) {
+        *this = AddAdditionalField(field);
+    }
+
+    if (!m_poll->m_additional_fields.WellFormed(m_poll->m_type.Value())) {
+        throw VotingError(_("The field list is not well-formed."));
+    }
+
+    return std::move(*this);
+}
+
+PollBuilder PollBuilder::AddAdditionalField(Poll::AdditionalField field)
+{
+    // Make sure there are no leading and trailing spaces.
+    field.m_name = TrimString(field.m_name);
+    field.m_value = TrimString(field.m_value);
+    field.m_required = field.m_required;
+
+    if (!field.WellFormed()) {
+        throw VotingError(_("The field is not well-formed."));
+    }
+
+    if (m_poll->m_additional_fields.size() + 1 > POLL_MAX_ADDITIONAL_FIELDS_SIZE) {
+        throw VotingError(strprintf(
+                              _("Poll cannot contain more than %s additional fields"),
+                              ToString(POLL_MAX_ADDITIONAL_FIELDS_SIZE)));
+    }
+
+    if (field.m_name.size() > Poll::AdditionalField::MAX_NAME_SIZE) {
+        throw VotingError(strprintf(
+                              _("Poll additional field name \"%s\" exceeds %s characters."),
+                              field.m_name,
+                              ToString(Poll::AdditionalField::MAX_NAME_SIZE)));
+    }
+
+    if (field.m_value.size() > Poll::AdditionalField::MAX_VALUE_SIZE) {
+        throw VotingError(strprintf(
+                              _("Poll additional field value \"%s\" for field name \"%s\" exceeds %s characters."),
+                              field.m_value,
+                              field.m_name,
+                              ToString(Poll::AdditionalField::MAX_VALUE_SIZE)));
+    }
+
+    if (m_poll->m_additional_fields.FieldExists(field.m_name)) {
+        throw VotingError(strprintf(_("Duplicate poll additional field: %s"), field.m_name));
+    }
+
+    m_poll->m_additional_fields.Add(field);
+
+    return std::move(*this);
+}
+
+CWalletTx PollBuilder::BuildContractTx(CWallet* const pwallet, const uint32_t& contract_version)
 {
     if (!pwallet) {
         throw VotingError(_("No wallet available."));
@@ -1099,13 +1199,21 @@ CWalletTx PollBuilder::BuildContractTx(CWallet* const pwallet)
     PollEligibilityClaim claim = claim_builder.BuildClaim(*m_poll);
 
     tx.vContracts.emplace_back(MakeContract<PollPayload>(
-        ContractAction::ADD,
-        std::move(*m_poll),
-        std::move(claim)));
+                                   contract_version,
+                                   ContractAction::ADD,
+                                   std::move(m_poll_payload_version),
+                                   std::move(*m_poll),
+                                   std::move(claim)));
 
     SelectFinalInputs<PollPayload>(*pwallet, tx);
     PollPayload& poll_payload = tx.vContracts.back().SharePayload().As<PollPayload>();
 
+    LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: tx contract payload claim address %s, poll title %s.",
+             __func__,
+             EncodeDestination(poll_payload.m_claim.m_address_claim.m_public_key.GetID()),
+             poll_payload.m_poll.m_title
+             );
+
     if (!claim_builder.SignClaim(poll_payload, tx)) {
         throw VotingError(_("Poll signature failed. See debug.log."));
     }
@@ -1117,6 +1225,12 @@ CWalletTx PollBuilder::BuildContractTx(CWallet* const pwallet)
         throw VotingError("Poll incomplete. This is probably a bug.");
     }
 
+    // Validate poll
+    int DoS = 0; // unused here
+    if (!GetPollRegistry().Validate(tx.vContracts.back(), tx, DoS)) {
+        throw VotingError("Poll invalid.");
+    }
+
     return tx;
 }
 
@@ -1224,7 +1338,7 @@ VoteBuilder VoteBuilder::AddResponse(const std::string& label)
     throw VotingError(strprintf(_("\"%s\" is not a valid poll choice."), label));
 }
 
-CWalletTx VoteBuilder::BuildContractTx(CWallet* const pwallet)
+CWalletTx VoteBuilder::BuildContractTx(CWallet* const pwallet, const uint32_t& contract_version)
 {
     if (!pwallet) {
         throw VotingError(_("No wallet available."));
@@ -1240,7 +1354,7 @@ CWalletTx VoteBuilder::BuildContractTx(CWallet* const pwallet)
     claim_builder.BuildClaim(*m_vote, *m_poll);
 
     tx.vContracts.emplace_back(
-        MakeContract<Vote>(ContractAction::ADD, std::move(*m_vote)));
+        MakeContract<Vote>(contract_version, ContractAction::ADD, std::move(*m_vote)));
 
     SelectFinalInputs<Vote>(*pwallet, tx);
     Vote& vote = tx.vContracts.back().SharePayload().As<Vote>();
