@@ -10,8 +10,11 @@
 #include "gridcoin/voting/result.h"
 #include "gridcoin/voting/poll.h"
 #include "gridcoin/voting/vote.h"
+#include "gridcoin/researcher.h"
 #include "txdb.h"
 #include "util/reverse_iterator.h"
+#include "wallet/wallet.h"
+#include "init.h"
 
 #include <optional>
 #include <queue>
@@ -23,6 +26,8 @@ using ResponseDetail = PollResult::ResponseDetail;
 using VoteDetail = PollResult::VoteDetail;
 using Weight = PollResult::Weight;
 
+extern MiningPools g_mining_pools;
+
 namespace {
 //!
 //! \brief Used for mapping legacy vote answer labels to poll choice offsets.
@@ -47,7 +52,7 @@ struct OutPointHasher
 {
     size_t operator()(const COutPoint& outpoint) const
     {
-        return outpoint.hash.GetUint64() + outpoint.n;
+        return outpoint.hash.GetUint64(0) + outpoint.n;
     }
 };
 
@@ -97,6 +102,21 @@ public:
         return m_payload.As<GRC::LegacyVote>();
     }
 
+    //!
+    //! \brief returns IsMine flag on transaction containing vote contract
+    //!
+    isminetype IsMine() const
+    {
+        LOCK(pwalletMain->cs_wallet);
+
+        LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: vote contract tx hash %s ismine status %i",
+                 __func__,
+                 m_tx.GetHash().GetHex(),
+                 pwalletMain->IsMine(m_tx));
+
+        return pwalletMain->IsMine(m_tx);
+    }
+
     //!
     //! \brief Serialize a vote for claim signing and verification.
     //!
@@ -154,17 +174,21 @@ public:
     //!
     VoteDetail Resolve(const VoteCandidate& candidate)
     {
+        g_timer.GetTimes(std::string{"Begin "} + std::string{__func__}, "buildPollTable");
+
         const Vote& vote = candidate.Vote();
         const ClaimMessage message = candidate.PackMessage();
 
         VoteDetail detail;
         detail.m_amount = Resolve(vote.m_claim.m_balance_claim, message);
+        detail.m_ismine = candidate.IsMine();
 
         if (m_poll.IncludesMagnitudeWeight()) {
             detail.m_mining_id = vote.m_claim.m_magnitude_claim.m_mining_id;
             detail.m_magnitude = Resolve(vote.m_claim.m_magnitude_claim, message);
         }
 
+        g_timer.GetTimes(std::string{"End "} + std::string{__func__}, "buildPollTable");
         return detail;
     }
 
@@ -786,29 +810,42 @@ public:
     //!
     void CountVotes(PollResult& result, const std::vector<uint256>& vote_txids)
     {
+        g_timer.GetTimes(std::string{"Begin "} + std::string{__func__}, "buildPollTable");
+
         m_votes.reserve(vote_txids.size());
 
         for (const auto& txid : reverse_iterate(vote_txids)) {
             try {
                 ProcessVoteCandidate(FetchVoteCandidate(txid));
             } catch (const InvalidVoteError& e) {
-                LogPrint(LogFlags::VOTE, "%s: skipped invalid vote: %s",
+                LogPrint(LogFlags::VOTE, "INFO: %s: skipped invalid vote: %s",
                     __func__,
                     txid.ToString());
 
                 ++result.m_invalid_votes;
+            } catch (const InvalidDuetoReorgFork& e) {
+                LogPrint(LogFlags::VOTE, " INFO: %s: aborted vote count due to reorg/fork",
+                         __func__);
+
+                g_timer.GetTimes(std::string{"End "} + std::string{__func__}, "buildPollTable");
+                throw InvalidDuetoReorgFork();
             }
         }
 
         for (auto& vote : m_votes) {
             result.TallyVote(std::move(vote));
         }
+
+        result.m_pools_voted = m_pools_voted;
+
+        g_timer.GetTimes(std::string{"End "} + std::string{__func__}, "buildPollTable");
     }
 
 private:
     CTxDB& m_txdb;
     const Poll& m_poll;
     std::vector<VoteDetail> m_votes;
+    std::vector<Cpid> m_pools_voted;
     Weight m_magnitude_factor;
     VoteResolver m_resolver;
     LegacyVoteCounterContext m_legacy;
@@ -832,18 +869,28 @@ private:
     {
         CTransaction tx;
 
-        if (!m_txdb.ReadDiskTx(txid, tx)) {
-            LogPrint(LogFlags::VOTE, "%s: failed to read vote tx", __func__);
-            throw InvalidVoteError();
+        {
+            // This lock is taken here to ensure that we wait on the leveldb batch write ("transaction commit") to finish
+            // in ReorganizeChain (which is essentially the ConnectBlock scope) and ensure that the voting transactions
+            // which correspond to the new vote signals sent from the contract handlers are actually present in leveldb when
+            // the below ReadDiskTx is called.
+            LOCK(cs_tx_val_commit_to_disk);
+            LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: cs_tx_val_commit_to_disk locked", __func__);
+
+            if (!m_txdb.ReadDiskTx(txid, tx)) {
+                LogPrintf("WARN: %s: failed to read vote tx.", __func__);
+            }
+
+            LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: cs_tx_val_commit_to_disk unlocked", __func__);
         }
 
         if (tx.nTime < m_poll.m_timestamp) {
-            LogPrint(LogFlags::VOTE, "%s: tx earlier than poll", __func__);
+            LogPrintf("WARN: %s: tx earlier than poll", __func__);
             throw InvalidVoteError();
         }
 
         if (m_poll.Expired(tx.nTime)) {
-            LogPrint(LogFlags::VOTE, "%s: tx exceeds expiration", __func__);
+            LogPrintf("WARN: %s: tx exceeds expiration", __func__);
             throw InvalidVoteError();
         }
 
@@ -853,7 +900,7 @@ private:
             }
 
             if (!contract.WellFormed()) {
-                LogPrint(LogFlags::VOTE, "%s: skipped bad contract", __func__);
+                LogPrintf("WARN: %s: skipped bad contract", __func__);
                 continue;
             }
 
@@ -871,6 +918,10 @@ private:
     //!
     void ProcessVoteCandidate(const VoteCandidate& candidate)
     {
+        if (GetPollRegistry().reorg_occurred_during_reg_traversal) {
+            throw InvalidDuetoReorgFork();
+        }
+
         if (!candidate.IsLegacy()) {
             ProcessVote(candidate);
             return;
@@ -884,7 +935,14 @@ private:
             throw InvalidVoteError();
         }
 
+#if defined(__clang__)
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wthread-safety-analysis"
+#endif
         ProcessLegacyVote(candidate.LegacyVote());
+#if defined(__clang__)
+#pragma clang diagnostic pop
+#endif
     }
 
     //!
@@ -894,6 +952,8 @@ private:
     //!
     void ProcessVote(const VoteCandidate& candidate)
     {
+        g_timer.GetTimes(std::string{"Begin "} + std::string{__func__}, "buildPollTable");
+
         VoteDetail detail = m_resolver.Resolve(candidate);
 
         if (detail.Empty()) {
@@ -912,7 +972,27 @@ private:
 
         CalculateWeight(detail, m_magnitude_factor);
 
+        const std::vector<MiningPool>& mining_pools = g_mining_pools.GetMiningPools();
+
+        // Record if a pool votes
+        if (detail.m_mining_id.TryCpid()) {
+            for (const auto& pool : mining_pools) {
+                if (detail.m_mining_id == pool.m_cpid) {
+                    LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: Pool with CPID %s voted on poll %s.",
+                             __func__,
+                             detail.m_mining_id.TryCpid()->ToString(),
+                             m_poll.m_title);
+
+                    m_pools_voted.push_back(*detail.m_mining_id.TryCpid());
+
+                    break;
+                }
+            }
+        }
+
         m_votes.emplace_back(std::move(detail));
+
+        g_timer.GetTimes(std::string{"End "} + std::string{__func__}, "buildPollTable");
     }
 
     //!
@@ -920,7 +1000,7 @@ private:
     //!
     //! \param vote Contains the vote contract to resolve.
     //!
-    void ProcessLegacyVote(const LegacyVote& vote)
+    void ProcessLegacyVote(const LegacyVote& vote) EXCLUSIVE_LOCKS_REQUIRED(PollRegistry::cs_poll_registry)
     {
         if (m_legacy.SeenKey(vote.m_key)) {
             LogPrint(LogFlags::VOTE, "%s: skipped duplicate key", __func__);
@@ -1083,13 +1163,21 @@ PollResult::PollResult(Poll poll)
     : m_poll(std::move(poll))
     , m_total_weight(0)
     , m_invalid_votes(0)
-    , m_finished(poll.Expired(GetAdjustedTime()))
+    , m_pools_voted({})
+    , m_active_vote_weight()
+    , m_vote_percent_avw()
+    , m_poll_results_validated()
+    , m_finished(m_poll.Expired(GetAdjustedTime()))
+    , m_self_voted(false)
+    , m_self_vote_detail()
 {
     m_responses.resize(m_poll.Choices().size());
 }
 
 PollResultOption PollResult::BuildFor(const PollReference& poll_ref)
 {
+    g_timer.GetTimes(std::string{"Begin "} + std::string{__func__}, "buildPollTable");
+
     if (PollOption poll = poll_ref.TryReadFromDisk()) {
         CTxDB txdb("r");
         PollResult result(std::move(*poll));
@@ -1101,11 +1189,37 @@ PollResultOption PollResult::BuildFor(const PollReference& poll_ref)
                 ResolveMoneySupplyForPoll(result.m_poll));
         }
 
+        LogPrint(BCLog::LogFlags::VOTE, "INFO: %s: number of votes = %u for poll %s",
+                 __func__, poll_ref.Votes().size(), result.m_poll.m_title);
+
         counter.CountVotes(result, poll_ref.Votes());
 
+        if (auto active_vote_weight = poll_ref.GetActiveVoteWeight(result)) {
+            result.m_active_vote_weight = active_vote_weight;
+
+            result.m_vote_percent_avw = (double) result.m_total_weight / (double) *result.m_active_vote_weight * 100.0;
+
+            // For purposes of validation, integer arithmetic is used.
+            uint32_t vote_percent_avw_for_validation = (uint32_t)((int64_t) result.m_total_weight * (int64_t) 100
+                                                                  / (int64_t) *result.m_active_vote_weight);
+
+            // For v1 and v2 polls, there is only one type, SURVEY, that was used on the blockchain for all polls, so this
+            // can only be done for v3+.
+            if (poll_ref.GetPollPayloadVersion() > 2) {
+                uint32_t min_vote_percent_avw_for_validation
+                        = Poll::POLL_TYPE_RULES[(int) poll_ref.GetPollType()].m_min_vote_percent_AVW;
+
+                result.m_poll_results_validated = (vote_percent_avw_for_validation >= min_vote_percent_avw_for_validation);
+            }
+        }
+
+        g_timer.GetTimes(std::string{"End "} + std::string{__func__}, "buildPollTable");
+
         return result;
     }
 
+    g_timer.GetTimes(std::string{"End "} + std::string{__func__}, "buildPollTable");
+
     return std::nullopt;
 }
 
@@ -1127,6 +1241,15 @@ void PollResult::TallyVote(VoteDetail detail)
         return;
     }
 
+    if (detail.m_ismine != ISMINE_NO) {
+        m_self_voted = true;
+
+        m_self_vote_detail.m_amount += detail.m_amount;
+        m_self_vote_detail.m_mining_id = detail.m_mining_id;
+        m_self_vote_detail.m_magnitude = detail.m_magnitude;
+        m_self_vote_detail.m_ismine = detail.m_ismine;
+    }
+
     for (const auto& response_pair : detail.m_responses) {
         const uint8_t response_offset = response_pair.first;
         const Weight response_weight = response_pair.second;
@@ -1134,6 +1257,24 @@ void PollResult::TallyVote(VoteDetail detail)
         m_responses[response_offset].m_weight += response_weight;
         m_responses[response_offset].m_votes += 1.0 / detail.m_responses.size();
         m_total_weight += response_weight;
+
+        if (detail.m_ismine != ISMINE_NO) {
+            bool choice_found = false;
+
+            // If the response offset entry already exists, then append to the existing entry...
+            for (auto& choice : m_self_vote_detail.m_responses) {
+                if (choice.first == response_offset) {
+                    choice.second += response_weight;
+                    choice_found = true;
+                    break;
+                }
+            }
+
+            // Otherwise make a new m_responses entry to represent the response offset and the associated weight.
+            if (!choice_found) {
+                m_self_vote_detail.m_responses.push_back(std::make_pair(response_offset, response_weight));
+            }
+        }
     }
 
     m_votes.emplace_back(std::move(detail));
@@ -1151,7 +1292,16 @@ ResponseDetail::ResponseDetail() : m_weight(0), m_votes(0)
 // Class: PollResult::VoteDetail
 // -----------------------------------------------------------------------------
 
-VoteDetail::VoteDetail() : m_amount(0), m_magnitude(Magnitude::Zero())
+VoteDetail::VoteDetail() : m_amount(0), m_magnitude(Magnitude::Zero()), m_ismine(ISMINE_NO)
+{
+}
+
+VoteDetail::VoteDetail(const VoteDetail &original_votedetail)
+    : m_amount(original_votedetail.m_amount)
+      , m_mining_id(original_votedetail.m_mining_id)
+      , m_magnitude(original_votedetail.m_magnitude)
+      , m_ismine(original_votedetail.m_ismine)
+      , m_responses(original_votedetail.m_responses)
 {
 }
 
@@ -1159,3 +1309,5 @@ bool VoteDetail::Empty() const
 {
     return m_amount == 0 && m_magnitude == 0;
 }
+
+VoteDetail& VoteDetail::operator=(const VoteDetail& b) = default;
