@@ -5,6 +5,7 @@
 
 
 #include "chainparams.h"
+#include "gridcoin/support/block_finder.h"
 #include "util.h"
 #include "util/threadnames.h"
 #include "net.h"
@@ -18,8 +19,10 @@
 #include "scheduler.h"
 #include "gridcoin/gridcoin.h"
 #include "gridcoin/upgrade.h"
+#include "gridcoin/contract/registry.h"
 #include "miner.h"
 #include "node/blockstorage.h"
+#include <util/syserror.h>
 
 #include <boost/algorithm/string/predicate.hpp>
 #include <openssl/crypto.h>
@@ -65,11 +68,39 @@ static fs::path GetPidFile(const ArgsManager& args)
     return AbsPathForConfigVal(fs::path(args.GetArg("-pid", GRIDCOIN_PID_FILENAME)));
 }
 
+[[nodiscard]] static bool CreatePidFile(const ArgsManager& args)
+{
+    fsbridge::ofstream file{GetPidFile(args)};
+    if (file) {
+#ifdef WIN32
+        tfm::format(file, "%d\n", GetCurrentProcessId());
+#else
+        tfm::format(file, "%d\n", getpid());
+#endif
+        return true;
+    } else {
+        return InitError(strprintf(_("Unable to create the PID file '%s': %s"), GetPidFile(args).string(), SysErrorString(errno)));
+    }
+}
+
 //////////////////////////////////////////////////////////////////////////////
 //
 // Shutdown
 //
 
+#if HAVE_SYSTEM
+static void ShutdownNotify(const ArgsManager& args)
+{
+    std::vector<std::thread> threads;
+    for (const auto& cmd : args.GetArgs("-shutdownnotify")) {
+        threads.emplace_back(runCommand, cmd);
+    }
+    for (auto& t : threads) {
+        t.join();
+    }
+}
+#endif
+
 bool ShutdownRequested()
 {
     return fRequestShutdown;
@@ -109,6 +140,11 @@ void Shutdown(void* parg)
     if (fFirstThread)
     {
          LogPrintf("gridcoinresearch exiting...");
+
+        #if HAVE_SYSTEM
+            ShutdownNotify(gArgs);
+        #endif
+
         fShutdown = true;
 
         // Signal to the scheduler to stop.
@@ -147,6 +183,7 @@ void Shutdown(void* parg)
         // This causes issues on daemons where it tries to create a second
         // lock file.
         //CTxDB().Close();
+        ECC_Stop();
         UninterruptibleSleep(std::chrono::milliseconds{50});
         LogPrintf("Gridcoin exited");
         fExit = true;
@@ -210,7 +247,7 @@ static void CreateNewConfigFile()
     myConfig
         << "addnode=addnode-us-central.cycy.me\n"
         << "addnode=ec2-3-81-39-58.compute-1.amazonaws.com\n"
-        << "addnode=gridcoin.ddns.net\n"
+        << "addnode=gridcoin.network\n"
         << "addnode=seeds.gridcoin.ifoggz-network.xyz\n"
         << "addnode=seed.gridcoin.pl\n"
         << "addnode=www.grcpool.com\n";
@@ -298,7 +335,12 @@ void SetupServerArgs()
     argsman.AddArg("-datadir=<dir>", "Specify data directory", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-wallet=<dir>", "Specify wallet file (within data directory)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
-    argsman.AddArg("-dbcache=<n>", "Set database cache size in megabytes (default: 25)",
+    argsman.AddArg("-dbcache=<n>", strprintf("Set database cache size in megabytes (%d to %d, default: %d)",
+                                             nMinDbCache, nMaxDbCache, nDefaultDbCache),
+                   ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+    argsman.AddArg("-txindexdbcache=<n>", strprintf("Set txindex (leveldb) database cache size in megabytes "
+                                                    "(%d to %d, default: %d)",
+                                                    nMinDbCache, nMaxTxIndexCache, nDefaultDbCache),
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-dblogsize=<n>", "Set database disk log size in megabytes (default: 100)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
@@ -311,27 +353,26 @@ void SetupServerArgs()
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-mininput=<amt>", "When creating transactions, ignore inputs with value less than this (default: 0.01)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
-    argsman.AddArg("-daemon", "Run in the background as a daemon and accept commands",
-                   ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-testnet", "Use the test network", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+#if HAVE_SYSTEM
     argsman.AddArg("-blocknotify=<cmd>", "Execute command when the best block changes (%s in cmd is replaced by block hash)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-walletnotify=<cmd>", "Execute command when a wallet transaction changes (%s in cmd is replaced by TxID)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+#endif
     argsman.AddArg("-confchange", "Require confirmations for change (default: 0)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-enforcecanonical", "Enforce transaction scripts to use canonical PUSH operators (default: 1)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+#if HAVE_SYSTEM
     argsman.AddArg("-alertnotify=<cmd>", "Execute command when a relevant alert is received or we see a really long fork"
                                          " (%s in cmd is replaced by message)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+#endif
     argsman.AddArg("-blockminsize=<n>", "Set minimum block size in bytes (default: 0)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-blockmaxsize=<n>", strprintf("Set maximum block size in bytes (default: %u)", MAX_BLOCK_SIZE_GEN/2),
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
-    argsman.AddArg("-blockprioritysize=<n>", "Set maximum size of high-priority/low-fee transactions in bytes"
-                                             " (default: 27000)",
-                   ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-snapshotdownload", "Download and apply latest snapshot",
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
     argsman.AddArg("-snapshoturl=<url>", "Optional: URL for the snapshot.zip file (ex: "
@@ -362,8 +403,11 @@ void SetupServerArgs()
                                                  " prefixed by datadir location. (default: %s)",
                                                  GRIDCOIN_CONF_FILENAME, GRIDCOIN_SETTINGS_FILENAME),
                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
-    //TODO: Implement startupnotify option
-    //argsman.AddArg("-startupnotify=<cmd>", "Execute command on startup.", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+    argsman.AddArg("-startupnotify=<cmd>", "Execute command on startup.", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+    argsman.AddArg("-shutdownnotify=<cmd>", "Execute command immediately before beginning shutdown. The need for shutdown may be urgent,"
+                                                " so be careful not to delay it long (if the command doesn't require interaction with the"
+                                                " server, consider having it fork into the background).",
+                    ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
 
 
     // Staking
@@ -389,6 +433,13 @@ void SetupServerArgs()
                                                    "if -enablesidestaking is set. If set along with -sidestakeaddresses "
                                                    "overrides the -sidestake entries.",
                    ArgsManager::ALLOW_ANY | ArgsManager::IMMEDIATE_EFFECT, OptionsCategory::STAKING);
+    argsman.AddArg("-sidestakedescriptions=string1,string2,...,stringN>", "Sidestake entry description. There can be as many "
+                                                                          "specified as desired. Only six per stake can be sent. "
+                                                                          "If more than six are specified. Six are randomly chosen "
+                                                                          "for each stake. Only active if -enablesidestaking is set. "
+                                                                          "If set along with -sidestakeaddresses overrides the "
+                                                                          "-sidestake entries.",
+                   ArgsManager::ALLOW_ANY | ArgsManager::IMMEDIATE_EFFECT, OptionsCategory::STAKING);
     argsman.AddArg("-enablestakesplit", "Enable unspent output spitting when staking to optimize staking efficiency "
                                         "(default: 0",
                    ArgsManager::ALLOW_ANY | ArgsManager::IMMEDIATE_EFFECT, OptionsCategory::STAKING);
@@ -424,12 +475,12 @@ void SetupServerArgs()
                    ArgsManager::ALLOW_ANY, OptionsCategory::RESEARCHER);
 
     // Wallet
-    argsman.AddArg("-upgradewallet", "Upgrade wallet to latest format",
-                   ArgsManager::ALLOW_ANY, OptionsCategory::WALLET);
-    argsman.AddArg("-keypool=<n>", "Set key pool size to <n> (default: 100)",
+    argsman.AddArg("-keypool=<n>", strprintf("Set key pool size to <n> (default: %u for HD, %u for pre-HD wallets)", DEFAULT_KEYPOOL_SIZE, DEFAULT_KEYPOOL_SIZE_PRE_HD),
                    ArgsManager::ALLOW_ANY, OptionsCategory::WALLET);
     argsman.AddArg("-rescan", "Rescan the block chain for missing wallet transactions",
                    ArgsManager::ALLOW_ANY, OptionsCategory::WALLET);
+    argsman.AddArg("-rescanmrcrequests", "Rescan the block chain for missing mrc request transactions",
+                   ArgsManager::ALLOW_ANY, OptionsCategory::WALLET);
     argsman.AddArg("-salvagewallet", "Attempt to recover private keys from a corrupt wallet.dat",
                    ArgsManager::ALLOW_ANY, OptionsCategory::WALLET);
     argsman.AddArg("-zapwallettxes", "Delete all wallet transactions and only recover those parts of the blockchain through"
@@ -554,11 +605,38 @@ void SetupServerArgs()
                    "Acceptable ciphers (default: TLSv1.2+HIGH:TLSv1+HIGH:!SSLv2:!aNULL:!eNULL:!3DES:@STRENGTH)",
                    ArgsManager::ALLOW_ANY, OptionsCategory::RPC);
 
+#if HAVE_DECL_FORK
+    argsman.AddArg("-daemon",
+                   strprintf("Run in the background as a daemon and accept commands (default: %d)", DEFAULT_DAEMON),
+                   ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+    argsman.AddArg("-daemonwait",
+                   strprintf("Wait for initialization to be finished before exiting. "
+                             "This implies -daemon (default: %d)", DEFAULT_DAEMONWAIT),
+                   ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+#else
+    hidden_args.emplace_back("-daemon");
+    hidden_args.emplace_back("-daemonwait");
+#endif
+
+    // Temporary hidden option for block v13 height override to facilitate testing.
+    hidden_args.emplace_back("-blockv13height");
+
     // Additional hidden options
     hidden_args.emplace_back("-devbuild");
     hidden_args.emplace_back("-scrapersleep");
     hidden_args.emplace_back("-activebeforesb");
-    hidden_args.emplace_back("-clearbeaconhistory");
+
+    // This puts hidden options in the form of -clear<type>history, where <type> is the contract types that have a
+    // registry with a backing db. This is currently beacon, project, protocol, and scraper, with sidestakes starting
+    // at V13 height.
+    for (const auto& contract_type : GRC::RegistryBookmarks::CONTRACT_TYPES_WITH_REG_DB) {
+        std::string history_arg = "-clear" + GRC::Contract::Type::ToString(contract_type) + "history";
+
+        hidden_args.emplace_back(history_arg);
+    }
+
+    // Also allow the -clearallregistryhistory hidden argument to support clearing all of the registries.
+    hidden_args.emplace_back("-clearallregistryhistory");
 
     // -boinckey should now be removed entirely. It is put here to prevent the executable erroring out on
     // an invalid parameter for old clients that may have left the argument in.
@@ -581,6 +659,8 @@ void SetupServerArgs()
     // This is hidden because it defaults to true and should NEVER be changed unless you know what you are doing.
     hidden_args.emplace_back("-flushwallet");
 
+    hidden_args.emplace_back("-upgradewallet");
+
     SetupChainParamsBaseOptions(argsman);
 
     // Add the hidden options
@@ -617,6 +697,17 @@ bool InitSanityCheck()
     return true;
 }
 
+#if HAVE_SYSTEM
+static void StartupNotify(const ArgsManager& args)
+{
+    std::string cmd = args.GetArg("-startupnotify", "");
+    if (!cmd.empty()) {
+        std::thread t(runCommand, cmd);
+        t.detach(); // thread runs free
+    }
+}
+#endif
+
 /**
  * Initialize global loggers.
  *
@@ -881,28 +972,10 @@ bool AppInit2(ThreadHandlerPtr threads)
             LogInstance().EnableCategory(BCLog::LogFlags::VERBOSE);
     }
 
-#if defined(WIN32)
-    fDaemon = false;
-#else
-    if(fQtActive)
-        fDaemon = false;
-    else
-        fDaemon = gArgs.GetBoolArg("-daemon");
-#endif
-
     // Check for -socks - as this is a privacy risk to continue, exit here
     if (gArgs.IsArgSet("-socks"))
         return InitError(_("Error: Unsupported argument -socks found. Setting SOCKS version isn't possible anymore, only SOCKS5 proxies are supported."));
 
-    if (fDaemon)
-        fServer = true;
-    else
-        fServer = gArgs.GetBoolArg("-server");
-
-    /* force fServer when running without GUI */
-    if(!fQtActive)
-        fServer = true;
-
     if (gArgs.IsArgSet("-timeout"))
     {
         int nNewTimeout = gArgs.GetArg("-timeout", 5000);
@@ -938,16 +1011,23 @@ bool AppInit2(ThreadHandlerPtr threads)
     }
 
     // ********************************************************* Step 4: application initialization: dir lock, daemonize, pidfile, debug log
-    // Sanity check
-    if (!InitSanityCheck())
-        return InitError(_("Initialization sanity check failed. Gridcoin is shutting down."));
-
+    if (!CreatePidFile(gArgs)) {
+        // Detailed error printed inside CreatePidFile().
+        return false;
+    }
     // Initialize internal hashing code with SSE/AVX2 optimizations. In the future we will also have ARM/NEON optimizations.
     std::string sha256_algo = SHA256AutoDetect();
     LogPrintf("Using the '%s' SHA256 implementation\n", sha256_algo);
     RandomInit();
+    ECC_Start();
+
+    // Sanity check
+    if (!InitSanityCheck())
+        return InitError(_("Initialization sanity check failed. Gridcoin is shutting down."));
 
     LogPrintf("Block version 11 hard fork configured for block %d", Params().GetConsensus().BlockV11Height);
+    LogPrintf("Block version 12 hard fork configured for block %d",
+              gArgs.GetArg("-blockv12height", Params().GetConsensus().BlockV12Height));
 
     fs::path datadir = GetDataDir();
     fs::path walletFileName = gArgs.GetArg("-wallet", "wallet.dat");
@@ -966,33 +1046,6 @@ bool AppInit2(ThreadHandlerPtr threads)
         return InitError(strprintf(_("Cannot obtain a lock on data directory %s. %s is probably already running."), datadir.string(), PACKAGE_NAME));
     }
 
-
-#if !defined(WIN32)
-    if (fDaemon)
-    {
-        // Daemonize
-        pid_t pid = fork();
-        if (pid < 0)
-        {
-            tfm::format(std::cerr, "Error: fork() returned %d errno %d\n", pid, errno);
-            return false;
-        }
-        if (pid > 0)
-        {
-            CreatePidFile(GetPidFile(gArgs), pid);
-
-            // Now that we are forked we can request a shutdown so the parent
-            // exits while the child lives on.
-            StartShutdown();
-            return true;
-        }
-
-        pid_t sid = setsid();
-        if (sid < 0)
-            tfm::format(std::cerr, "Error: setsid() returned %d errno %d\n", sid, errno);
-    }
-#endif
-
     #if (OPENSSL_VERSION_NUMBER < 0x10100000L)
         LogPrintf("Using OpenSSL version %s\n", SSLeay_version(SSLEAY_VERSION));
     #elif defined OPENSSL_VERSION
@@ -1021,9 +1074,6 @@ bool AppInit2(ThreadHandlerPtr threads)
         }
     }
 
-    if (fDaemon)
-        tfm::format(std::cout, "Gridcoin server starting\n");
-
     // ********************************************************* Step 5: verify database integrity
 
     uiInterface.InitMessage(_("Verifying database integrity..."));
@@ -1085,7 +1135,7 @@ bool AppInit2(ThreadHandlerPtr threads)
     CService addrProxy;
     bool fProxy = false;
     if (gArgs.IsArgSet("-proxy")) {
-        addrProxy = CService(gArgs.GetArg("-proxy", ""), 9050);
+        CService addrProxy(LookupNumeric(gArgs.GetArg("-proxy", "").c_str(), 9050));
         if (!addrProxy.IsValid())
             return InitError(strprintf(_("Invalid -proxy address: '%s'"), gArgs.GetArg("-proxy", "")));
 
@@ -1094,19 +1144,26 @@ bool AppInit2(ThreadHandlerPtr threads)
         if (!IsLimited(NET_IPV6))
             SetProxy(NET_IPV6, addrProxy);
         SetNameProxy(addrProxy);
-        
         fProxy = true;
     }
 
     // -tor can override normal proxy, -notor disables Tor entirely
-    if (gArgs.IsArgSet("-tor") && (fProxy || gArgs.IsArgSet("-tor"))) {
+    if (gArgs.IsArgSet("-tor")) {
         CService addrOnion;
-        if (!gArgs.IsArgSet("-tor"))
-            addrOnion = addrProxy;
-        else
-            addrOnion = CService(gArgs.GetArg("-tor", ""), 9050);
-        if (!addrOnion.IsValid())
-            return InitError(strprintf(_("Invalid -tor address: '%s'"), gArgs.GetArg("-tor", "")));
+
+        // If -tor is specified without any argument, and proxy was specified, then override proxy with tor
+        // at same address and port.
+        if (gArgs.GetArg("-tor", "") == "") {
+            if (fProxy) {
+                addrOnion = addrProxy;
+            }
+        } else {
+            addrOnion = CService(LookupNumeric(gArgs.GetArg("-tor", "").c_str(), 9050));
+        }
+
+        if (!addrOnion.IsValid()) {
+            return InitError(strprintf(_("Invalid -tor address: '%s'"), gArgs.GetArg("-tor", gArgs.GetArg("-proxy", ""))));
+        }
         SetProxy(NET_TOR, addrOnion);
         SetReachable(NET_TOR, true);
     }
@@ -1147,10 +1204,11 @@ bool AppInit2(ThreadHandlerPtr threads)
     {
         for (auto const& strAddr : gArgs.GetArgs("-externalip"))
         {
-            CService addrLocal(strAddr, GetListenPort(), fNameLookup);
-            if (!addrLocal.IsValid())
+            CService addrLocal;
+            if (Lookup(strAddr.c_str(), addrLocal, GetListenPort(), fNameLookup) && addrLocal.IsValid())
+                AddLocal(addrLocal, LOCAL_MANUAL);
+            else
                 return InitError(strprintf(_("Cannot resolve -externalip address: '%s'"), strAddr));
-            AddLocal(CService(strAddr, GetListenPort(), fNameLookup), LOCAL_MANUAL);
         }
     }
 
@@ -1192,7 +1250,7 @@ bool AppInit2(ThreadHandlerPtr threads)
     std::vector<std::pair<fs::path, uintmax_t>> block_data_files_to_load;
 
     // If -reindex argument passed at startup, then remove existing txleveldb and accrual directories and renaming the
-    // exising block data files from blk*.dat to blk*.dat.orig to prepare for reloading index from block data files.
+    // existing block data files from blk*.dat to blk*.dat.orig to prepare for reloading index from block data files.
     // This is the first half of reindex. The second half is below in the import blocks section.
     if (gArgs.GetBoolArg("-reindex")) {
         uiInterface.InitMessage(_("Resetting block chain index to prepare for reindexing..."));
@@ -1204,7 +1262,7 @@ bool AppInit2(ThreadHandlerPtr threads)
 
     uiInterface.InitMessage(_("Loading block index..."));
     LogPrintf("Loading block index...");
-    if (!LoadBlockIndex())
+    if (!LoadBlockIndex() && !fRequestShutdown)
         return InitError(_("Error loading blkindex.dat"));
 
     // as LoadBlockIndex can take several minutes, it's possible the user
@@ -1275,27 +1333,18 @@ bool AppInit2(ThreadHandlerPtr threads)
             strErrors << _("Error loading wallet.dat") << "\n";
     }
 
-    if (gArgs.GetBoolArg("-upgradewallet", fFirstRun))
-    {
-        int nMaxVersion = gArgs.GetArg("-upgradewallet", 0);
-        if (nMaxVersion == 0) // the -upgradewallet without argument case
-        {
-            LogPrintf("Performing wallet upgrade to %i", FEATURE_LATEST);
-            nMaxVersion = CLIENT_VERSION;
-            pwalletMain->SetMinVersion(FEATURE_LATEST); // permanently upgrade the wallet immediately
-        }
-        else
-            LogPrintf("Allowing wallet upgrade up to %i", nMaxVersion);
-        if (nMaxVersion < pwalletMain->GetVersion())
-            strErrors << _("Cannot downgrade wallet") << "\n";
-        pwalletMain->SetMaxVersion(nMaxVersion);
-    }
-
     if (fFirstRun)
     {
         // So Clang doesn't complain, even though we are really essentially single-threaded here.
         LOCK(pwalletMain->cs_wallet);
 
+        pwalletMain->SetMinVersion(wallet::FEATURE_LATEST);
+
+        // generate a new master key
+        CPubKey masterPubKey = pwalletMain->GenerateNewHDMasterKey();
+        if (!pwalletMain->SetHDMasterKey(masterPubKey))
+            throw std::runtime_error(std::string(__func__) + ": Storing master key failed");
+
         // Create new keyUser and set as default key
         CPubKey newDefaultKey;
         if (pwalletMain->GetKeyFromPool(newDefaultKey, false)) {
@@ -1329,16 +1378,59 @@ bool AppInit2(ThreadHandlerPtr threads)
     RegisterWallet(pwalletMain);
 
     CBlockIndex *pindexRescan = pindexBest;
+    bool mrc_request_correction_scan_complete = false;
+
     if (gArgs.GetBoolArg("-rescan"))
         pindexRescan = pindexGenesisBlock;
     else
     {
         CWalletDB walletdb(walletFileName.string());
+
         CBlockLocator locator;
-        if (walletdb.ReadBestBlock(locator))
+        if (walletdb.ReadBestBlock(locator)) {
             pindexRescan = locator.GetBlockIndex();
+        }
+
+        walletdb.ReadAttribute("mrc_request_correction_scan_complete", mrc_request_correction_scan_complete);
     }
-    if (pindexBest != pindexRescan && pindexBest && pindexRescan && pindexBest->nHeight > pindexRescan->nHeight)
+
+    // If rescan is NOT specified and mrc_request_correction_scan_complete is false and the wallet best height
+    // is greater than the V12 height, where MRC requests became possible, then perform a correction rescan for
+    // MRC requests from the BlockV12Height block to the wallet best height - 1. From the wallet best height to
+    // the block chain height will be handled by the normal rescan block below.
+    // -rescanmrcrequests can be specified as a startup parameter regardless of the state of the
+    // mrc_request_correction_scan_complete flag.
+    if (!gArgs.GetBoolArg("-rescan")
+            && (!mrc_request_correction_scan_complete || gArgs.GetBoolArg("-rescanmrcrequests"))
+            && pindexRescan->nHeight > Params().GetConsensus().BlockV12Height) {
+        CBlockIndex *pindexMRCRequestRescan = GRC::BlockFinder::FindByHeight(Params().GetConsensus().BlockV12Height);
+        uiInterface.InitMessage(_("Rescanning for MRC requests..."));
+        LogPrintf("INFO: %s: Rescanning from block height %i to %i for missing MRC request transactions",
+                 __func__, pindexMRCRequestRescan->nHeight, pindexRescan->nHeight - 1);
+
+        g_timer.GetTimes("mrc request correction scan start", "init");
+
+        int mrc_requests_added = 0;
+
+        pwalletMain->ScanForMRCRequests(pindexMRCRequestRescan, pindexRescan, true);
+
+        LogPrintf("INFO: %u: %i missing MRC request transactions added to wallet.",
+                  __func__, mrc_requests_added);
+
+        g_timer.GetTimes("mrc request correction scan complete", "init");
+
+        CWalletDB walletdb(walletFileName.string());
+        mrc_request_correction_scan_complete = true;
+        if (!walletdb.WriteAttribute("mrc_request_correction_scan_complete", mrc_request_correction_scan_complete)) {
+            error("%s: Unable to update mrc request correction scan attribute in wallet db.", __func__);
+        }
+    }
+
+    // If -rescan was not requested, but the wallet height is less than the block database height, then we
+    // must rescan from the wallet height to the block database height anyway to catch the wallet up. If rescan
+    // was requested, then this starts from genesis. If the pindexRescan->nHeight (i.e. wallet best height was
+    // less than or equal to the BlockV12Height, then the MRC request rescan above did not occur.
+    if (pindexBest && pindexRescan && pindexBest != pindexRescan && pindexBest->nHeight > pindexRescan->nHeight)
     {
         uiInterface.InitMessage(_("Rescanning..."));
         LogPrintf("Rescanning last %i blocks (from block %i)...", pindexBest->nHeight - pindexRescan->nHeight, pindexRescan->nHeight);
@@ -1470,7 +1562,7 @@ bool AppInit2(ThreadHandlerPtr threads)
     if (!threads->createThread(StartNode, nullptr, "Start Thread"))
         InitError(_("Error: could not start node"));
 
-    if (fServer) StartRPCThreads();
+    if (gArgs.GetBoolArg("-server", false)) StartRPCThreads();
 
     // ********************************************************* Step 13: finished
 
@@ -1502,6 +1594,10 @@ bool AppInit2(ThreadHandlerPtr threads)
 
     GRC::ScheduleBackgroundJobs(scheduler);
 
+    #if HAVE_SYSTEM
+        StartupNotify(gArgs);
+    #endif
+
     uiInterface.InitMessage(_("Done loading"));
     g_timer.GetTimes("Done loading", "init");
 
