@@ -8,12 +8,13 @@
 #define BITCOIN_MINER_H
 
 #include "main.h"
+#include "gridcoin/sidestake.h"
 
 
 class CWallet;
 class CWalletTx;
 
-typedef std::vector< std::pair<std::string, double> > SideStakeAlloc;
+typedef std::vector<GRC::SideStake_ptr> SideStakeAlloc;
 
 extern unsigned int nMinerSleep;
 
@@ -22,9 +23,19 @@ extern unsigned int nMinerSleep;
 // It will be converted to Halfords in GetNumberOfStakeOutputs by multiplying by COIN.
 static const int64_t MIN_STAKE_SPLIT_VALUE_GRC = 800;
 
-void SplitCoinStakeOutput(CBlock &blocknew, int64_t &nReward, bool &fEnableStakeSplit, bool &fEnableSideStaking, SideStakeAlloc &vSideStakeAlloc, double &dEfficiency);
+void SplitCoinStakeOutput(CBlock &blocknew, int64_t &nReward, bool &fEnableStakeSplit, bool &fEnableSideStaking,
+                          SideStakeAlloc &vSideStakeAlloc, double &dEfficiency);
 unsigned int GetNumberOfStakeOutputs(int64_t &nValue, int64_t &nMinStakeSplitValue, double &dEfficiency);
-SideStakeAlloc GetSideStakingStatusAndAlloc();
 bool GetStakeSplitStatusAndParams(int64_t& nMinStakeSplitValue, double& dEfficiency, int64_t& nDesiredStakeOutputValue);
 
+bool CreateMRCRewards(CBlock &blocknew,
+                      std::map<GRC::Cpid, std::pair<uint256, GRC::MRC>>& mrc_map,
+                      std::map<GRC::Cpid, uint256>& mrc_tx_map,
+                      CAmount& reward,
+                      uint32_t& claim_contract_version,
+                      GRC::Claim& claim,
+                      CWallet* pwallet) EXCLUSIVE_LOCKS_REQUIRED(cs_main);
+bool CreateRestOfTheBlock(CBlock &block, CBlockIndex* pindexPrev, std::map<GRC::Cpid, std::pair<uint256, GRC::MRC>>& mrc_map);
+bool CreateGridcoinReward(CBlock &blocknew, CBlockIndex* pindexPrev, int64_t &nReward, GRC::Claim& claim) EXCLUSIVE_LOCKS_REQUIRED(cs_main);
+
 #endif // BITCOIN_MINER_H
