@@ -64,7 +64,7 @@ CCriticalSection cs_mapLocalHost;
 std::map<CNetAddr, LocalServiceInfo> mapLocalHost;
 static bool vfLimited[NET_MAX] GUARDED_BY(cs_mapLocalHost) = {};
 static CNode* pnodeLocalHost = nullptr;
-CAddress addrSeenByPeer(CService("0.0.0.0", 0), nLocalServices);
+CAddress addrSeenByPeer(LookupNumeric("0.0.0.0", 0), nLocalServices);
 uint64_t nLocalHostNonce = 0;
 
 
@@ -141,7 +141,7 @@ void CNode::PushGetBlocks(CBlockIndex* pindexBegin, uint256 hashEnd)
         g_getblocks_locator = CBlockLocator(pindexBegin);
     }
 
-    PushMessage("getblocks", g_getblocks_locator, hashEnd);
+    PushMessage(NetMsgType::GETBLOCKS, g_getblocks_locator, hashEnd);
 }
 
 // find 'best' local address for a particular peer
@@ -212,7 +212,7 @@ void AdvertiseLocal(CNode *pnode)
         // If discovery is enabled, sometimes give our peer the address it
         // tells us that it sees us as in case it has a better idea of our
         // address than we do.
-        const int randomNumber = GetRandInt((GetnScore(addrLocal) > LOCAL_MANUAL) ? 3+1 : 1+1);
+        const int randomNumber = GetRand<int>((GetnScore(addrLocal) > LOCAL_MANUAL) ? 3+1 : 1+1);
         if (IsPeerAddrLocalGood(pnode) && (!addrLocal.IsRoutable() ||
              randomNumber == 0))
         {
@@ -484,15 +484,15 @@ bool CNode::DisconnectNode(NodeId id)
 void CNode::PushVersion()
 {
     int64_t nTime = GetAdjustedTime();
-    CAddress addrYou = (addr.IsRoutable() && !IsProxy(addr) ? addr : CAddress(CService("0.0.0.0",0)));
-    CAddress addrMe = GetLocalAddress(&addr);
-    GetRandBytes((unsigned char*)&nLocalHostNonce, sizeof(nLocalHostNonce));
+    CAddress addrYou = (addr.IsRoutable() && !IsProxy(addr) ? addr : CAddress(LookupNumeric("0.0.0.0", 0)));
+    CAddress addrMe = CAddress(CService(), nLocalServices);
+    GetRandBytes({(unsigned char*)&nLocalHostNonce, sizeof(nLocalHostNonce)});
     LogPrint(BCLog::LogFlags::NET, "send version message: version %d, blocks=%d, us=%s, them=%s, peer=%s",
         PROTOCOL_VERSION, nBestHeight, addrMe.ToString(), addrYou.ToString(), addr.ToString());
 
     //TODO: change `PushMessage()` to use ServiceFlags so we don't need to cast nLocalServices
     PushMessage(
-        "aries",
+        NetMsgType::ARIES,
         PROTOCOL_VERSION,
         (uint64_t)nLocalServices,
         nTime,
@@ -704,13 +704,13 @@ int CNetMessage::readData(const char *pch, unsigned int nBytes)
 // requires LOCK(cs_vSend)
 void SocketSendData(CNode *pnode)
 {
-    std::deque<CSerializeData>::iterator it = pnode->vSendMsg.begin();
+    std::deque<SerializeData>::iterator it = pnode->vSendMsg.begin();
 
     while (it != pnode->vSendMsg.end())
     {
-        const CSerializeData &data = *it;
+        const SerializeData &data = *it;
         assert(data.size() > pnode->nSendOffset);
-        int nBytes = send(pnode->hSocket, &data[pnode->nSendOffset], data.size() - pnode->nSendOffset, MSG_NOSIGNAL | MSG_DONTWAIT);
+        int nBytes = send(pnode->hSocket, (const char*)&data[pnode->nSendOffset], data.size() - pnode->nSendOffset, MSG_NOSIGNAL | MSG_DONTWAIT);
         if (nBytes > 0) {
             pnode->nLastSend = GetAdjustedTime();
             pnode->nSendBytes += nBytes;
@@ -1155,6 +1155,9 @@ void ThreadMapPort2(void* parg)
     const char* minissdpdpath = nullptr;
     struct UPNPDev* devlist = nullptr;
     char lanaddr[64];
+#if MINIUPNPC_API_VERSION >= 18
+    char wanaddr[64];
+#endif
 
     int error = 0;
 #if MINIUPNPC_API_VERSION < 14
@@ -1167,10 +1170,17 @@ void ThreadMapPort2(void* parg)
     struct IGDdatas data;
     int r;
 
+#if MINIUPNPC_API_VERSION < 18
     r = UPNP_GetValidIGD(devlist, &urls, &data, lanaddr, sizeof(lanaddr));
+#else
+    r = UPNP_GetValidIGD(devlist, &urls, &data, lanaddr, sizeof(lanaddr), wanaddr, sizeof(wanaddr));
+#endif
     if (r == 1)
     {
         if (fDiscover) {
+            // Note that the below is technically duplicative for API version > 18, since the wanaddr is filled out
+            // by UPNP_GetValidIGD in the internal call to UPNP_GetExternalIPAddress for API version > 18. However,
+            // it is not harmful to leave the additional separate call here.
             char externalIPAddress[40];
             r = UPNP_GetExternalIPAddress(urls.controlURL, data.first.servicetype, externalIPAddress);
             if(r != UPNPCOMMAND_SUCCESS)
@@ -1179,8 +1189,11 @@ void ThreadMapPort2(void* parg)
             {
                 if(externalIPAddress[0])
                 {
-                    LogPrintf("UPnP: ExternalIPAddress = %s", externalIPAddress);
-                    AddLocal(CNetAddr(externalIPAddress), LOCAL_UPNP);
+                    CNetAddr resolved;
+                    if(LookupHost(externalIPAddress, resolved, false)) {
+                        LogPrintf("UPnP: ExternalIPAddress = %s\n", resolved.ToString().c_str());
+                        AddLocal(resolved, LOCAL_UPNP);
+                    }
                 }
                 else
                     LogPrintf("UPnP: GetExternalIPAddress not successful.");
@@ -1268,6 +1281,7 @@ static const char *strDNSSeed[][2] = {
     {"ec2-3-81-39-58.compute-1.amazonaws.com", "ec2-3-81-39-58.compute-1.amazonaws.com"},
     {"node.grcpool.com", "node.grcpool.com"},
     {"seeds.gridcoin.ifoggz-network.xyz", "seeds.gridcoin.ifoggz-network.xyz"},
+    {"node.gridcoin.network", "node.gridcoin.network"},
     {"", ""},
 };
 
@@ -1310,11 +1324,11 @@ void ThreadDNSAddressSeed2(void* parg)
             if (HaveNameProxy()) {
                 AddOneShot(seed[1]);
             } else {
-                vector<CNetAddr> vaddr;
+                vector<CNetAddr> vIPs;
                 vector<CAddress> vAdd;
-                if (LookupHost(seed[1], vaddr))
+                if (LookupHost(seed[1], vIPs, 0, true))
                 {
-                    for (auto const& ip : vaddr)
+                    for (auto const& ip : vIPs)
                     {
                         int nOneDay = 24*3600;
                         CAddress addr = CAddress(CService(ip, GetDefaultPort()));
@@ -1323,7 +1337,15 @@ void ThreadDNSAddressSeed2(void* parg)
                         found++;
                     }
                 }
-                addrman.Add(vAdd, CNetAddr(seed[0], true));
+                // TODO: The seed name resolve may fail, yielding an IP of [::], which results in
+                // addrman assigning the same source to results from different seeds.
+                // This should switch to a hard-coded stable dummy IP for each seed name, so that the
+                // resolve is not required at all.
+                if (!vIPs.empty()) {
+                    CService seedSource;
+                    Lookup(seed[0], seedSource, 0, true);
+                    addrman.Add(vAdd, seedSource);
+                }
             }
         }
     }
@@ -1331,12 +1353,6 @@ void ThreadDNSAddressSeed2(void* parg)
     LogPrint(BCLog::LogFlags::NET, "%d addresses found from DNS seeds", found);
 }
 
-
-
-
-
-
-
 unsigned int pnSeed[] =
 {
     0xdf4bd379, 0x7934d29b, 0x26bc02ad, 0x7ab743ad, 0x0ab3a7bc,
@@ -1526,7 +1542,7 @@ void ThreadOpenConnections2(void* parg)
             return;
 
         // Add seed nodes
-        if (addrman.size()==0 && (GetAdjustedTime() - nStart > 60) && !fTestNet)
+        if (addrman.size() == 0 && (GetAdjustedTime() - nStart > 60) && !fTestNet)
         {
             std::vector<CAddress> vAdd;
             for (const auto& seed : pnSeed)
@@ -1542,7 +1558,9 @@ void ThreadOpenConnections2(void* parg)
                 addr.nTime = GetAdjustedTime() - GetRand(nOneWeek) - nOneWeek;
                 vAdd.push_back(addr);
             }
-            addrman.Add(vAdd, CNetAddr("127.0.0.1"));
+            CNetAddr local;
+            LookupHost("127.0.0.1", local, false);
+            addrman.Add(vAdd, local);
         }
 
         //
@@ -1552,14 +1570,12 @@ void ThreadOpenConnections2(void* parg)
 
         // Only connect out to one peer per network group (/16 for IPv4).
         // Do this here so we don't have to critsect vNodes inside mapAddresses critsect.
-        int nOutbound = 0;
         set<vector<unsigned char> > setConnected;
         {
             LOCK(cs_vNodes);
             for (auto const& pnode : vNodes) {
                 if (!pnode->fInbound) {
                     setConnected.insert(pnode->addr.GetGroup());
-                    nOutbound++;
                 }
             }
         }
@@ -1569,8 +1585,7 @@ void ThreadOpenConnections2(void* parg)
         int nTries = 0;
         while (true)
         {
-            // use an nUnkBias between 10 (no outgoing connections) and 90 (8 outgoing connections)
-            CAddress addr = addrman.Select(10 + min(nOutbound,8)*10);
+            CAddress addr = addrman.Select();
 
             // if we selected an invalid address, restart
             if (!addr.IsValid() || setConnected.count(addr.GetGroup()) || IsLocal(addr))
@@ -1952,7 +1967,7 @@ void static Discover()
     if (gethostname(pszHostName, sizeof(pszHostName)) != SOCKET_ERROR)
     {
         vector<CNetAddr> vaddr;
-        if (LookupHost(pszHostName, vaddr))
+        if (LookupHost(pszHostName, vaddr, 0, true))
         {
             for (auto const& addr : vaddr)
             {
@@ -2010,7 +2025,7 @@ void StartNode(void* parg)
               nMaxOutbound, max_connections);
 
     if (pnodeLocalHost == nullptr)
-        pnodeLocalHost = new CNode(INVALID_SOCKET, CAddress(CService("127.0.0.1", 0), nLocalServices));
+        pnodeLocalHost = new CNode(INVALID_SOCKET, CAddress(LookupNumeric("127.0.0.1", 0), nLocalServices));
 
     Discover();
 
