@@ -12,6 +12,7 @@
 #include "clientmodel.h"
 #include "walletmodel.h"
 #include "researcher/researchermodel.h"
+#include "mrcmodel.h"
 #include "voting/votingmodel.h"
 #include "optionsmodel.h"
 #include "guiutil.h"
@@ -31,6 +32,8 @@
 #include "validation.h"
 #include "decoration.h"
 
+#include <stdexcept>
+
 #include <QMessageBox>
 #include <QGridLayout>
 #include <QDebug>
@@ -41,10 +44,14 @@
 #include <QLibraryInfo>
 #include <QProcess>
 
+// This eliminates the linter false positive on double include of QtPlugin
+#if (defined(BITCOIN_NEED_QT_PLUGINS) && !defined(_BITCOIN_QT_PLUGINS_INCLUDED)) || defined(QT_STATICPLUGIN)
+#include <QtPlugin>
+#endif
+
 #if defined(BITCOIN_NEED_QT_PLUGINS) && !defined(_BITCOIN_QT_PLUGINS_INCLUDED)
 #define _BITCOIN_QT_PLUGINS_INCLUDED
 #define __INSURE__
-#include <QtPlugin>
 Q_IMPORT_PLUGIN(qcncodecs)
 Q_IMPORT_PLUGIN(qjpcodecs)
 Q_IMPORT_PLUGIN(qtwcodecs)
@@ -53,7 +60,6 @@ Q_IMPORT_PLUGIN(qtaccessiblewidgets)
 #endif
 
 #if defined(QT_STATICPLUGIN)
-#include <QtPlugin>
 #if defined(QT_QPA_PLATFORM_XCB)
 Q_IMPORT_PLUGIN(QXcbIntegrationPlugin);
 #elif defined(QT_QPA_PLATFORM_WINDOWS)
@@ -141,7 +147,7 @@ static bool ThreadSafeAskFee(int64_t nFeeRequired, const std::string& strCaption
         nMinFee = GetBaseFee(txDummy, GMF_SEND);
     }
 
-    if(nFeeRequired < nMinFee || nFeeRequired <= nTransactionFee || fDaemon)
+    if (nFeeRequired < nMinFee || nFeeRequired <= nTransactionFee)
         return true;
     bool payFee = false;
 
@@ -186,16 +192,16 @@ static void InitMessage(const std::string &message)
     }
 }
 
-static void UpdateMessageBox(const std::string& version, const std::string& message)
+static void UpdateMessageBox(const std::string& version, const int& update_version, const std::string& message)
 {
     std::string caption = _("Gridcoin Update Available");
 
     if (guiref)
     {
-        std::string guiaddition = version + _("Click \"Show Details\" to view changes in latest update.");
         QMetaObject::invokeMethod(guiref, "update", Qt::QueuedConnection,
                                    Q_ARG(QString, QString::fromStdString(caption)),
-                                   Q_ARG(QString, QString::fromStdString(guiaddition)),
+                                   Q_ARG(QString, QString::fromStdString(version)),
+                                   Q_ARG(int, update_version),
                                    Q_ARG(QString, QString::fromStdString(message)));
     }
 
@@ -660,11 +666,13 @@ int StartGridcoinQt(int argc, char *argv[], QApplication& app, OptionsModel& opt
                 ClientModel clientModel(&optionsModel);
                 WalletModel walletModel(pwalletMain, &optionsModel);
                 ResearcherModel researcherModel;
+                MRCModel mrcModel(&walletModel, &clientModel, &researcherModel);
                 VotingModel votingModel(clientModel, optionsModel, walletModel);
 
                 window.setResearcherModel(&researcherModel);
                 window.setClientModel(&clientModel);
                 window.setWalletModel(&walletModel);
+                window.setMRCModel(&mrcModel);
                 window.setVotingModel(&votingModel);
 
                 // If -min option passed, start window minimized.
