@@ -1,10 +1,6 @@
-<TS language="la" version="2.1">
+<TS language="la" version="2.0">
 <context>
     <name>AddressBookPage</name>
-    <message>
-        <source>Double-click to edit address or label</source>
-        <translation>Dupliciter-clicca ut inscriptionem vel titulum mutes</translation>
-    </message>
     <message>
         <source>Create a new address</source>
         <translation>Crea novam inscriptionem</translation>
@@ -29,10 +25,6 @@
         <source>&amp;Edit</source>
         <translation>&amp;Muta</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Comma Separata Plica (*.csv)</translation>
-    </message>
     </context>
 <context>
     <name>AddressTableModel</name>
@@ -79,14 +71,6 @@
         <source>Unlock wallet</source>
         <translation>Resera cassidile</translation>
     </message>
-    <message>
-        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
-        <translation>Huic operationi necesse est tessera cassidili tuo ut cassidile decifret.</translation>
-    </message>
-    <message>
-        <source>Decrypt wallet</source>
-        <translation>Decifra cassidile</translation>
-    </message>
     <message>
         <source>Change passphrase</source>
         <translation>Muta tesseram</translation>
@@ -131,10 +115,6 @@
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation>Tessera inserta pro cassidilis decifrando prava erat.</translation>
     </message>
-    <message>
-        <source>Wallet decryption failed</source>
-        <translation>Cassidile decifrare abortum est.</translation>
-    </message>
     <message>
         <source>Wallet passphrase was successfully changed.</source>
         <translation>Tessera cassidilis successa est in mutando.</translation>
@@ -147,8 +127,8 @@
 <context>
     <name>BitcoinGUI</name>
     <message>
-        <source>Sign &amp;message...</source>
-        <translation>Signa &amp;nuntium...</translation>
+        <source>Wallet</source>
+        <translation>Cassidile</translation>
     </message>
     <message>
         <source>&amp;Overview</source>
@@ -158,6 +138,14 @@
         <source>Show general overview of wallet</source>
         <translation>Monstra generale summarium cassidilis</translation>
     </message>
+    <message>
+        <source>&amp;Send</source>
+        <translation>&amp;Mitte</translation>
+    </message>
+    <message>
+        <source>&amp;Receive</source>
+        <translation>&amp;Accipe</translation>
+    </message>
     <message>
         <source>Browse transaction history</source>
         <translation>Inspicio historiam transactionum</translation>
@@ -174,6 +162,10 @@
         <source>&amp;Options...</source>
         <translation>&amp;Optiones</translation>
     </message>
+    <message>
+        <source>&amp;Show / Hide</source>
+        <translation>&amp;Monstra/Occulta</translation>
+    </message>
     <message>
         <source>&amp;Encrypt Wallet...</source>
         <translation>&amp;Cifra Cassidile...</translation>
@@ -187,32 +179,20 @@
         <translation>Muta tesseram utam pro cassidilis cifrando</translation>
     </message>
     <message>
-        <source>&amp;Debug window</source>
-        <translation>Fenestra &amp;Debug</translation>
-    </message>
-    <message>
-        <source>Open debugging and diagnostic console</source>
-        <translation>Aperi terminalem debug et diagnosticalem</translation>
+        <source>Sign &amp;message...</source>
+        <translation>Signa &amp;nuntium...</translation>
     </message>
     <message>
         <source>&amp;Verify message...</source>
         <translation>&amp;Verifica nuntium...</translation>
     </message>
     <message>
-        <source>Wallet</source>
-        <translation>Cassidile</translation>
+        <source>&amp;Debug window</source>
+        <translation>Fenestra &amp;Debug</translation>
     </message>
     <message>
-        <source>&amp;Send</source>
-        <translation>&amp;Mitte</translation>
-    </message>
-    <message>
-        <source>&amp;Receive</source>
-        <translation>&amp;Accipe</translation>
-    </message>
-    <message>
-        <source>&amp;Show / Hide</source>
-        <translation>&amp;Monstra/Occulta</translation>
+        <source>Open debugging and diagnostic console</source>
+        <translation>Aperi terminalem debug et diagnosticalem</translation>
     </message>
     <message>
         <source>&amp;File</source>
@@ -226,34 +206,46 @@
         <source>&amp;Help</source>
         <translation>&amp;Auxilium</translation>
     </message>
+    <message numerus="yes">
+        <source>%n active connection(s) to the Gridcoin network</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
     <message numerus="yes">
         <source>Processed %n block(s) of transaction history.</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n second(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minute(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n hour(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n day(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Up to date</source>
         <translation>Recentissimo</translation>
     </message>
-    <message numerus="yes">
-        <source>%n second(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n minute(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n active connection(s) to the Gridcoin network</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
     <message>
         <source>Catching up...</source>
         <translation>Persequens...</translation>
@@ -364,6 +356,27 @@
         <translation>Generare novam clavem abortum est.</translation>
     </message>
 </context>
+<context>
+    <name>Intro</name>
+    <message numerus="yes">
+        <source>%n GB of free space available</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>(of %n GB needed)</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>(%n GB needed for full chain)</source>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
+    </message>
+</context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -390,14 +403,6 @@
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Porta vicarii (e.g. 9050)</translation>
     </message>
-    <message>
-        <source>SOCKS &amp;Version:</source>
-        <translation>SOCKS &amp;Versio:</translation>
-    </message>
-    <message>
-        <source>SOCKS version of the proxy (e.g. 5)</source>
-        <translation>SOCKS versio vicarii (e.g. 5)</translation>
-    </message>
     <message>
         <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
         <translation>Minifac potius quam exire applicatione quando fenestra clausa sit.  Si haec optio activa est, applicatio clausa erit tantum postquam selegeris Exi in menu.</translation>
@@ -466,27 +471,39 @@
     <name>QObject</name>
     <message numerus="yes">
         <source>%n second(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n minute(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n hour(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n day(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n week(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n year(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     </context>
 <context>
@@ -535,18 +552,6 @@
         <source>Clear console</source>
         <translation>Vacuefac terminale</translation>
     </message>
-    <message>
-        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
-        <translation>Scribe &lt;b&gt;help&lt;/b&gt; pro summario possibilium mandatorum.</translation>
-    </message>
-    <message>
-        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
-        <translation>Utere sagittis sursum deorsumque ut per historiam naviges, et &lt;b&gt;Ctrl+L&lt;/b&gt; ut scrinium vacuefacias.</translation>
-    </message>
-    <message>
-        <source>Build date</source>
-        <translation>Dies aedificandi</translation>
-    </message>
     <message>
         <source>Estimated total blocks</source>
         <translation>Aestimatus totalis numerus frustorum</translation>
@@ -555,7 +560,15 @@
         <source>Client name</source>
         <translation>Nomen clientis</translation>
     </message>
-</context>
+    <message>
+        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
+        <translation>Utere sagittis sursum deorsumque ut per historiam naviges, et &lt;b&gt;Ctrl+L&lt;/b&gt; ut scrinium vacuefacias.</translation>
+    </message>
+    <message>
+        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
+        <translation>Scribe &lt;b&gt;help&lt;/b&gt; pro summario possibilium mandatorum.</translation>
+    </message>
+    </context>
 <context>
     <name>SendCoinsDialog</name>
     <message>
@@ -622,7 +635,7 @@
         <source>(no label)</source>
         <translation>(nullus titulus)</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>SendCoinsEntry</name>
     <message>
@@ -633,6 +646,10 @@
         <source>Pay &amp;To:</source>
         <translation>Pensa &amp;Ad:</translation>
     </message>
+    <message>
+        <source>Message:</source>
+        <translation>Nuntius:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;Titulus:</translation>
@@ -753,7 +770,9 @@
     <name>TransactionDesc</name>
     <message numerus="yes">
         <source>Open for %n more block(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Open until %1</source>
@@ -777,7 +796,9 @@
     </message>
     <message numerus="yes">
         <source>, broadcast through %n node(s)</source>
-        <translation><numerusform>, disseminatum per %n nodo</numerusform><numerusform>, disseminata per %n nodis</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Date</source>
@@ -813,7 +834,9 @@
     </message>
     <message numerus="yes">
         <source>matures in %n more block(s)</source>
-        <translation><numerusform>maturum erit in %n plure frusto</numerusform><numerusform>maturum erit in %n pluribus frustis</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>not accepted</source>
@@ -883,7 +906,9 @@
     </message>
     <message numerus="yes">
         <source>Open for %n more block(s)</source>
-        <translation><numerusform>Aperi pro %n plure frusto</numerusform><numerusform>Aperi pro %n pluribus frustis</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Open until %1</source>
@@ -1008,10 +1033,6 @@
         <source>Show transaction details</source>
         <translation>Monstra particularia transactionis</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Comma Separata Plica (*.csv)</translation>
-    </message>
     <message>
         <source>Confirmed</source>
         <translation>Confirmatum</translation>
@@ -1103,10 +1124,6 @@ Si plica non existat, crea eam cum permissionibus ut solus eius dominus eam lege
         <source>wallet.dat corrupt, salvage failed</source>
         <translation>wallet.dat corrupta, salvare abortum est</translation>
     </message>
-    <message>
-        <source>Unknown -socks proxy version requested: %i</source>
-        <translation>Ignota -socks vicarii versio postulata: %i</translation>
-    </message>
     <message>
         <source>Invalid -proxy address: '%s'</source>
         <translation>Inscriptio -proxy non valida: '%s'</translation>
@@ -1155,10 +1172,6 @@ Si plica non existat, crea eam cum permissionibus ut solus eius dominus eam lege
         <source>Loading wallet...</source>
         <translation>Legens cassidile...</translation>
     </message>
-    <message>
-        <source>Cannot downgrade wallet</source>
-        <translation>Non posse cassidile regredi</translation>
-    </message>
     <message>
         <source>Cannot write default address</source>
         <translation>Non posse scribere praedefinitam inscriptionem</translation>
