@@ -1,4 +1,4 @@
-<TS language="nb" version="2.1">
+<TS language="nb" version="2.0">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -12,10 +12,6 @@
     </context>
 <context>
     <name>AddressBookPage</name>
-    <message>
-        <source>Double-click to edit address or label</source>
-        <translation>Dobbeltklikk for å redigere adresse eller merkelapp</translation>
-    </message>
     <message>
         <source>Create a new address</source>
         <translation>Opprett en ny addresse</translation>
@@ -76,10 +72,6 @@
         <source>&amp;Edit</source>
         <translation>&amp;Rediger</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Kommaseparert fil (*.csv)</translation>
-    </message>
     <message>
         <source>Export Address Book Data</source>
         <translation>Eksporter Adressebok</translation>
@@ -142,14 +134,6 @@
         <source>Unlock wallet</source>
         <translation>Lås opp lommebok</translation>
     </message>
-    <message>
-        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
-        <translation>Denne operasjonen krever adgangsfrasen til lommeboken for å dekryptere den.</translation>
-    </message>
-    <message>
-        <source>Decrypt wallet</source>
-        <translation>Dekrypter lommebok</translation>
-    </message>
     <message>
         <source>Change passphrase</source>
         <translation>Endre adgangsfrase</translation>
@@ -170,14 +154,14 @@
         <source>Are you sure you wish to encrypt your wallet?</source>
         <translation>Er du sikker på at du vil kryptere lommeboken?</translation>
     </message>
-    <message>
-        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
-        <translation>Gridcoin vil nå lukke applikasjonen for å fullføre krypteringsprosessen. Husk at en fullt kryptert lommebok ikke kan hindre myntene dine fra å bli stjålet hvis datamaskinen din blir infisert av skadevare.</translation>
-    </message>
     <message>
         <source>Wallet encrypted</source>
         <translation>Lommebok kryptert</translation>
     </message>
+    <message>
+        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
+        <translation>Gridcoin vil nå lukke applikasjonen for å fullføre krypteringsprosessen. Husk at en fullt kryptert lommebok ikke kan hindre myntene dine fra å bli stjålet hvis datamaskinen din blir infisert av skadevare.</translation>
+    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>VIKTIG: Tidligere sikkerhetskopier av din lommebok-fil, bør erstattes med den nylig genererte, krypterte filen, da de blir ugyldiggjort av sikkerhetshensyn så snart du begynner å bruke den nye krypterte lommeboken.</translation>
@@ -202,10 +186,6 @@
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation>Adgangsfrasen angitt for dekryptering av lommeboken var feil.</translation>
     </message>
-    <message>
-        <source>Wallet decryption failed</source>
-        <translation>Dekryptering av lommebok feilet</translation>
-    </message>
     <message>
         <source>Wallet passphrase was successfully changed.</source>
         <translation>Adgangsfrase for lommebok endret.</translation>
@@ -218,8 +198,8 @@
 <context>
     <name>BitcoinGUI</name>
     <message>
-        <source>Sign &amp;message...</source>
-        <translation>Signer &amp;melding...</translation>
+        <source>Wallet</source>
+        <translation>Lommebok</translation>
     </message>
     <message>
         <source>&amp;Overview</source>
@@ -230,89 +210,25 @@
         <translation>Vis generell oversikt over lommeboken</translation>
     </message>
     <message>
-        <source>&amp;History</source>
-        <translation>&amp;Historie</translation>
-    </message>
-    <message>
-        <source>Browse transaction history</source>
-        <translation>Vis transaksjonshistorikk</translation>
-    </message>
-    <message>
-        <source>E&amp;xit</source>
-        <translation>&amp;Avslutt</translation>
-    </message>
-    <message>
-        <source>Quit application</source>
-        <translation>Avslutt applikasjonen</translation>
-    </message>
-    <message>
-        <source>&amp;Options...</source>
-        <translation>&amp;Innstillinger...</translation>
-    </message>
-    <message>
-        <source>&amp;Encrypt Wallet...</source>
-        <translation>&amp;Krypter Lommebok...</translation>
-    </message>
-    <message>
-        <source>&amp;Change Passphrase...</source>
-        <translation>&amp;Endre Adgangsfrase...</translation>
-    </message>
-    <message>
-        <source>Change the passphrase used for wallet encryption</source>
-        <translation>Endre adgangsfrasen brukt for kryptering av lommebok</translation>
-    </message>
-    <message>
-        <source>&amp;Debug window</source>
-        <translation>&amp;Feilsøkingsvindu</translation>
-    </message>
-    <message>
-        <source>Open debugging and diagnostic console</source>
-        <translation>Åpne konsoll for feilsøk og diagnostikk</translation>
-    </message>
-    <message>
-        <source>&amp;Verify message...</source>
-        <translation>&amp;Verifiser melding...</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Lommebok</translation>
+        <source>Send coins to a Gridcoin address</source>
+        <translation>Send mynter til Gridcoin adresse</translation>
     </message>
     <message>
         <source>&amp;Receive</source>
         <translation>&amp;Motta</translation>
     </message>
-    <message>
-        <source>&amp;Show / Hide</source>
-        <translation>&amp;Vis / Skjul</translation>
-    </message>
-    <message>
-        <source>&amp;File</source>
-        <translation>&amp;Fil</translation>
-    </message>
-    <message>
-        <source>&amp;Settings</source>
-        <translation>&amp;Innstillinger</translation>
-    </message>
-    <message>
-        <source>&amp;Help</source>
-        <translation>&amp;Hjelp</translation>
-    </message>
-    <message numerus="yes">
-        <source>Processed %n block(s) of transaction history.</source>
-        <translation><numerusform>Lastet %n blokk med transaksjonshistorikk.</numerusform><numerusform>Lastet %n blokker med transaksjonshistorikk.</numerusform></translation>
-    </message>
-    <message>
-        <source>Up to date</source>
-        <translation>Oppdatert</translation>
-    </message>
-    <message>
-        <source>Send coins to a Gridcoin address</source>
-        <translation>Send mynter til Gridcoin adresse</translation>
-    </message>
     <message>
         <source>Show the list of addresses for receiving payments</source>
         <translation>Vis listen med adresser for å motta betalinger</translation>
     </message>
+    <message>
+        <source>&amp;History</source>
+        <translation>&amp;Historie</translation>
+    </message>
+    <message>
+        <source>Browse transaction history</source>
+        <translation>Vis transaksjonshistorikk</translation>
+    </message>
     <message>
         <source>&amp;Favorites</source>
         <translation>&amp;Favoritter</translation>
@@ -337,6 +253,14 @@
         <source>Gridcoin rewards distributed computing with BOINC</source>
         <translation>Gridcoin belønner distribuert databehandling gjennom BOINC</translation>
     </message>
+    <message>
+        <source>E&amp;xit</source>
+        <translation>&amp;Avslutt</translation>
+    </message>
+    <message>
+        <source>Quit application</source>
+        <translation>Avslutt applikasjonen</translation>
+    </message>
     <message>
         <source>&amp;About Gridcoin</source>
         <translation>&amp;Om Gridcoin</translation>
@@ -345,6 +269,160 @@
         <source>Show information about Gridcoin</source>
         <translation>Vis informasjon om Gridcoin</translation>
     </message>
+    <message>
+        <source>&amp;Options...</source>
+        <translation>&amp;Innstillinger...</translation>
+    </message>
+    <message>
+        <source>&amp;Show / Hide</source>
+        <translation>&amp;Vis / Skjul</translation>
+    </message>
+    <message>
+        <source>&amp;Encrypt Wallet...</source>
+        <translation>&amp;Krypter Lommebok...</translation>
+    </message>
+    <message>
+        <source>&amp;Change Passphrase...</source>
+        <translation>&amp;Endre Adgangsfrase...</translation>
+    </message>
+    <message>
+        <source>Change the passphrase used for wallet encryption</source>
+        <translation>Endre adgangsfrasen brukt for kryptering av lommebok</translation>
+    </message>
+    <message>
+        <source>&amp;Unlock Wallet...</source>
+        <translation>&amp;Lås opp lommeboken</translation>
+    </message>
+    <message>
+        <source>Unlock wallet</source>
+        <translation>Lås opp lommebok</translation>
+    </message>
+    <message>
+        <source>&amp;Lock Wallet</source>
+        <translation>&amp;Lås Lommeboken</translation>
+    </message>
+    <message>
+        <source>Lock wallet</source>
+        <translation>Lås lommeboken</translation>
+    </message>
+    <message>
+        <source>Sign &amp;message...</source>
+        <translation>Signer &amp;melding...</translation>
+    </message>
+    <message>
+        <source>&amp;Verify message...</source>
+        <translation>&amp;Verifiser melding...</translation>
+    </message>
+    <message>
+        <source>&amp;Export...</source>
+        <translation>&amp;Eksporter...</translation>
+    </message>
+    <message>
+        <source>Export the data in the current tab to a file</source>
+        <translation>Eksporter dataene i nåværende fane til en fil</translation>
+    </message>
+    <message>
+        <source>&amp;Debug window</source>
+        <translation>&amp;Feilsøkingsvindu</translation>
+    </message>
+    <message>
+        <source>Open debugging and diagnostic console</source>
+        <translation>Åpne konsoll for feilsøk og diagnostikk</translation>
+    </message>
+    <message>
+        <source>&amp;File</source>
+        <translation>&amp;Fil</translation>
+    </message>
+    <message>
+        <source>&amp;Settings</source>
+        <translation>&amp;Innstillinger</translation>
+    </message>
+    <message>
+        <source>&amp;Help</source>
+        <translation>&amp;Hjelp</translation>
+    </message>
+    <message>
+        <source>[testnet]</source>
+        <translation>[testnett]</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n active connection(s) to the Gridcoin network</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Processed %n block(s) of transaction history.</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n second(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minute(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n hour(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n day(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message>
+        <source>Up to date</source>
+        <translation>Oppdatert</translation>
+    </message>
+    <message>
+        <source>Catching up...</source>
+        <translation>Laster ned...</translation>
+    </message>
+    <message>
+        <source>Sent transaction</source>
+        <translation>Sendt transaksjon</translation>
+    </message>
+    <message>
+        <source>Incoming transaction</source>
+        <translation>Innkommende transaksjon</translation>
+    </message>
+    <message>
+        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently %1 </source>
+        <translation>Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for tiden %1</translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;unlocked for staking only&lt;/b&gt;</source>
+        <translation>&lt;b&gt;låst opp for innsats(staking) &lt;/b&gt;</translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;fully unlocked&lt;/b&gt;</source>
+        <translation>&lt;b&gt;Helt låst opp&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
+        <translation>Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for tiden &lt;b&gt;låst&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <source>Backup Failed</source>
+        <translation>Backup Mislyktes</translation>
+    </message>
     <message>
         <source>none</source>
         <translation>Ingen</translation>
@@ -383,90 +461,6 @@ Prosjekt(er) ekskludert: %2.</translation>
         <source>Scraper: No convergence able to be achieved. Will retry in a few minutes.</source>
         <translation>Skraper: Kunne ikke oppå konvergens. Prøver igjen om noen minutter.</translation>
     </message>
-    <message numerus="yes">
-        <source>%n second(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n minute(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message>
-        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently %1 </source>
-        <translation>Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for tiden %1</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;unlocked for staking only&lt;/b&gt;</source>
-        <translation>&lt;b&gt;låst opp for innsats(staking) &lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;fully unlocked&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Helt låst opp&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>Encrypt or decrypt wallet</source>
-        <translation>Krypter eller dekrypter lommeboken</translation>
-    </message>
-    <message>
-        <source>&amp;Unlock Wallet...</source>
-        <translation>&amp;Lås opp lommeboken</translation>
-    </message>
-    <message>
-        <source>Unlock wallet</source>
-        <translation>Lås opp lommebok</translation>
-    </message>
-    <message>
-        <source>&amp;Lock Wallet</source>
-        <translation>&amp;Lås Lommeboken</translation>
-    </message>
-    <message>
-        <source>Lock wallet</source>
-        <translation>Lås lommeboken</translation>
-    </message>
-    <message>
-        <source>&amp;Export...</source>
-        <translation>&amp;Eksporter...</translation>
-    </message>
-    <message>
-        <source>Export the data in the current tab to a file</source>
-        <translation>Eksporter dataene i nåværende fane til en fil</translation>
-    </message>
-    <message>
-        <source>[testnet]</source>
-        <translation>[testnett]</translation>
-    </message>
-    <message numerus="yes">
-        <source>%n active connection(s) to the Gridcoin network</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
-    </message>
-    <message>
-        <source>Catching up...</source>
-        <translation>Laster ned...</translation>
-    </message>
-    <message>
-        <source>Backup Failed</source>
-        <translation>Backup Mislyktes</translation>
-    </message>
-    <message>
-        <source>Sent transaction</source>
-        <translation>Sendt transaksjon</translation>
-    </message>
-    <message>
-        <source>Incoming transaction</source>
-        <translation>Innkommende transaksjon</translation>
-    </message>
-    <message>
-        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
-        <translation>Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for tiden &lt;b&gt;låst&lt;/b&gt;</translation>
-    </message>
     </context>
 <context>
     <name>ClientModel</name>
@@ -489,10 +483,6 @@ Prosjekt(er) ekskludert: %2.</translation>
         <source>Fee:</source>
         <translation>Avgift:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Prioritet:</translation>
-    </message>
     <message>
         <source>Low Output:</source>
         <translation>Lav Utdata:</translation>
@@ -529,10 +519,6 @@ Prosjekt(er) ekskludert: %2.</translation>
         <source>Address</source>
         <translation>Adresse</translation>
     </message>
-    <message>
-        <source>Priority</source>
-        <translation>Prioritet</translation>
-    </message>
     <message>
         <source>Copy address</source>
         <translation>Kopier adresse</translation>
@@ -561,38 +547,10 @@ Prosjekt(er) ekskludert: %2.</translation>
         <source>Copy after fee</source>
         <translation>Kopier etter gebyr</translation>
     </message>
-    <message>
-        <source>Copy priority</source>
-        <translation>Kopier prioritet</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation>Kopier veksel</translation>
     </message>
-    <message>
-        <source>highest</source>
-        <translation>høyest</translation>
-    </message>
-    <message>
-        <source>high</source>
-        <translation>høy</translation>
-    </message>
-    <message>
-        <source>medium-high</source>
-        <translation>medium-høy</translation>
-    </message>
-    <message>
-        <source>low-medium</source>
-        <translation>lav-medium</translation>
-    </message>
-    <message>
-        <source>low</source>
-        <translation>lav</translation>
-    </message>
-    <message>
-        <source>lowest</source>
-        <translation>lavest</translation>
-    </message>
     <message>
         <source>yes</source>
         <translation>ja</translation>
@@ -680,6 +638,30 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <translation>Bruk:</translation>
     </message>
     </context>
+<context>
+    <name>Intro</name>
+    <message numerus="yes">
+        <source>%n GB of free space available</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>(of %n GB needed)</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>(%n GB needed for full chain)</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+</context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -698,22 +680,10 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>Map port using &amp;UPnP</source>
         <translation>Sett opp port ved hjelp av &amp;UPnP</translation>
     </message>
-    <message>
-        <source>&amp;Connect through SOCKS proxy:</source>
-        <translation>&amp;Koble til via en SOCKS proxy:</translation>
-    </message>
     <message>
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Proxyens port (f.eks. 9050)</translation>
     </message>
-    <message>
-        <source>SOCKS &amp;Version:</source>
-        <translation>SOCKS &amp;Versjon:</translation>
-    </message>
-    <message>
-        <source>SOCKS version of the proxy (e.g. 5)</source>
-        <translation>Proxyens SOCKS versjon (f.eks. 5)</translation>
-    </message>
     <message>
         <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
         <translation>Minimerer vinduet istedenfor å avslutte applikasjonen når vinduet lukkes. Når dette er slått på avsluttes applikasjonen kun ved å velge avslutt i menyen.</translation>
@@ -806,27 +776,45 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
     <name>QObject</name>
     <message numerus="yes">
         <source>%n second(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n minute(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n hour(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n day(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n week(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n year(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     </context>
 <context>
@@ -847,11 +835,7 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>&amp;Save As...</source>
         <translation>&amp;Lagre som...</translation>
     </message>
-    <message>
-        <source>PNG Images (*.png)</source>
-        <translation>PNG Bilder (*.png)</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>RPCConsole</name>
     <message>
@@ -922,18 +906,6 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>Clear console</source>
         <translation>Tøm konsoll</translation>
     </message>
-    <message>
-        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
-        <translation>Skriv &lt;b&gt;help&lt;/b&gt; for en oversikt over kommandoer.</translation>
-    </message>
-    <message>
-        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
-        <translation>Bruk opp og ned pil for å navigere historikken, og &lt;b&gt;Ctrl-L&lt;/b&gt; for å tømme skjermen.</translation>
-    </message>
-    <message>
-        <source>Build date</source>
-        <translation>Byggedato</translation>
-    </message>
     <message>
         <source>Estimated total blocks</source>
         <translation>Estimert totalt antall blokker</translation>
@@ -946,7 +918,15 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>Client name</source>
         <translation>Klientnavn</translation>
     </message>
-</context>
+    <message>
+        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
+        <translation>Bruk opp og ned pil for å navigere historikken, og &lt;b&gt;Ctrl-L&lt;/b&gt; for å tømme skjermen.</translation>
+    </message>
+    <message>
+        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
+        <translation>Skriv &lt;b&gt;help&lt;/b&gt; for en oversikt over kommandoer.</translation>
+    </message>
+    </context>
 <context>
     <name>SendCoinsDialog</name>
     <message>
@@ -973,10 +953,6 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>Amount:</source>
         <translation>Beløp:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Prioritet:</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Gebyr:</translation>
@@ -1057,7 +1033,7 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>(no label)</source>
         <translation>(ingen merkelapp)</translation>
     </message>
-</context>
+    </context>
 <context>
     <name>SendCoinsEntry</name>
     <message>
@@ -1068,6 +1044,10 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>Pay &amp;To:</source>
         <translation>Betal &amp;Til:</translation>
     </message>
+    <message>
+        <source>Message:</source>
+        <translation>Melding:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;Merkelapp:</translation>
@@ -1200,7 +1180,10 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
     <name>TransactionDesc</name>
     <message numerus="yes">
         <source>Open for %n more block(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Open until %1</source>
@@ -1224,7 +1207,10 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
     </message>
     <message numerus="yes">
         <source>, broadcast through %n node(s)</source>
-        <translation><numerusform>, kringkast gjennom %n node</numerusform><numerusform>, kringkast gjennom %n noder</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Date</source>
@@ -1260,7 +1246,10 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
     </message>
     <message numerus="yes">
         <source>matures in %n more block(s)</source>
-        <translation><numerusform>blir moden om %n blokk</numerusform><numerusform>blir moden om %n blokker</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>not accepted</source>
@@ -1326,7 +1315,10 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
     </message>
     <message numerus="yes">
         <source>Open for %n more block(s)</source>
-        <translation><numerusform>Åpen for %n blokk til</numerusform><numerusform>Åpen for %n blokker til</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Open until %1</source>
@@ -1459,10 +1451,6 @@ Dette betyr at det trengs en avgift på minimum %2.</translation>
         <source>Show transaction details</source>
         <translation>Vis transaksjonsdetaljer</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Kommaseparert fil (*.csv)</translation>
-    </message>
     <message>
         <source>Confirmed</source>
         <translation>Bekreftet</translation>
@@ -1573,10 +1561,6 @@ Hvis filen ikke finnes, opprett den med leserettighet kun for eier av filen.</tr
         <source>wallet.dat corrupt, salvage failed</source>
         <translation>wallet.dat korrupt, bergning feilet</translation>
     </message>
-    <message>
-        <source>Unknown -socks proxy version requested: %i</source>
-        <translation>Ukjent -socks proxy versjon angitt: %i</translation>
-    </message>
     <message>
         <source>Invalid -proxy address: '%s'</source>
         <translation>Ugyldig -proxy adresse: '%s'</translation>
@@ -1633,10 +1617,6 @@ Hvis filen ikke finnes, opprett den med leserettighet kun for eier av filen.</tr
         <source>Loading wallet...</source>
         <translation>Laster lommebok...</translation>
     </message>
-    <message>
-        <source>Cannot downgrade wallet</source>
-        <translation>Kan ikke nedgradere lommebok</translation>
-    </message>
     <message>
         <source>Cannot write default address</source>
         <translation>Kan ikke skrive standardadresse</translation>
