@@ -1,4 +1,4 @@
-<TS language="ro_RO" version="2.1">
+<TS language="ro_RO" version="2.0">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -8,10 +8,6 @@
     </context>
 <context>
     <name>AddressBookPage</name>
-    <message>
-        <source>Double-click to edit address or label</source>
-        <translation>Dublu-click pentru a edita adresa sau eticheta</translation>
-    </message>
     <message>
         <source>Create a new address</source>
         <translation>Creează o adresă nouă</translation>
@@ -72,10 +68,6 @@
         <source>&amp;Edit</source>
         <translation>&amp;Editeaz?</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Valori separate prin virgul? (*.csv)</translation>
-    </message>
     <message>
         <source>Export Address Book Data</source>
         <translation>Export? datele din Agend?</translation>
@@ -142,14 +134,6 @@
         <source>Unlock wallet</source>
         <translation>Deblocheaz? portofelul</translation>
     </message>
-    <message>
-        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
-        <translation>Aceast? ac?iune necesit? fraza ta de acces pentru decriptarea portofelului.</translation>
-    </message>
-    <message>
-        <source>Decrypt wallet</source>
-        <translation>Decripteaz? portofelul.</translation>
-    </message>
     <message>
         <source>Change passphrase</source>
         <translation>Schimb? fraza de acces</translation>
@@ -170,14 +154,14 @@
         <source>Are you sure you wish to encrypt your wallet?</source>
         <translation>Sunte?i sigur c? dori?i s? cripta?i portofelul electronic?</translation>
     </message>
-    <message>
-        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
-        <translation>Gridcoin se va inchide pentru a termina procesul de encriptie. Aminti?i-v?, criptarea portofelul dumneavoastr? nu poate proteja pe deplin monedele dvs. de a fi furate de  infectarea cu malware a computerului.</translation>
-    </message>
     <message>
         <source>Wallet encrypted</source>
         <translation>Portofel criptat</translation>
     </message>
+    <message>
+        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
+        <translation>Gridcoin se va inchide pentru a termina procesul de encriptie. Aminti?i-v?, criptarea portofelul dumneavoastr? nu poate proteja pe deplin monedele dvs. de a fi furate de  infectarea cu malware a computerului.</translation>
+    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>IMPORTANT: Orice copie de siguranta facuta in prealabil portofelului dumneavoastra ar trebui inlocuita cu cea generata cel mai recent fisier criptat al portofelului. Pentru siguranta, copiile de siguranta vechi ale portofelului ne-criptat vor deveni inutile de indata ce veti incepe folosirea noului fisier criptat al portofelului.</translation>
@@ -202,10 +186,6 @@
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation>Fraza de acces introdus? pentru decriptarea portofelului a fost incorect?.</translation>
     </message>
-    <message>
-        <source>Wallet decryption failed</source>
-        <translation>Decriptarea portofelului a e?uat</translation>
-    </message>
     <message>
         <source>Wallet passphrase was successfully changed.</source>
         <translation>Parola portofelului electronic a fost schimbat?.</translation>
@@ -218,8 +198,12 @@
 <context>
     <name>BitcoinGUI</name>
     <message>
-        <source>Sign &amp;message...</source>
-        <translation>Semnează &amp;mesaj...</translation>
+        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
+        <translation>A ap?rut o eroare fatal?. Gridcoin nu mai poate continua în condi?ii de siguran?? ?i va iesi.</translation>
+    </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Portofel</translation>
     </message>
     <message>
         <source>&amp;Overview</source>
@@ -229,10 +213,30 @@
         <source>Show general overview of wallet</source>
         <translation>Arată o stare generală de ansamblu a portofelului</translation>
     </message>
+    <message>
+        <source>&amp;Send</source>
+        <translation>Trimite</translation>
+    </message>
+    <message>
+        <source>Send coins to a Gridcoin address</source>
+        <translation>Trimite monede c?tre o adres? Gridcoin</translation>
+    </message>
+    <message>
+        <source>&amp;Receive</source>
+        <translation>P&amp;rimeşte</translation>
+    </message>
+    <message>
+        <source>Show the list of addresses for receiving payments</source>
+        <translation>Arat? lista de adrese pentru primire pl??i</translation>
+    </message>
     <message>
         <source>Browse transaction history</source>
         <translation>Răsfoire istoric tranzacţii</translation>
     </message>
+    <message>
+        <source>Edit the list of stored addresses and labels</source>
+        <translation>Editeaz? lista de adrese si etichete stocate</translation>
+    </message>
     <message>
         <source>E&amp;xit</source>
         <translation>Ieşire</translation>
@@ -241,10 +245,26 @@
         <source>Quit application</source>
         <translation>Închide aplicaţia</translation>
     </message>
+    <message>
+        <source>&amp;About Gridcoin</source>
+        <translation>Despre Gridcoin</translation>
+    </message>
+    <message>
+        <source>Show information about Gridcoin</source>
+        <translation>Arat? informa?ii despre Gridcoin</translation>
+    </message>
     <message>
         <source>&amp;Options...</source>
         <translation>&amp;Opţiuni...</translation>
     </message>
+    <message>
+        <source>Modify configuration options for Gridcoin</source>
+        <translation>Modific? op?iuni de configurare pentru Gridcoin</translation>
+    </message>
+    <message>
+        <source>&amp;Show / Hide</source>
+        <translation>Arată/Ascunde</translation>
+    </message>
     <message>
         <source>&amp;Encrypt Wallet...</source>
         <translation>Cript&amp;ează portofelul...</translation>
@@ -257,98 +277,6 @@
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Schimbă fraza de acces folosită pentru criptarea portofelului</translation>
     </message>
-    <message>
-        <source>&amp;Debug window</source>
-        <translation>Fereastra de &amp;depanare</translation>
-    </message>
-    <message>
-        <source>Open debugging and diagnostic console</source>
-        <translation>Deschide consola de depanare şi diagnosticare</translation>
-    </message>
-    <message>
-        <source>&amp;Verify message...</source>
-        <translation>&amp;Verifică mesaj...</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Portofel</translation>
-    </message>
-    <message>
-        <source>&amp;Send</source>
-        <translation>Trimite</translation>
-    </message>
-    <message>
-        <source>&amp;Receive</source>
-        <translation>P&amp;rimeşte</translation>
-    </message>
-    <message>
-        <source>&amp;Show / Hide</source>
-        <translation>Arată/Ascunde</translation>
-    </message>
-    <message>
-        <source>&amp;File</source>
-        <translation>&amp;Fişier</translation>
-    </message>
-    <message>
-        <source>&amp;Settings</source>
-        <translation>&amp;Setări</translation>
-    </message>
-    <message>
-        <source>&amp;Help</source>
-        <translation>A&amp;jutor</translation>
-    </message>
-    <message numerus="yes">
-        <source>Processed %n block(s) of transaction history.</source>
-        <translation><numerusform>S-a procesat %n bloc din istoricul tranzacţiilor.</numerusform><numerusform>S-au procesat %n blocuri din istoricul tranzacţiilor.</numerusform><numerusform>S-au procesat %n de blocuri din istoricul tranzacţiilor.</numerusform></translation>
-    </message>
-    <message>
-        <source>Up to date</source>
-        <translation>Actualizat</translation>
-    </message>
-    <message>
-        <source>Send coins to a Gridcoin address</source>
-        <translation>Trimite monede c?tre o adres? Gridcoin</translation>
-    </message>
-    <message>
-        <source>Show the list of addresses for receiving payments</source>
-        <translation>Arat? lista de adrese pentru primire pl??i</translation>
-    </message>
-    <message>
-        <source>Edit the list of stored addresses and labels</source>
-        <translation>Editeaz? lista de adrese si etichete stocate</translation>
-    </message>
-    <message>
-        <source>&amp;About Gridcoin</source>
-        <translation>Despre Gridcoin</translation>
-    </message>
-    <message>
-        <source>Show information about Gridcoin</source>
-        <translation>Arat? informa?ii despre Gridcoin</translation>
-    </message>
-    <message numerus="yes">
-        <source>%n second(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n minute(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n hour(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n day(s) ago</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
-    </message>
-    <message>
-        <source>Modify configuration options for Gridcoin</source>
-        <translation>Modific? op?iuni de configurare pentru Gridcoin</translation>
-    </message>
-    <message>
-        <source>Encrypt or decrypt wallet</source>
-        <translation>Cripteaz? sau decripteaz? portofelul</translation>
-    </message>
     <message>
         <source>&amp;Unlock Wallet...</source>
         <translation>&amp;Deblocheaz? portofelul</translation>
@@ -365,6 +293,14 @@
         <source>Lock wallet</source>
         <translation>Blocheaz? portofelul</translation>
     </message>
+    <message>
+        <source>Sign &amp;message...</source>
+        <translation>Semnează &amp;mesaj...</translation>
+    </message>
+    <message>
+        <source>&amp;Verify message...</source>
+        <translation>&amp;Verifică mesaj...</translation>
+    </message>
     <message>
         <source>&amp;Export...</source>
         <translation>&amp;Export?</translation>
@@ -373,13 +309,81 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Export? datele din tab-ul curent într-un fi?ier</translation>
     </message>
+    <message>
+        <source>&amp;Debug window</source>
+        <translation>Fereastra de &amp;depanare</translation>
+    </message>
+    <message>
+        <source>Open debugging and diagnostic console</source>
+        <translation>Deschide consola de depanare şi diagnosticare</translation>
+    </message>
+    <message>
+        <source>&amp;File</source>
+        <translation>&amp;Fişier</translation>
+    </message>
+    <message>
+        <source>&amp;Settings</source>
+        <translation>&amp;Setări</translation>
+    </message>
+    <message>
+        <source>&amp;Help</source>
+        <translation>A&amp;jutor</translation>
+    </message>
     <message>
         <source>Gridcoin client</source>
         <translation>Clientul Gridcoin</translation>
     </message>
     <message numerus="yes">
         <source>%n active connection(s) to the Gridcoin network</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Processed %n block(s) of transaction history.</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n second(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minute(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n hour(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n day(s) ago</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message>
+        <source>Up to date</source>
+        <translation>Actualizat</translation>
     </message>
     <message>
         <source>Catching up...</source>
@@ -398,13 +402,25 @@
         <translation>Confirm? comisinoul tranzac?iei</translation>
     </message>
     <message>
-        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
-        <translation>URI nu poate fi parsatt! Cauza poate fi o adresa Gridcoin invalid? sau parametrii URI malforma?i.</translation>
+        <source>Sent transaction</source>
+        <translation>Tranzacţie expediată</translation>
+    </message>
+    <message>
+        <source>Incoming transaction</source>
+        <translation>Tranzacţie recepţionată</translation>
     </message>
     <message>
         <source>URI handling</source>
         <translation>Manipulare URI</translation>
     </message>
+    <message>
+        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
+        <translation>URI nu poate fi parsatt! Cauza poate fi o adresa Gridcoin invalid? sau parametrii URI malforma?i.</translation>
+    </message>
+    <message>
+        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
+        <translation>Portofelul este &lt;b&gt;criptat&lt;/b&gt; iar în momentul de faţă este &lt;b&gt;blocat&lt;/b&gt;</translation>
+    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>F? o copie de siguran?? a portofelului</translation>
@@ -421,23 +437,7 @@
         <source>There was an error trying to save the wallet data to the new location.</source>
         <translation>Eroare la încercarea de a salva datele portofelului în noua loca?ie.</translation>
     </message>
-    <message>
-        <source>Sent transaction</source>
-        <translation>Tranzacţie expediată</translation>
-    </message>
-    <message>
-        <source>Incoming transaction</source>
-        <translation>Tranzacţie recepţionată</translation>
-    </message>
-    <message>
-        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
-        <translation>Portofelul este &lt;b&gt;criptat&lt;/b&gt; iar în momentul de faţă este &lt;b&gt;blocat&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
-        <translation>A ap?rut o eroare fatal?. Gridcoin nu mai poate continua în condi?ii de siguran?? ?i va iesi.</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>ClientModel</name>
     <message>
@@ -467,10 +467,6 @@
         <source>Coin Control</source>
         <translation>Controleaz? moneda</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Prioritate:</translation>
-    </message>
     <message>
         <source>Low Output:</source>
         <translation>Ie?ire minim?: </translation>
@@ -507,10 +503,6 @@
         <source>Address</source>
         <translation>Adres?</translation>
     </message>
-    <message>
-        <source>Priority</source>
-        <translation>Prioritate</translation>
-    </message>
     <message>
         <source>Copy address</source>
         <translation>Copiaz? adresa</translation>
@@ -543,10 +535,6 @@
         <source>Copy bytes</source>
         <translation>Copia?i octe?i</translation>
     </message>
-    <message>
-        <source>Copy priority</source>
-        <translation>Copia?i prioritatea</translation>
-    </message>
     <message>
         <source>Copy low output</source>
         <translation>Copia?i ie?ire minim?:</translation>
@@ -555,34 +543,6 @@
         <source>Copy change</source>
         <translation>Copia?i schimb</translation>
     </message>
-    <message>
-        <source>highest</source>
-        <translation>cel mai mare</translation>
-    </message>
-    <message>
-        <source>high</source>
-        <translation>mare</translation>
-    </message>
-    <message>
-        <source>medium-high</source>
-        <translation>marime medie</translation>
-    </message>
-    <message>
-        <source>medium</source>
-        <translation>mediu</translation>
-    </message>
-    <message>
-        <source>low-medium</source>
-        <translation>mediu-scazut</translation>
-    </message>
-    <message>
-        <source>low</source>
-        <translation>scazut</translation>
-    </message>
-    <message>
-        <source>lowest</source>
-        <translation>cel mai scazut</translation>
-    </message>
     <message>
         <source>yes</source>
         <translation>da</translation>
@@ -602,18 +562,6 @@
 Acest lucru inseamna ca este nevoie de o taxa de cel putin %1 pe kb
 
 Poate varia +/- 1 Byte pe imput.</translation>
-    </message>
-    <message>
-        <source>Transactions with higher priority get more likely into a block.
-
-This label turns red, if the priority is smaller than "medium".
-
- This means a fee of at least %1 per kb is required.</source>
-        <translation>Tranzac?iile cu prioritate mai mare ajunge mult mai probabil într-un bloc
-
-Aceasta eticheta se inroseste daca prioritatea este mai mica decat "medium"
-
-Acest lucru inseamna ca este necesar un comision cel putin de %1 pe kB</translation>
     </message>
     <message>
         <source>This label turns red, if any recipient receives an amount smaller than %1.
@@ -718,6 +666,33 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <translation>Optiuni linie de comanda</translation>
     </message>
     </context>
+<context>
+    <name>Intro</name>
+    <message numerus="yes">
+        <source>%n GB of free space available</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>(of %n GB needed)</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>(%n GB needed for full chain)</source>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
+    </message>
+</context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -748,14 +723,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
         <translation>Deschide automat portul pentru cientul Gridcoin pe router. Aces lucru este posibil doara daca routerul suporta UPnP si este activat</translation>
     </message>
-    <message>
-        <source>Connect to the Gridcoin network through a SOCKS proxy (e.g. when connecting through Tor).</source>
-        <translation>Conecteaza la reteaua Gridcoin prinr-un proxy SOCKS(ex. cand te conectezi prin Tor)</translation>
-    </message>
-    <message>
-        <source>&amp;Connect through SOCKS proxy:</source>
-        <translation>Conecteaz?-te printr-un proxy socks</translation>
-    </message>
     <message>
         <source>IP address of the proxy (e.g. 127.0.0.1)</source>
         <translation>Adresa IP a proxy-ului(ex. 127.0.0.1)</translation>
@@ -764,14 +731,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Port of the proxy (e.g. 9050)</source>
         <translation>Portul proxy (de exemplu: 9050)</translation>
     </message>
-    <message>
-        <source>SOCKS &amp;Version:</source>
-        <translation>SOCKS &amp;Versiune:</translation>
-    </message>
-    <message>
-        <source>SOCKS version of the proxy (e.g. 5)</source>
-        <translation>Versiunea SOCKS a proxiului (ex. 5)</translation>
-    </message>
     <message>
         <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
         <translation>Ascunde fereastra în locul p?r?sirii programului în momentul închiderii ferestrei. Când acest? op?iune e activ?, aplica?ia se va opri doar în momentul select?rii comenzii Quit din menu.</translation>
@@ -876,27 +835,51 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
     <name>QObject</name>
     <message numerus="yes">
         <source>%n second(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n minute(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n hour(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n day(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n week(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n year(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     </context>
 <context>
@@ -941,11 +924,7 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Save QR Code</source>
         <translation>Salveaz? codul QR</translation>
     </message>
-    <message>
-        <source>PNG Images (*.png)</source>
-        <translation>Imagini PNG(*png)</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>RPCConsole</name>
     <message>
@@ -1016,18 +995,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Clear console</source>
         <translation>Curăţă consola</translation>
     </message>
-    <message>
-        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
-        <translation>Scrieţi &lt;b&gt;help&lt;/b&gt; pentru a vedea comenzile disponibile.</translation>
-    </message>
-    <message>
-        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
-        <translation>Folosiţi săgetile sus şi jos pentru a naviga în istoric şi &lt;b&gt;Ctrl-L&lt;/b&gt; pentru a curăţa.</translation>
-    </message>
-    <message>
-        <source>Build date</source>
-        <translation>Construit la data</translation>
-    </message>
     <message>
         <source>On testnet</source>
         <translation>Pe testnet</translation>
@@ -1052,7 +1019,15 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Client name</source>
         <translation>Nume client</translation>
     </message>
-</context>
+    <message>
+        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
+        <translation>Folosiţi săgetile sus şi jos pentru a naviga în istoric şi &lt;b&gt;Ctrl-L&lt;/b&gt; pentru a curăţa.</translation>
+    </message>
+    <message>
+        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
+        <translation>Scrieţi &lt;b&gt;help&lt;/b&gt; pentru a vedea comenzile disponibile.</translation>
+    </message>
+    </context>
 <context>
     <name>SendCoinsDialog</name>
     <message>
@@ -1083,14 +1058,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Amount:</source>
         <translation>Sumă:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Prioritate:</translation>
-    </message>
-    <message>
-        <source>medium</source>
-        <translation>mediu</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Taxă:</translation>
@@ -1167,10 +1134,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Copy change</source>
         <translation>Copia?i schimb</translation>
     </message>
-    <message>
-        <source>Copy priority</source>
-        <translation>Copia?i prioritatea</translation>
-    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Confirm? trimiterea de monede</translation>
@@ -1211,6 +1174,10 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
         <translation>Eroare: tranzac?ia a fost respins?. Acest lucru s-ar putea întâmpla în cazul în care unele dintre monedele din portofel au fost deja cheltuite, cum si cum a?i utilizat o copie a wallet.dat ?i monedele au fost cheltuite în copie dar nu au fost marcate ca ?i cheltuite aici.</translation>
     </message>
+    <message>
+        <source>(no label)</source>
+        <translation>(f?r? etichet?)</translation>
+    </message>
     <message>
         <source>WARNING: Invalid Gridcoin address</source>
         <translation>Aten?ie: Adres? Gridcoin invalid?</translation>
@@ -1219,11 +1186,7 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>WARNING: unknown change address</source>
         <translation>ATENTIE: adresa schimb necunoscuta</translation>
     </message>
-    <message>
-        <source>(no label)</source>
-        <translation>(f?r? etichet?)</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>SendCoinsEntry</name>
     <message>
@@ -1234,6 +1197,10 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Pay &amp;To:</source>
         <translation>Plăteşte că&amp;tre:</translation>
     </message>
+    <message>
+        <source>Message:</source>
+        <translation>Mesaj:</translation>
+    </message>
     <message>
         <source>&amp;Label:</source>
         <translation>&amp;Etichetă:</translation>
@@ -1382,12 +1349,20 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
     <name>TransactionDesc</name>
     <message numerus="yes">
         <source>Open for %n more block(s)</source>
-        <translation type="unfinished"><numerusform /><numerusform /><numerusform /></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Open until %1</source>
         <translation>Deschis pân? la %1</translation>
     </message>
+    <message>
+        <source>conflicted</source>
+        <translation>conflictual</translation>
+    </message>
     <message>
         <source>%1/offline</source>
         <translation>%1/deconectat</translation>
@@ -1396,10 +1371,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>%1/unconfirmed</source>
         <translation>%1/neconfirmat</translation>
     </message>
-    <message>
-        <source>conflicted</source>
-        <translation>conflictual</translation>
-    </message>
     <message>
         <source>%1 confirmations</source>
         <translation>%1 confirm?ri</translation>
@@ -1414,7 +1385,11 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
     </message>
     <message numerus="yes">
         <source>, broadcast through %n node(s)</source>
-        <translation><numerusform>, distribuit prin %n nod</numerusform><numerusform>, distribuit prin %n noduri</numerusform><numerusform>, distribuit prin %n de noduri</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Date</source>
@@ -1446,7 +1421,11 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
     </message>
     <message numerus="yes">
         <source>matures in %n more block(s)</source>
-        <translation><numerusform>se maturizeaz? în înc? %n bloc</numerusform><numerusform>se maturizeaz? în înc? %n blocuri</numerusform><numerusform>se maturizeaz? în înc? %n de blocuri</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>not accepted</source>
@@ -1512,7 +1491,11 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
     </message>
     <message numerus="yes">
         <source>Open for %n more block(s)</source>
-        <translation><numerusform>Deschis pentru înc? %n bloc</numerusform><numerusform>Deschis pentru înc? %n blocuri</numerusform><numerusform>Deschis pentru înc? %n de blocuri</numerusform></translation>
+        <translation type="unfinished">
+            <numerusform />
+            <numerusform />
+            <numerusform />
+        </translation>
     </message>
     <message>
         <source>Open until %1</source>
@@ -1653,10 +1636,6 @@ Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
         <source>Export Transaction Data</source>
         <translation>Exporta datele trazactiei</translation>
     </message>
-    <message>
-        <source>Comma separated file (*.csv)</source>
-        <translation>Fi?ier text cu valori separate prin virgul? (*.csv)</translation>
-    </message>
     <message>
         <source>Confirmed</source>
         <translation>Confirmat</translation>
@@ -1791,10 +1770,6 @@ Dac? fi?ierul nu exist?, creeaz?-l cu permisiuni de citire doar de c?tre proprie
         <source>wallet.dat corrupt, salvage failed</source>
         <translation>wallet.dat corupt, recuperare e?uat?</translation>
     </message>
-    <message>
-        <source>Unknown -socks proxy version requested: %i</source>
-        <translation>S-a cerut o versiune necunoscut? de proxy -socks: %i</translation>
-    </message>
     <message>
         <source>Invalid -proxy address: '%s'</source>
         <translation>Adresa -proxy nevalidă: '%s'</translation>
@@ -1835,10 +1810,6 @@ Dac? fi?ierul nu exist?, creeaz?-l cu permisiuni de citire doar de c?tre proprie
         <source>Error loading wallet.dat</source>
         <translation>Eroare la înc?rcarea wallet.dat</translation>
     </message>
-    <message>
-        <source>Importing blockchain data file.</source>
-        <translation>Se importa fisierul blockchain</translation>
-    </message>
     <message>
         <source>Importing bootstrap blockchain data file.</source>
         <translation>Se importa fisierul bootstrap blockchain</translation>
@@ -1903,10 +1874,6 @@ Dac? fi?ierul nu exist?, creeaz?-l cu permisiuni de citire doar de c?tre proprie
         <source>Loading wallet...</source>
         <translation>Încărcare portofel...</translation>
     </message>
-    <message>
-        <source>Cannot downgrade wallet</source>
-        <translation>Nu se poate retrograda portofelul</translation>
-    </message>
     <message>
         <source>Cannot write default address</source>
         <translation>Nu se poate scrie adresa implicită</translation>
