@@ -2,7 +2,7 @@
 // Distributed under the MIT/X11 software license, see the accompanying
 // file COPYING or https://opensource.org/licenses/mit-license.php.
 
-#include "base58.h"
+#include <key_io.h>
 #include "main.h"
 #include "gridcoin/beacon.h"
 #include "gridcoin/boinc.h"
@@ -10,6 +10,8 @@
 #include "gridcoin/project.h"
 #include "gridcoin/quorum.h"
 #include "gridcoin/researcher.h"
+#include "gridcoin/scraper/scraper.h"
+#include "gridcoin/superblock.h"
 #include "node/ui_interface.h"
 
 #include "qt/bitcoinunits.h"
@@ -22,6 +24,7 @@
 #include <QTimer>
 
 extern CWallet* pwalletMain;
+extern ConvergedScraperStats ConvergedScraperStatsCache;
 
 using namespace GRC;
 using LogFlags = BCLog::LogFlags;
@@ -44,6 +47,16 @@ void ResearcherChanged(ResearcherModel* model)
         Q_ARG(GRC::ResearcherPtr, Researcher::Get()));
 }
 
+//!
+//! \brief Model callback bound to the \c AccrualChangedFromStakeOrMRC core signal.
+//!
+void AccrualChangedFromStakeOrMRC(ResearcherModel* model)
+{
+    LogPrint(LogFlags::QT, "GUI: received ResearcherChanged() core signal");
+
+    QMetaObject::invokeMethod(model, "accrualChanged", Qt::QueuedConnection);
+}
+
 //!
 //! \brief Model callback bound to the \c BeaconChanged core signal.
 //!
@@ -72,7 +85,8 @@ BeaconStatus MapAdvertiseBeaconError(const BeaconError error)
         case BeaconError::PENDING:            return BeaconStatus::PENDING;
         case BeaconError::TX_FAILED:          return BeaconStatus::ERROR_TX_FAILED;
         case BeaconError::WALLET_LOCKED:      return BeaconStatus::ERROR_WALLET_LOCKED;
-    }
+        case BeaconError::ALEADY_IN_MEMPOOL:  return BeaconStatus::ALREADY_IN_MEMPOOL;
+        }
 
     assert(false); // Suppress warning
 }
@@ -87,6 +101,8 @@ ResearcherModel::ResearcherModel()
     , m_configured_for_investor_mode(false)
     , m_wizard_open(false)
     , m_out_of_sync(true)
+    , m_split_cpid(false)
+    , m_privacy_enabled(false)
     , m_theme_suffix("_dark")
 {
     qRegisterMetaType<ResearcherPtr>("GRC::ResearcherPtr");
@@ -135,6 +151,8 @@ QString ResearcherModel::mapBeaconStatus(const BeaconStatus status)
             return tr("Beacon expires soon. Renew immediately.");
         case BeaconStatus::RENEWAL_POSSIBLE:
             return tr("Beacon eligible for renewal.");
+        case BeaconStatus::ALREADY_IN_MEMPOOL:
+            return tr("Beacon advertisement transaction already in mempool.");
         case BeaconStatus::UNKNOWN:
             return tr("Waiting for sync...");
     }
@@ -166,6 +184,7 @@ QIcon ResearcherModel::mapBeaconStatusIcon(const BeaconStatus status) const
         case BeaconStatus::PENDING:                  return make_icon(warning);
         case BeaconStatus::RENEWAL_NEEDED:           return make_icon(danger);
         case BeaconStatus::RENEWAL_POSSIBLE:         return make_icon(warning);
+        case BeaconStatus::ALREADY_IN_MEMPOOL:       return make_icon(warning);
         case BeaconStatus::UNKNOWN:                  return make_icon(inactive);
     }
 
@@ -263,7 +282,17 @@ bool ResearcherModel::hasActiveBeacon() const
 
 bool ResearcherModel::hasPendingBeacon() const
 {
-    return m_pending_beacon.operator bool();
+    if (!m_pending_beacon.operator bool()) {
+        return false;
+    }
+
+    // If here, a pending beacon is present. Determine if expired
+    // while pending. No need to actually clean the pending entry
+    // up. It will be eventually cleaned by the contract handler via
+    // the ActivatePending call.
+    GRC::PendingBeacon pending_beacon(*m_pending_beacon);
+
+    return !pending_beacon.PendingExpired(GetAdjustedTime());
 }
 
 bool ResearcherModel::hasRenewableBeacon() const
@@ -271,6 +300,11 @@ bool ResearcherModel::hasRenewableBeacon() const
     return m_beacon && m_beacon->Renewable(GetAdjustedTime());
 }
 
+bool ResearcherModel::beaconExpired() const
+{
+    return m_beacon && m_beacon->Expired(GetAdjustedTime());
+}
+
 bool ResearcherModel::hasMagnitude() const
 {
     return m_researcher->Magnitude() != 0;
@@ -299,6 +333,16 @@ bool ResearcherModel::needsBeaconAuth() const
     return m_beacon->m_public_key != m_pending_beacon->m_public_key;
 }
 
+std::optional<CAmount> ResearcherModel::accrualNearLimit() const
+{
+    return m_researcher->AccrualNearLimit();
+}
+
+CAmount ResearcherModel::getAccrual() const
+{
+    return m_researcher->Accrual();
+}
+
 QString ResearcherModel::email() const
 {
     return QString::fromStdString(Researcher::Email());
@@ -330,16 +374,28 @@ QString ResearcherModel::formatMagnitude() const
     return text;
 }
 
-QString ResearcherModel::formatAccrual(const int display_unit) const
+QString ResearcherModel::formatAccrual(const int display_unit, bool& near_limit) const
 {
     QString text;
 
+    // We only do the actual accrual calculation once. The AccrualNearLimit() is lighter.
+    CAmount accrual = m_researcher->Accrual();
+    std::optional<CAmount> near_limit_accrual = accrualNearLimit();
+
+    if (near_limit_accrual && accrual >= *near_limit_accrual) {
+        near_limit = true;
+    } else {
+        near_limit = false;
+    }
+
     if (outOfSync()) {
         text = "...";
     } else {
-        text = BitcoinUnits::formatWithPrivacy(display_unit, m_researcher->Accrual(), m_privacy_enabled);
+        text = BitcoinUnits::formatWithPrivacy(display_unit, accrual, m_privacy_enabled);
     }
 
+
+
     return text;
 }
 
@@ -391,13 +447,22 @@ QString ResearcherModel::formatTimeToBeaconExpiration() const
     return GUIUtil::formatDurationStr(Beacon::MAX_AGE - m_beacon->Age(GetAdjustedTime()));
 }
 
+QString ResearcherModel::formatTimeToPendingBeaconExpiration() const
+{
+    if (!m_pending_beacon) {
+        return QString();
+    }
+
+    return GUIUtil::formatDurationStr(PendingBeacon::RETENTION_AGE - m_pending_beacon->Age(GetAdjustedTime()));
+}
+
 QString ResearcherModel::formatBeaconAddress() const
 {
     if (!m_beacon) {
         return QString();
     }
 
-    return QString::fromStdString(m_beacon->GetAddress().ToString());
+    return QString::fromStdString(EncodeDestination(m_beacon->GetAddress()));
 }
 
 QString ResearcherModel::formatBeaconVerificationCode() const
@@ -422,6 +487,20 @@ std::vector<ProjectRow> ResearcherModel::buildProjectTable(bool extended) const
     //
 
     const WhitelistSnapshot whitelist = GetWhitelist().Snapshot();
+    std::vector<std::string> excluded_projects;
+
+    {
+        LOCK(cs_ConvergedScraperStatsCache);
+
+        excluded_projects = ConvergedScraperStatsCache.Convergence.vExcludedProjects;
+    }
+
+    // This is temporary implementation of the suppression of "not attached" for projects that
+    // are whitelisted that require an external adapter, and so will not be attached as a native
+    // BOINC project. This will be replaced by a field in the Projects class at the next mandatory
+    // (5.5.0.0).
+    std::vector<std::string> external_adapter_projects = GetProjectsExternalAdapterRequired();
+
     std::vector<ExplainMagnitudeProject> explain_mag;
     std::map<std::string, ProjectRow> rows;
 
@@ -449,8 +528,15 @@ std::vector<ProjectRow> ResearcherModel::buildProjectTable(bool extended) const
         // that also compares the project URL to establish the relationship
         // between local projects and whitelisted projects:
         //
-        if (const Project* whitelist_project = project.TryWhitelist(whitelist)) {
-            row.m_whitelisted = true;
+        if (const ProjectEntry* whitelist_project = project.TryWhitelist(whitelist)) {
+            if (std::find(excluded_projects.begin(), excluded_projects.end(), whitelist_project->m_name)
+                != excluded_projects.end()) {
+                row.m_whitelisted = ProjectRow::WhiteListStatus::Greylisted;
+                row.m_error = tr("Greylisted");
+            } else {
+                row.m_whitelisted = ProjectRow::WhiteListStatus::True;
+            }
+
             row.m_name = QString::fromStdString(whitelist_project->DisplayName()).toLower();
 
             for (const auto& explain_mag_project : explain_mag) {
@@ -461,9 +547,11 @@ std::vector<ProjectRow> ResearcherModel::buildProjectTable(bool extended) const
                 }
             }
 
+            row.m_gdpr_controls = whitelist_project->HasGDPRControls();
+
             rows.emplace(whitelist_project->m_name, std::move(row));
         } else {
-            row.m_whitelisted = false;
+            row.m_whitelisted = ProjectRow::WhiteListStatus::False;
             row.m_name = QString::fromStdString(project.m_name).toLower();
             row.m_rac = project.m_rac;
 
@@ -483,10 +571,26 @@ std::vector<ProjectRow> ResearcherModel::buildProjectTable(bool extended) const
         }
 
         ProjectRow row;
-        row.m_whitelisted = true;
+        row.m_gdpr_controls = project.HasGDPRControls();
+
         row.m_name = QString::fromStdString(project.DisplayName()).toLower();
         row.m_magnitude = 0.0;
-        row.m_error = tr("Not attached");
+
+        if (std::find(external_adapter_projects.begin(),
+                      external_adapter_projects.end(),
+                      project.m_name) == external_adapter_projects.end()) {
+            row.m_error = tr("Not attached");
+        } else {
+            row.m_error = tr("Uses external adapter");
+        }
+
+        if (std::find(excluded_projects.begin(), excluded_projects.end(), project.m_name)
+            != excluded_projects.end()) {
+            row.m_whitelisted = ProjectRow::WhiteListStatus::Greylisted;
+            row.m_error = tr("Greylisted");
+        } else {
+            row.m_whitelisted = ProjectRow::WhiteListStatus::True;
+        }
 
         for (const auto& explain_mag_project : explain_mag) {
             if (explain_mag_project.m_name == project.m_name) {
@@ -640,6 +744,7 @@ void ResearcherModel::subscribeToCoreSignals()
 {
     // Connect signals to client
     uiInterface.ResearcherChanged_connect(std::bind(ResearcherChanged, this));
+    uiInterface.AccrualChangedFromStakeOrMRC_connect(std::bind(AccrualChangedFromStakeOrMRC, this));
     uiInterface.BeaconChanged_connect(std::bind(BeaconChanged, this));
 }
 
