@@ -57,7 +57,6 @@ SendCoinsDialog::SendCoinsDialog(QWidget* parent)
     QAction *clipboardFeeAction = new QAction(tr("Copy fee"), this);
     QAction *clipboardAfterFeeAction = new QAction(tr("Copy after fee"), this);
     QAction *clipboardBytesAction = new QAction(tr("Copy bytes"), this);
-    QAction *clipboardPriorityAction = new QAction(tr("Copy priority"), this);
     QAction *clipboardLowOutputAction = new QAction(tr("Copy low output"), this);
     QAction *clipboardChangeAction = new QAction(tr("Copy change"), this);
     connect(clipboardQuantityAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardQuantity);
@@ -65,7 +64,6 @@ SendCoinsDialog::SendCoinsDialog(QWidget* parent)
     connect(clipboardFeeAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardFee);
     connect(clipboardAfterFeeAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardAfterFee);
     connect(clipboardBytesAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardBytes);
-    connect(clipboardPriorityAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardPriority);
     connect(clipboardLowOutputAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardLowOutput);
     connect(clipboardChangeAction, &QAction::triggered, this, &SendCoinsDialog::coinControlClipboardChange);
     ui->coinControlQuantityLabel->addAction(clipboardQuantityAction);
@@ -73,7 +71,6 @@ SendCoinsDialog::SendCoinsDialog(QWidget* parent)
     ui->coinControlFeeLabel->addAction(clipboardFeeAction);
     ui->coinControlAfterFeeLabel->addAction(clipboardAfterFeeAction);
     ui->coinControlBytesLabel->addAction(clipboardBytesAction);
-    ui->coinControlPriorityLabel->addAction(clipboardPriorityAction);
     ui->coinControlLowOutputLabel->addAction(clipboardLowOutputAction);
     ui->coinControlChangeLabel->addAction(clipboardChangeAction);
 
@@ -352,8 +349,8 @@ bool SendCoinsDialog::handleURI(const QString &uri)
     // URI has to be valid
     if (GUIUtil::parseBitcoinURI(uri, &rv))
     {
-        CBitcoinAddress address(rv.address.toStdString());
-        if (!address.IsValid())
+        CTxDestination address = DecodeDestination(rv.address.toStdString());
+        if (!IsValidDestination(address))
             return false;
         pasteEntry(rv);
         return true;
@@ -425,12 +422,6 @@ void SendCoinsDialog::coinControlClipboardBytes()
     QApplication::clipboard()->setText(ui->coinControlBytesLabel->text());
 }
 
-// Coin Control: copy label "Priority" to clipboard
-void SendCoinsDialog::coinControlClipboardPriority()
-{
-    QApplication::clipboard()->setText(ui->coinControlPriorityLabel->text());
-}
-
 // Coin Control: copy label "Low output" to clipboard
 void SendCoinsDialog::coinControlClipboardLowOutput()
 {
@@ -518,7 +509,7 @@ void SendCoinsDialog::coinControlChangeChecked(int state)
     if (model)
     {
         if (state == Qt::Checked)
-            coinControl->destChange = CBitcoinAddress(ui->coinControlChangeEdit->text().toStdString()).Get();
+            coinControl->destChange = DecodeDestination(ui->coinControlChangeEdit->text().toStdString());
         else
             coinControl->destChange = CNoDestination();
     }
@@ -534,13 +525,13 @@ void SendCoinsDialog::coinControlChangeEdited(const QString & text)
 {
     if (model)
     {
-        coinControl->destChange = CBitcoinAddress(text.toStdString()).Get();
+        coinControl->destChange = DecodeDestination(text.toStdString());
 
         // label for the change address
         ui->coinControlChangeAddressLabel->setStyleSheet(QString());
         if (text.isEmpty())
             ui->coinControlChangeAddressLabel->setText(QString());
-        else if (!CBitcoinAddress(text.toStdString()).IsValid())
+        else if (!IsValidDestination(DecodeDestination(text.toStdString())))
         {
             ui->coinControlChangeAddressLabel->setStyleSheet("QLabel{color:red;}");
             ui->coinControlChangeAddressLabel->setText(tr("WARNING: Invalid Gridcoin address"));
@@ -553,9 +544,9 @@ void SendCoinsDialog::coinControlChangeEdited(const QString & text)
             else
             {
                 CPubKey pubkey;
-                CKeyID keyid;
-                CBitcoinAddress(text.toStdString()).GetKeyID(keyid);
-                if (model->getPubKey(keyid, pubkey))
+                CTxDestination dest = DecodeDestination(text.toStdString());
+                CKeyID* keyid = std::get_if<CKeyID>(&dest);
+                if (keyid && model->getPubKey(*keyid, pubkey))
                     ui->coinControlChangeAddressLabel->setText(tr("(no label)"));
                 else
                 {
