@@ -1,6 +1,7 @@
 #include "transactionrecord.h"
 #include "wallet/wallet.h"
-#include "base58.h"
+#include <key_io.h>
+#include <QObject>
 
 /* Return positive answer if transaction should be shown in list. */
 bool TransactionRecord::showTransaction(const CWalletTx &wtx, bool datetime_limit_flag, const int64_t &datetime_limit)
@@ -87,7 +88,7 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
 
                 if (ExtractDestination(txout.scriptPubKey, address))
                 {
-                    sub.address = CBitcoinAddress(address).ToString();
+                    sub.address = EncodeDestination(address);
                 }
 
                 // Generated (proof-of-work)
@@ -120,7 +121,7 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
             // The coinstake HAS to be from an address.
             if(ExtractDestination(wtx.vout[1].scriptPubKey, address))
             {
-                sub.address = CBitcoinAddress(address).ToString();
+                sub.address = EncodeDestination(address);
             }
 
             // Here we add up all of the outputs, whether they are ours (the stake return with
@@ -146,6 +147,17 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
         // sidestake.
         for (unsigned int t = 2; t < wtx_size; t++)
         {
+            // If not a stake split and a self sidestake, then we need to net the self-sidestake
+            // from the gross stake entry above. The first condition below guarantees that
+            // parts[0] will be "my" gross stake and exists because it matches the condition
+            // above, the second guarantees that the output t is a sidestake back to me. The
+            // actual self-sidestake entry itself is handled below.
+            if (wtx.vout[t].scriptPubKey != wtx.vout[1].scriptPubKey
+                    && wallet->IsMine(wtx.vout[1]) != ISMINE_NO
+                    && wallet->IsMine(wtx.vout[t]) != ISMINE_NO) {
+                parts[0].debit += -wtx.vout[t].nValue;
+            }
+
             // If this is not a stake split AND either vout[1] is mine OR
             // vout[t] is mine
             if (wtx.vout[t].scriptPubKey != wtx.vout[1].scriptPubKey &&
@@ -161,7 +173,7 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
 
                 if (ExtractDestination(wtx.vout[t].scriptPubKey, address))
                 {
-                    sub.address = CBitcoinAddress(address).ToString();
+                    sub.address = EncodeDestination(address);
                 }
 
                 int64_t nValue = wtx.vout[t].nValue;
@@ -193,7 +205,7 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
                 {
                     // Received by Bitcoin Address
                     sub.type = TransactionRecord::RecvWithAddress;
-                    sub.address = CBitcoinAddress(address).ToString();
+                    sub.address = EncodeDestination(address);
                 }
                 else
                 {
@@ -269,7 +281,7 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
                 {
                     // Sent to Bitcoin Address
                     sub.type = TransactionRecord::SendToAddress;
-                    sub.address = CBitcoinAddress(address).ToString();
+                    sub.address = EncodeDestination(address);
                 }
                 else
                 {
@@ -314,6 +326,9 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
                     case GRC::ContractType::VOTE:
                         sub.type = TransactionRecord::Vote;
                         break;
+                    case GRC::ContractType::MRC:
+                        sub.type = TransactionRecord::MRC;
+                        break;
                     case GRC::ContractType::MESSAGE:
                         // Only display the message type for the first not is mine output
                         if (!fMessageDisplayed && wallet->IsMine(txout) == ISMINE_NO)
@@ -347,6 +362,54 @@ QList<TransactionRecord> TransactionRecord::decomposeTransaction(const CWallet *
     return parts;
 }
 
+QString TransactionRecord::TypeToString() const
+{
+    return TypeToString(type);
+}
+
+QString TransactionRecord::TypeToString(const Type& type, const bool& translated)
+{
+    if (translated) {
+        switch(type) {
+        case Other:                 return QObject::tr("Other");
+        case Generated:             return QObject::tr("Mined");
+        case SendToAddress:         return QObject::tr("Sent to Address");
+        case SendToOther:           return QObject::tr("Sent to Other");
+        case RecvWithAddress:       return QObject::tr("Received with Address");
+        case RecvFromOther:         return QObject::tr("Received from Other");
+        case SendToSelf:            return QObject::tr("Self");
+        case BeaconAdvertisement:   return QObject::tr("Beacon Advertisements");
+        case Poll:                  return QObject::tr("Polls");
+        case Vote:                  return QObject::tr("Votes");
+        case Message:               return QObject::tr("Messages");
+        case MRC:                   return QObject::tr("MRCs");
+        }
+
+        assert(false); // Suppress warning
+    } else {
+        switch(type) {
+        case Other:                 return "Other";
+        case Generated:             return "Mined";
+        case SendToAddress:         return "Sent to Address";
+        case SendToOther:           return "Sent to Other";
+        case RecvWithAddress:       return "Received with Address";
+        case RecvFromOther:         return "Received from Other";
+        case SendToSelf:            return "Self";
+        case BeaconAdvertisement:   return "Beacon Advertisements";
+        case Poll:                  return "Polls";
+        case Vote:                  return "Votes";
+        case Message:               return "Messages";
+        case MRC:                   return "MRCs";
+        }
+
+        assert(false); // Suppress warning
+    }
+
+    // This will never be reached. Put it in anyway to prevent control reaches end of non-void function warning
+    // from some compiler versions.
+    return QString{};
+}
+
 void TransactionRecord::updateStatus(const CWalletTx &wtx) EXCLUSIVE_LOCKS_REQUIRED(cs_main)
 {
     AssertLockHeld(cs_main);
