@@ -14,23 +14,12 @@ public:
     QString m_name;
     QString m_description;
     int m_min_duration_days;
+    std::vector<QString> m_required_fields;
 };
 
 class PollTypes : public std::vector<PollTypeItem>
 {
 public:
-    enum PollType
-    {
-        PollTypeUnknown,
-        PollTypeProject,
-        PollTypeDevelopment,
-        PollTypeGovernance,
-        PollTypeMarketing,
-        PollTypeOutreach,
-        PollTypeCommunity,
-        PollTypeSurvey,
-    };
-
     PollTypes();
 };
 
