@@ -19,14 +19,13 @@
 
 #include <boost/algorithm/string.hpp>
 #include <algorithm>
+#include <stdexcept>
 
 #include <univalue.h>
 
 using namespace GRC;
 using namespace std;
 
-extern GRC::BlockFinder RPCBlockFinder;
-
 // Brod
 static bool compare_second(const pair<std::string, int64_t>  &p1, const pair<std::string, int64_t> &p2)
 {
@@ -149,7 +148,7 @@ UniValue rpc_getblockstats(const UniValue& params, bool fHelp)
             throw runtime_error("getblockstats: failed to read block");
         }
 
-        assert(block.vtx.size() > 0);
+        if (!block.vtx.size()) throw runtime_error("getblockstats: block has zero transactions");
 
         unsigned txcountinblock = 0;
 
@@ -604,9 +603,12 @@ UniValue rpc_getrecentblocks(const UniValue& params, bool fHelp)
         if( (detail<100 && detail>=20) || (detail>=120) )
         {
             CBlock block;
-            if(!ReadBlockFromDisk(block, cur->nFile, cur->nBlockPos, Params().GetConsensus()))
+            if (!ReadBlockFromDisk(block, cur->nFile, cur->nBlockPos, Params().GetConsensus())) {
                 throw runtime_error("failed to read block");
-            //assert(block.vtx.size() > 0);
+            }
+
+            if (!block.vtx.size()) throw runtime_error("getblockstats: block has zero transactions");
+
             const Claim& claim = block.GetClaim();
 
             if(detail<100)
