@@ -2,6 +2,8 @@
 // Distributed under the MIT/X11 software license, see the accompanying
 // file COPYING or https://opensource.org/licenses/mit-license.php.
 
+#include <stdexcept>
+
 #include "server.h"
 #include "protocol.h"
 #include "alert.h"
@@ -11,9 +13,13 @@
 #include "wallet/walletdb.h"
 #include "net.h"
 #include "banman.h"
+#include "logging.h"
 
 using namespace std;
 
+extern std::map<uint256, CAlert> mapAlerts;
+extern CCriticalSection cs_mapAlerts;
+
 UniValue getconnectioncount(const UniValue& params, bool fHelp)
 {
     if (fHelp || params.size() != 0)
@@ -46,7 +52,7 @@ UniValue addnode(const UniValue& params, bool fHelp)
         CAddress addr;
         CNode* pnode= ConnectNode(addr, strNode.c_str());
         if(!pnode)
-            throw JSONRPCError(-23, "Error: Node connection failed");
+            throw JSONRPCError(RPC_CLIENT_NODE_ALREADY_ADDED, "Error: Node connection failed");
         UniValue result(UniValue::VOBJ);
         result.pushKV("result", "ok");
         return result;
@@ -61,13 +67,13 @@ UniValue addnode(const UniValue& params, bool fHelp)
     if (strCommand == "add")
     {
         if (it != vAddedNodes.end())
-            throw JSONRPCError(-23, "Error: Node already added");
+            throw JSONRPCError(RPC_CLIENT_NODE_ALREADY_ADDED, "Error: Node already added");
         vAddedNodes.push_back(strNode);
     }
     else if(strCommand == "remove")
     {
         if (it == vAddedNodes.end())
-            throw JSONRPCError(-24, "Error: Node has not been added.");
+            throw JSONRPCError(RPC_CLIENT_NODE_NOT_ADDED, "Error: Node has not been added.");
         vAddedNodes.erase(it);
     }
 
@@ -76,6 +82,38 @@ UniValue addnode(const UniValue& params, bool fHelp)
     return result;
 }
 
+UniValue getnodeaddresses(const UniValue& params, bool fHelp)
+{
+    if (fHelp || params.size() > 1)
+        throw runtime_error(
+                "getnodeaddresses [count]\n"
+                "\nReturn known addresses which can potentially be used to find new nodes in the network\n"
+                "count: How many addresses to return. Limited to the smaller of " + std::to_string(ADDRMAN_GETADDR_MAX) +
+                " or " + std::to_string(ADDRMAN_GETADDR_MAX_PCT) + "% of all known addresses. (default = 1)\n");
+    int count = 1;
+    if(!params[0].isNull())
+        count = params[0].get_int();
+
+    if (count <= 0)
+        throw JSONRPCError(RPC_INVALID_PARAMETER, "Address count out of range");
+
+    // returns a shuffled list of CAddress
+    std::vector<CAddress> vAddr = addrman.GetAddr();
+    UniValue ret(UniValue::VARR);
+
+    int address_return_count = std::min<int>(count, vAddr.size());
+    for (int i = 0; i < address_return_count; ++i) {
+        UniValue obj(UniValue::VOBJ);
+        const CAddress& addr = vAddr[i];
+        obj.pushKV("time", (int)addr.nTime);
+        obj.pushKV("services", (uint64_t)addr.nServices);
+        obj.pushKV("address", addr.ToStringIP());
+        obj.pushKV("port", addr.GetPort());
+        ret.push_back(obj);
+    }
+    return ret;
+}
+
 UniValue getaddednodeinfo(const UniValue& params, bool fHelp)
 {
     if (fHelp || params.size() < 1 || params.size() > 2)
@@ -107,7 +145,7 @@ UniValue getaddednodeinfo(const UniValue& params, bool fHelp)
                 break;
             }
         if (laddedNodes.size() == 0)
-            throw JSONRPCError(-24, "Error: Node has not been added.");
+            throw JSONRPCError(RPC_CLIENT_NODE_NOT_ADDED, "Error: Node has not been added.");
     }
 
     if (!fDns)
@@ -203,8 +241,9 @@ UniValue setban(const UniValue& params, bool fHelp)
 
     if (!isSubnet) {
         std::vector<CNetAddr> resolved;
-        LookupHost(params[0].get_str().c_str(), resolved, 1, false);
-        netAddr = resolved[0];
+        if (LookupHost(params[0].get_str().c_str(), resolved, 1, false)) {
+            netAddr = resolved[0];
+        }
     }
     else
         LookupSubNet(params[0].get_str().c_str(), subNet);
@@ -384,6 +423,61 @@ UniValue getnettotals(const UniValue& params, bool fHelp)
     return obj;
 }
 
+UniValue listalerts(const UniValue& params, bool fHelp)
+{
+    if (fHelp || params.size() > 0)
+        throw runtime_error(
+                "listalerts\n"
+                "\n"
+                "Returns information about alerts.\n");
+
+    LOCK(cs_mapAlerts);
+
+    UniValue result(UniValue::VOBJ);
+    UniValue alerts(UniValue::VARR);
+
+
+    for (const auto& iter_alert : mapAlerts) {
+        UniValue alert(UniValue::VOBJ);
+
+        alert.pushKV("version", iter_alert.second.nVersion);
+        alert.pushKV("relay_until", DateTimeStrFormat(iter_alert.second.nRelayUntil));
+        alert.pushKV("expiration", DateTimeStrFormat(iter_alert.second.nExpiration));
+        alert.pushKV("id", iter_alert.second.nID);
+        alert.pushKV("cancel_upto", iter_alert.second.nCancel);
+
+        UniValue set_cancel(UniValue::VARR);
+        for (const auto& cancel : iter_alert.second.setCancel) {
+            set_cancel.push_back(cancel);
+        }
+        alert.pushKV("cancels", set_cancel);
+
+        alert.pushKV("minimum_version", iter_alert.second.nMinVer);
+        alert.pushKV("maximum_version", iter_alert.second.nMaxVer);
+
+        UniValue set_subver(UniValue::VARR);
+        for (const auto& subver : iter_alert.second.setSubVer) {
+            set_subver.push_back(subver);
+        }
+        alert.pushKV("subversions", set_subver);
+
+        alert.pushKV("priority", iter_alert.second.nPriority);
+
+        alert.pushKV("comment", iter_alert.second.strComment);
+        alert.pushKV("status_bar", iter_alert.second.strStatusBar);
+        alert.pushKV("reserved", iter_alert.second.strReserved);
+
+        alert.pushKV("hash", iter_alert.second.GetHash().GetHex());
+        alert.pushKV("in_effect", iter_alert.second.IsInEffect());
+        alert.pushKV("applies_to_me", iter_alert.second.AppliesToMe());
+
+        alerts.push_back(alert);
+    }
+
+    result.pushKV("alerts", alerts);
+
+    return result;
+}
 
 
 // ppcoin: send alert.
@@ -397,7 +491,7 @@ UniValue sendalert(const UniValue& params, bool fHelp)
             "sendalert <message> <privatekey> <minver> <maxver> <priority> <id> [cancelupto]\n"
             "\n"
             "<message> ----> is the alert text message\n"
-            "<privatekey> -> is hex string of alert master private key\n"
+            "<privatekey> -> is WIF encoded alert master private key\n"
             "<minver> -----> is the minimum applicable internal client version\n"
             "<maxver> -----> is the maximum applicable internal client version\n"
             "<priority> ---> is integer priority number\n"
@@ -422,11 +516,15 @@ UniValue sendalert(const UniValue& params, bool fHelp)
 
     CDataStream sMsg(SER_NETWORK, PROTOCOL_VERSION);
     sMsg << (CUnsignedAlert)alert;
-    alert.vchMsg = vector<unsigned char>(sMsg.begin(), sMsg.end());
+    alert.vchMsg = vector<unsigned char>((unsigned char*)&sMsg.begin()[0], (unsigned char*)&sMsg.end()[0]);
 
-    vector<unsigned char> vchPrivKey = ParseHex(params[1].get_str());
-    key.SetPrivKey(CPrivKey(vchPrivKey.begin(), vchPrivKey.end())); // if key is not correct openssl may crash
-    if (!key.Sign(Hash(alert.vchMsg.begin(), alert.vchMsg.end()), alert.vchSig))
+    key = DecodeSecret(params[0].get_str());
+
+    if (!key.IsValid()) {
+        throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid private key");
+    }
+
+    if (!key.Sign(Hash(alert.vchMsg), alert.vchSig))
         throw runtime_error(
             "Unable to sign alert, check private key?\n");
     if(!alert.ProcessAlert())
@@ -458,7 +556,7 @@ UniValue sendalert2(const UniValue& params, bool fHelp)
             //          0            1    2            3            4        5          6
             "sendalert2 <privatekey> <id> <subverlist> <cancellist> <expire> <priority> <message>\n"
             "\n"
-            "<privatekey> -> is hex string of alert master private key\n"
+            "<privatekey> -> is WIF encoded alert master private key\n"
             "<id> ---------> is the unique alert number\n"
             "<subverlist> -> comma separated list of versions warning applies to\n"
             "<cancellist> -> comma separated ids of alerts to cancel\n"
@@ -496,11 +594,15 @@ UniValue sendalert2(const UniValue& params, bool fHelp)
 
     CDataStream sMsg(SER_NETWORK, PROTOCOL_VERSION);
     sMsg << (CUnsignedAlert)alert;
-    alert.vchMsg = vector<unsigned char>(sMsg.begin(), sMsg.end());
+    alert.vchMsg = vector<unsigned char>((unsigned char*)&sMsg.begin()[0], (unsigned char*)&sMsg.end()[0]);
 
-    vector<unsigned char> vchPrivKey = ParseHex(params[0].get_str());
-    key.SetPrivKey(CPrivKey(vchPrivKey.begin(), vchPrivKey.end())); // if key is not correct openssl may crash
-    if (!key.Sign(Hash(alert.vchMsg.begin(), alert.vchMsg.end()), alert.vchSig))
+    key = DecodeSecret(params[0].get_str());
+
+    if (!key.IsValid()) {
+        throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid private key");
+    }
+
+    if (!key.Sign(Hash(alert.vchMsg), alert.vchSig))
         throw runtime_error(
             "Unable to sign alert, check private key?\n");
     if(!alert.ProcessAlert())
