@@ -9,12 +9,15 @@
 #include "gridcoin/beacon.h"
 #include "gridcoin/claim.h"
 #include "gridcoin/contract/contract.h"
+#include "gridcoin/mrc.h"
 #include "gridcoin/project.h"
+#include "gridcoin/sidestake.h"
 #include "gridcoin/staking/difficulty.h"
 #include "gridcoin/superblock.h"
 #include "gridcoin/support/block_finder.h"
 #include "gridcoin/tx_message.h"
 #include "gridcoin/voting/payloads.h"
+#include <key_io.h>
 #include "node/blockstorage.h"
 #include "policy/policy.h"
 #include "policy/fees.h"
@@ -30,13 +33,19 @@
 #include <script.h>
 
 #include <queue>
+#include <stdexcept>
 
 using namespace GRC;
 using namespace std;
 
+UniValue MRCToJson(const GRC::MRC& mrc);
+
 std::vector<std::pair<std::string, std::string>> GetTxStakeBoincHashInfo(const CMerkleTx& mtx)
 {
-    assert(mtx.IsCoinStake() || mtx.IsCoinBase());
+    if (!(mtx.IsCoinStake() || mtx.IsCoinBase())) {
+        throw runtime_error("GetTxStakeBoincHashInfo: transaction is not a coinstake or coinbase");
+    }
+
     std::vector<std::pair<std::string, std::string>> res;
 
     // Fetch BlockIndex for tx block
@@ -99,7 +108,7 @@ void ScriptPubKeyToJSON(const CScript& scriptPubKey, UniValue& out, bool fInclud
     out.pushKV("asm", scriptPubKey.ToString());
 
     if (fIncludeHex)
-        out.pushKV("hex", HexStr(scriptPubKey.begin(), scriptPubKey.end()));
+        out.pushKV("hex", HexStr(scriptPubKey));
 
     if (!ExtractDestinations(scriptPubKey, type, addresses, nRequired))
     {
@@ -112,7 +121,7 @@ void ScriptPubKeyToJSON(const CScript& scriptPubKey, UniValue& out, bool fInclud
 
     UniValue a(UniValue::VARR);
     for (auto const& addr : addresses)
-        a.push_back(CBitcoinAddress(addr).ToString());
+        a.push_back(EncodeDestination(addr));
     out.pushKV("addresses", a);
 }
 
@@ -135,7 +144,7 @@ UniValue BeaconToJson(const GRC::ContractPayload& payload)
 
     out.pushKV("version", (int)beacon.m_version);
     out.pushKV("cpid", beacon.m_cpid.ToString());
-    out.pushKV("public_key", beacon.m_beacon.m_public_key.ToString());
+    out.pushKV("public_key", HexStr(beacon.m_beacon.m_public_key));
 
     return out;
 }
@@ -238,6 +247,20 @@ UniValue VotePayloadToJson(const GRC::ContractPayload& payload)
     return out;
 }
 
+UniValue SideStakePayloadToJson (const GRC::ContractPayload& payload)
+{
+    const auto& sidestake = payload.As<GRC::SideStakePayload>();
+
+    UniValue out(UniValue::VOBJ);
+
+    out.pushKV("address", EncodeDestination(sidestake.m_entry.m_destination));
+    out.pushKV("allocation", sidestake.m_entry.m_allocation.ToPercent());
+    out.pushKV("description", sidestake.m_entry.m_description);
+    out.pushKV("status", sidestake.m_entry.StatusToString());
+
+    return out;
+}
+
 UniValue LegacyVotePayloadToJson(const GRC::ContractPayload& payload)
 {
     const auto& vote = payload.As<GRC::LegacyVote>();
@@ -285,6 +308,12 @@ UniValue ContractToJson(const GRC::Contract& contract)
                 out.pushKV("body", LegacyVotePayloadToJson(contract.SharePayload()));
             }
             break;
+        case GRC::ContractType::MRC:
+            out.pushKV("body", MRCToJson(contract.CopyPayloadAs<GRC::MRC>()));
+            break;
+        case GRC::ContractType::SIDESTAKE:
+            out.pushKV("body", SideStakePayloadToJson(contract.SharePayload()));
+            break;
         default:
             out.pushKV("body", LegacyContractPayloadToJson(contract.SharePayload()));
             break;
@@ -316,7 +345,7 @@ void TxToJSON(const CTransaction& tx, const uint256 hashBlock, UniValue& entry)
         UniValue in(UniValue::VOBJ);
 
         if (tx.IsCoinBase())
-            in.pushKV("coinbase", HexStr(txin.scriptSig.begin(), txin.scriptSig.end()));
+            in.pushKV("coinbase", HexStr(txin.scriptSig));
 
         else
         {
@@ -325,7 +354,7 @@ void TxToJSON(const CTransaction& tx, const uint256 hashBlock, UniValue& entry)
             in.pushKV("vout", (int)txin.prevout.n);
             UniValue o(UniValue::VOBJ);
             o.pushKV("asm", txin.scriptSig.ToString());
-            o.pushKV("hex", HexStr(txin.scriptSig.begin(), txin.scriptSig.end()));
+            o.pushKV("hex", HexStr(txin.scriptSig));
             in.pushKV("scriptSig", o);
         }
         in.pushKV("sequence", (int)txin.nSequence);
@@ -394,7 +423,7 @@ UniValue getrawtransaction(const UniValue& params, bool fHelp)
 
     CDataStream ssTx(SER_NETWORK, PROTOCOL_VERSION);
     ssTx << tx;
-    string strHex = HexStr(ssTx.begin(), ssTx.end());
+    string strHex = HexStr(ssTx);
 
     if (!fVerbose)
         return strHex;
@@ -427,14 +456,14 @@ UniValue listunspent(const UniValue& params, bool fHelp)
     if (params.size() > 1)
         nMaxDepth = params[1].get_int();
 
-    set<CBitcoinAddress> setAddress;
+    set<CTxDestination> setAddress;
     if (params.size() > 2)
     {
         UniValue inputs = params[2].get_array();
         for (unsigned int ix = 0; ix < inputs.size(); ix++)
         {
-            CBitcoinAddress address(inputs[ix].get_str());
-            if (!address.IsValid())
+            CTxDestination address = DecodeDestination(inputs[ix].get_str());
+            if (!IsValidDestination(address))
                 throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, string("Invalid Gridcoin address: ")+inputs[ix].get_str());
             if (setAddress.count(address))
                 throw JSONRPCError(RPC_INVALID_PARAMETER, string("Invalid parameter, duplicated address: ")+inputs[ix].get_str());
@@ -473,7 +502,7 @@ UniValue listunspent(const UniValue& params, bool fHelp)
         CTxDestination address;
         if (ExtractDestination(out.tx->vout[out.i].scriptPubKey, address))
         {
-            entry.pushKV("address", CBitcoinAddress(address).ToString());
+            entry.pushKV("address", EncodeDestination(address));
 
             auto item = pwalletMain->mapAddressBook.find(address);
 
@@ -485,7 +514,7 @@ UniValue listunspent(const UniValue& params, bool fHelp)
                     entry.pushKV("account", item->second);
             }
         }
-        entry.pushKV("scriptPubKey", HexStr(pk.begin(), pk.end()));
+        entry.pushKV("scriptPubKey", HexStr(pk));
         entry.pushKV("amount", ValueFromAmount(nValue));
         entry.pushKV("confirmations", out.nDepth);
         results.push_back(entry);
@@ -538,7 +567,7 @@ UniValue consolidateunspent(const UniValue& params, bool fHelp)
     UniValue result(UniValue::VOBJ);
 
     std::string sAddress = params[0].get_str();
-    CBitcoinAddress OptimizeAddress(sAddress);
+    CTxDestination OptimizeAddress = DecodeDestination(sAddress);
 
     int64_t nConsolidateLimit = 0;
     unsigned int nInputNumberLimit = GetMaxInputsForConsolidationTxn();
@@ -560,14 +589,14 @@ UniValue consolidateunspent(const UniValue& params, bool fHelp)
     // due to the size.
     nInputNumberLimit = std::min<unsigned int>(nInputNumberLimit, GetMaxInputsForConsolidationTxn());
 
-    if (!OptimizeAddress.IsValid())
+    if (!IsValidDestination(OptimizeAddress))
     {
         throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, string("Invalid Gridcoin address: ") + sAddress);
     }
 
     // Set the consolidation transaction address to the specified output address.
     CScript scriptDestPubKey;
-    scriptDestPubKey.SetDestination(OptimizeAddress.Get());
+    scriptDestPubKey.SetDestination(OptimizeAddress);
 
     std::vector<COutput> vecInputs;
 
@@ -594,7 +623,7 @@ UniValue consolidateunspent(const UniValue& params, bool fHelp)
 
         // If the UTXO matches the consolidation address or all sweep_all_addresses is true then add to the inputs
         // map for consolidation. Note that the value of sweep_change is ignored and all change will be swept.
-        if (CBitcoinAddress(out_address) == OptimizeAddress || sweep_all_addresses)
+        if (out_address == OptimizeAddress || sweep_all_addresses)
         {
             mInputs.insert(std::make_pair(nOutValue, out));
         }
@@ -655,7 +684,7 @@ UniValue consolidateunspent(const UniValue& params, bool fHelp)
                     // to the inputs map for consolidation.
                     if (ExtractDestination(prev_ctxout.scriptPubKey, change_input_address))
                     {
-                        if (CBitcoinAddress(change_input_address) == OptimizeAddress)
+                        if (change_input_address == OptimizeAddress)
                         {
                             // Insert the ORIGINAL change UTXO into the input map for the consolidation.
                             mInputs.insert(std::make_pair(nOutValue, out));
@@ -789,7 +818,7 @@ UniValue consolidateunspent(const UniValue& params, bool fHelp)
     CCoinControl coinControl;
 
     // Send the change back to the same address.
-    coinControl.destChange = OptimizeAddress.Get();
+    coinControl.destChange = OptimizeAddress;
 
     if (!pwalletMain->CreateTransaction(vecSend, setCoins, wtxNew, reservekey, nFeeRequired, &coinControl))
     {
@@ -970,10 +999,10 @@ UniValue consolidatemsunspent(const UniValue& params, bool fHelp)
     if (nMaxValue < 0)
         throw JSONRPCError(RPC_INVALID_PARAMETER, "Value must not be less than 0");
 
-    CBitcoinAddress Address(sAddress);
+    CTxDestination Address = DecodeDestination(sAddress);
 
     // Check if the address is valid
-    if (!Address.IsValid())
+    if (!IsValidDestination(Address))
         throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Gridcoin Address");
 
     {
@@ -991,7 +1020,7 @@ UniValue consolidatemsunspent(const UniValue& params, bool fHelp)
         txnouttype WhichType;
         vector<valtype> vSolutions;
 
-        CSDest.SetDestination(Address.Get());
+        CSDest.SetDestination(Address);
 
         // Solve the solutions for Destination script
         if (!Solver(CSDest, WhichType, vSolutions))
@@ -1069,9 +1098,7 @@ UniValue consolidatemsunspent(const UniValue& params, bool fHelp)
         if (nMaxInputs == 0 || nMaxInputs > nEqMaxInputs)
             nMaxInputs = nEqMaxInputs;
 
-        GRC::BlockFinder blockfinder;
-
-        CBlockIndex* pblkindex = blockfinder.FindByHeight((nBlockStart - 1));
+        CBlockIndex* pblkindex = GRC::BlockFinder::FindByHeight((nBlockStart - 1));
 
         if (!pblkindex)
             throw JSONRPCError(RPC_PARSE_ERROR, "Block not found");
@@ -1122,7 +1149,7 @@ UniValue consolidatemsunspent(const UniValue& params, bool fHelp)
                         continue;
 
                     // If we found a match to multisig address do our work
-                    if (CBitcoinAddress(txaddress) == Address)
+                    if (txaddress == Address)
                     {
                         // Check if this output is already spent
                         COutPoint dummy = COutPoint(tx.GetHash(), j);
@@ -1180,7 +1207,7 @@ UniValue consolidatemsunspent(const UniValue& params, bool fHelp)
     // Make the output
     CScript scriptPubKey;
 
-    scriptPubKey.SetDestination(Address.Get());
+    scriptPubKey.SetDestination(Address);
 
     CTxOut out(nOutput, scriptPubKey);
 
@@ -1190,7 +1217,7 @@ UniValue consolidatemsunspent(const UniValue& params, bool fHelp)
 
     ss << rawtx;
 
-    sHash = HexStr(ss.begin(), ss.end());
+    sHash = HexStr(ss);
     std::string sMultisigtype = ToString(vOpCodes[0]);
     sMultisigtype.append("_of_");
     sMultisigtype.append(ToString(vOpCodes[1]));
@@ -1263,19 +1290,18 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
     if (nBlockEnd < 1 || nBlockEnd > nBestHeight || nBlockEnd <= nBlockStart)
         throw JSONRPCError(RPC_INVALID_PARAMETER, "Invalid block-end");
 
-    CBitcoinAddress Address(sAddress);
+    CTxDestination Address = DecodeDestination(sAddress);
 
-    if (!Address.IsValid())
+    if (!IsValidDestination(Address))
         throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid Gridcoin Address");
 
-    std::unordered_multimap<int64_t, std::pair<uint256, unsigned int>> uMultisig;
+    // Store as: TXID, VOUT, nValue, nHeight
+    std::vector<std::pair<std::pair<uint256, unsigned int>, std::pair<int64_t, int>>> Multisig;
 
     {
         LOCK(cs_main);
 
-        GRC::BlockFinder blockfinder;
-
-        CBlockIndex* pblkindex = blockfinder.FindByHeight((nBlockStart - 1));
+        CBlockIndex* pblkindex = GRC::BlockFinder::FindByHeight((nBlockStart - 1));
 
         if (!pblkindex)
             throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Block not found");
@@ -1314,7 +1340,7 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
                         continue;
 
                     // If we found a match to multisig address do our work
-                    if (CBitcoinAddress(txaddress) == Address)
+                    if (txaddress == Address)
                     {
                         // Check if this output is already spent
                         COutPoint dummy = COutPoint(tx.GetHash(), j);
@@ -1323,8 +1349,8 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
                         if (!txindex.vSpent[dummy.n].IsNull())
                             continue;
 
-                        // Add to multimap
-                        uMultisig.insert(std::make_pair(txout.nValue, std::make_pair(tx.GetHash(), j)));
+                        // Add to vector
+                        Multisig.push_back(std::make_pair(std::make_pair(tx.GetHash(), j), std::make_pair(txout.nValue, pblkindex->nHeight)));
                     }
                 }
             }
@@ -1338,7 +1364,7 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
     res.pushKV("Block Start", nBlockStart);
     res.pushKV("Block End", nBlockEnd);
     // Check the end results
-    if (uMultisig.empty())
+    if (Multisig.empty())
         res.pushKV("Result", "No utxos found in specified range");
 
     else
@@ -1352,7 +1378,7 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
                 exportoutput << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<id>\n";
 
             else if (nType == 1)
-                exportoutput << "TXID / VOUT / Value\n";
+                exportoutput << "TXID / VOUT / Value / HEIGHT\n";
 
         }
 
@@ -1360,17 +1386,18 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
         int64_t nValue = 0;
 
         // Process the map
-        for (const auto& data : uMultisig)
+        for (const auto& data : Multisig)
         {
             nCount++;
 
-            nValue += data.first;
+            nValue += data.second.first;
 
             UniValue txdata(UniValue::VOBJ);
 
-            txdata.pushKV("txid", data.second.first.ToString());
-            txdata.pushKV("vout", (int)data.second.second);
-            txdata.pushKV("value", ValueFromAmount(data.first));
+            txdata.pushKV("txid", data.first.first.ToString());
+            txdata.pushKV("vout", (int)data.first.second);
+            txdata.pushKV("value", ValueFromAmount(data.second.first));
+            txdata.pushKV("height", data.second.second);
 
             txres.push_back(txdata);
             // Parse into type file here
@@ -1380,14 +1407,15 @@ UniValue scanforunspent(const UniValue& params, bool fHelp)
                 if (nType == 0)
                 {
                     exportoutput << spacing << "<tx id=\"" << nCount << "\">\n";
-                    exportoutput << spacing << spacing << "<txid>" << data.second.first.ToString() << "</txid>\n";
-                    exportoutput << spacing << spacing << "<vout>" << data.second.second << "</vout>\n";
-                    exportoutput << spacing << spacing << "<value>" << std::fixed << setprecision(8) << data.first / (double)COIN << "</value>\n";
+                    exportoutput << spacing << spacing << "<txid>" << data.first.first.ToString() << "</txid>\n";
+                    exportoutput << spacing << spacing << "<vout>" << data.first.second << "</vout>\n";
+                    exportoutput << spacing << spacing << "<value>" << std::fixed << setprecision(8) << data.second.first / (double)COIN << "</value>\n";
+                    exportoutput << spacing << spacing << "<height>" << data.second.second << "</height>\n";
                     exportoutput << spacing << "</tx>\n";
                 }
 
                 else if (nType == 1)
-                    exportoutput << data.second.first.ToString() << " / " << data.second.second << " / " << std::fixed << setprecision(8) << data.first / (double)COIN << "\n";
+                    exportoutput << data.first.first.ToString() << " / " << data.first.second << " / " << std::fixed << setprecision(8) << data.second.first / (double)COIN << " / " << data.second.second << "\n";
             }
         }
 
@@ -1501,14 +1529,14 @@ UniValue createrawtransaction(const UniValue& params, bool fHelp)
         const UniValue& input = inputs[idx];
         const UniValue& o = input.get_obj();
 
-        const UniValue& txid_v = find_value(o, "txid");
+        UniValue txid_v = find_value(o, "txid");
         if (!txid_v.isStr())
             throw JSONRPCError(RPC_INVALID_PARAMETER, "Invalid parameter, missing txid key");
         string txid = txid_v.get_str();
         if (!IsHex(txid))
             throw JSONRPCError(RPC_INVALID_PARAMETER, "Invalid parameter, expected hex txid");
 
-        const UniValue& vout_v = find_value(o, "vout");
+        UniValue vout_v = find_value(o, "vout");
         if (!vout_v.isNum())
             throw JSONRPCError(RPC_INVALID_PARAMETER, "Invalid parameter, missing vout key");
         int nOutput = vout_v.get_int();
@@ -1519,11 +1547,11 @@ UniValue createrawtransaction(const UniValue& params, bool fHelp)
         rawTx.vin.push_back(in);
     }
 
-    set<CBitcoinAddress> setAddress;
+    set<CTxDestination> setAddress;
     vector<string> addrList = sendTo.getKeys();
     for (auto const& name_: addrList)
     {
-        CBitcoinAddress address(name_);
+        CTxDestination address = DecodeDestination(name_);
         if (name_ == "data")
         {
             std::vector<unsigned char> data = ParseHexV(sendTo[name_],"Data");
@@ -1532,8 +1560,8 @@ UniValue createrawtransaction(const UniValue& params, bool fHelp)
         }
         else
         {
-            CBitcoinAddress address(name_);
-            if (!address.IsValid())
+            CTxDestination address = DecodeDestination(name_);
+            if (!IsValidDestination(address))
                 throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, string("Invalid Gridcoin address: ")+name_);
 
             if (setAddress.count(address))
@@ -1541,7 +1569,7 @@ UniValue createrawtransaction(const UniValue& params, bool fHelp)
             setAddress.insert(address);
 
             CScript scriptPubKey;
-            scriptPubKey.SetDestination(address.Get());
+            scriptPubKey.SetDestination(address);
             int64_t nAmount = AmountFromValue(sendTo[name_]);
 
             CTxOut out(nAmount, scriptPubKey);
@@ -1551,7 +1579,7 @@ UniValue createrawtransaction(const UniValue& params, bool fHelp)
 
     CDataStream ss(SER_NETWORK, PROTOCOL_VERSION);
     ss << rawTx;
-    return HexStr(ss.begin(), ss.end());
+    return HexStr(ss);
 }
 
 UniValue decoderawtransaction(const UniValue& params, bool fHelp)
@@ -1603,7 +1631,7 @@ UniValue decodescript(const UniValue& params, bool fHelp)
     }
     ScriptPubKeyToJSON(script, r, false);
 
-    r.pushKV("p2sh", CBitcoinAddress(script.GetID()).ToString());
+    r.pushKV("p2sh", EncodeDestination(script.GetID()));
     return r;
 }
 
@@ -1735,14 +1763,10 @@ UniValue signrawtransaction(const UniValue& params, bool fHelp)
         for (unsigned int idx = 0; idx < keys.size(); idx++)
         {
             UniValue k = keys[idx];
-            CBitcoinSecret vchSecret;
-            bool fGood = vchSecret.SetString(k.get_str());
-            if (!fGood)
-                throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY,"Invalid private key");
-            CKey key;
-            bool fCompressed;
-            CSecret secret = vchSecret.GetSecret(fCompressed);
-            key.SetSecret(secret, fCompressed);
+            CKey key = DecodeSecret(k.get_str());
+            if (!key.IsValid()) {
+                throw JSONRPCError(RPC_INVALID_ADDRESS_OR_KEY, "Invalid private key");
+            }
             tempKeystore.AddKey(key);
         }
     }
@@ -1800,7 +1824,7 @@ UniValue signrawtransaction(const UniValue& params, bool fHelp)
     UniValue result(UniValue::VOBJ);
     CDataStream ssTx(SER_NETWORK, PROTOCOL_VERSION);
     ssTx << mergedTx;
-    result.pushKV("hex", HexStr(ssTx.begin(), ssTx.end()));
+    result.pushKV("hex", HexStr(ssTx));
     result.pushKV("complete", fComplete);
 
     return result;
