@@ -4,10 +4,11 @@
 // file COPYING or https://opensource.org/licenses/mit-license.php.
 
 #include "amount.h"
+#include <base58.h>
 #include "init.h"
 #include "sync.h"
+#include <key_io.h>
 #include "node/ui_interface.h"
-#include "base58.h"
 #include "server.h"
 #include "client.h"
 #include "protocol.h"
@@ -25,6 +26,7 @@
 #include <boost/shared_ptr.hpp>
 #include <list>
 #include <algorithm>
+#include <stdexcept>
 
 #include <memory>
 
@@ -287,7 +289,6 @@ static const CRPCCommand vRPCCommands[] =
   // Wallet commands
     { "addmultisigaddress",      &addmultisigaddress,      cat_wallet        },
     { "addredeemscript",         &addredeemscript,         cat_wallet        },
-    { "backupprivatekeys",       &backupprivatekeys,       cat_wallet        },
     { "backupwallet",            &backupwallet,            cat_wallet        },
     { "burn",                    &burn,                    cat_wallet        },
     { "checkwallet",             &checkwallet,             cat_wallet        },
@@ -337,23 +338,28 @@ static const CRPCCommand vRPCCommands[] =
     { "sendrawtransaction",      &sendrawtransaction,      cat_wallet        },
     { "sendtoaddress",           &sendtoaddress,           cat_wallet        },
     { "setaccount",              &setaccount,              cat_wallet        },
+    { "sethdseed",               &sethdseed,               cat_wallet        },
     { "settxfee",                &settxfee,                cat_wallet        },
     { "signmessage",             &signmessage,             cat_wallet        },
     { "signrawtransaction",      &signrawtransaction,      cat_wallet        },
+    { "upgradewallet",           &upgradewallet,           cat_wallet        },
     { "validateaddress",         &validateaddress,         cat_wallet        },
     { "validatepubkey",          &validatepubkey,          cat_wallet        },
     { "verifymessage",           &verifymessage,           cat_wallet        },
     { "walletlock",              &walletlock,              cat_wallet        },
     { "walletpassphrase",        &walletpassphrase,        cat_wallet        },
     { "walletpassphrasechange",  &walletpassphrasechange,  cat_wallet        },
+    { "walletdiagnose",          &walletdiagnose,          cat_wallet        },
 
   // Staking commands
     { "advertisebeacon",         &advertisebeacon,         cat_staking        },
     { "beaconconvergence",       &beaconconvergence,       cat_staking        },
     { "beaconreport",            &beaconreport,            cat_staking        },
     { "beaconstatus",            &beaconstatus,            cat_staking        },
+    { "createmrcrequest",        &createmrcrequest,        cat_staking        },
     { "explainmagnitude",        &explainmagnitude,        cat_staking        },
     { "getlaststake",            &getlaststake,            cat_staking        },
+    { "getmrcinfo",              &getmrcinfo,              cat_staking        },
     { "getstakinginfo",          &getstakinginfo,          cat_staking        },
     { "getmininginfo",           &getstakinginfo,          cat_staking        }, //alias for getstakinginfo (compatibility)
     { "lifetime",                &lifetime,                cat_staking        },
@@ -368,18 +374,21 @@ static const CRPCCommand vRPCCommands[] =
     { "auditsnapshotaccrual",    &auditsnapshotaccrual,    cat_developer     },
     { "auditsnapshotaccruals",   &auditsnapshotaccruals,   cat_developer     },
     { "addkey",                  &addkey,                  cat_developer     },
+    { "beaconaudit",             &beaconaudit,             cat_developer     },
     { "changesettings",          &changesettings,          cat_developer     },
     { "currentcontractaverage",  &currentcontractaverage,  cat_developer     },
     { "debug",                   &debug,                   cat_developer     },
     { "dumpcontracts",           &dumpcontracts,           cat_developer     },
     { "exportstats1",            &rpc_exportstats,         cat_developer     },
     { "getblockstats",           &rpc_getblockstats,       cat_developer     },
-    { "getlistof",               &getlistof,               cat_developer     },
     { "getrecentblocks",         &rpc_getrecentblocks,     cat_developer     },
     { "inspectaccrualsnapshot",  &inspectaccrualsnapshot,  cat_developer     },
-    { "listdata",                &listdata,                cat_developer     },
+    { "listalerts",              &listalerts,              cat_developer     },
     { "listprojects",            &listprojects,            cat_developer     },
+    { "listprotocolentries",     &listprotocolentries,     cat_developer     },
     { "listresearcheraccounts",  &listresearcheraccounts,  cat_developer     },
+    { "listscrapers",            &listscrapers,            cat_developer     },
+    { "listmandatorysidestakes", &listmandatorysidestakes, cat_developer     },
     { "listsettings",            &listsettings,            cat_developer     },
     { "logging",                 &logging,                 cat_developer     },
     { "network",                 &network,                 cat_developer     },
@@ -413,6 +422,7 @@ static const CRPCCommand vRPCCommands[] =
     { "clearbanned",             &clearbanned,             cat_network       },
     { "currenttime",             &currenttime,             cat_network       },
     { "getaddednodeinfo",        &getaddednodeinfo,        cat_network       },
+    { "getnodeaddresses",        &getnodeaddresses,        cat_network       },
     { "getbestblockhash",        &getbestblockhash,        cat_network       },
     { "getblock",                &getblock,                cat_network       },
     { "getblockbynumber",        &getblockbynumber,        cat_network       },
@@ -490,15 +500,19 @@ bool ClientAllowed(const boost::asio::ip::address& address)
 {
     // Make sure that IPv4-compatible and IPv4-mapped IPv6 addresses are treated as IPv4 addresses
     if (address.is_v6()
-     && (address.to_v6().is_v4_compatible()
-      || address.to_v6().is_v4_mapped()))
-        return ClientAllowed(address.to_v6().to_v4());
+     && (address.to_v6() <= boost::asio::ip::make_address_v6("::ffff:ffff")
+      || address.to_v6().is_v4_mapped())) {
+        auto address6 = address.to_v6();
+        auto bytes = address6.to_bytes();
+
+        return ClientAllowed(boost::asio::ip::address_v4({bytes[12], bytes[13], bytes[14], bytes[15]}));
+    }
 
     if (address == asio::ip::address_v4::loopback()
      || address == asio::ip::address_v6::loopback()
      || (address.is_v4()
          // Check whether IPv4 addresses match 127.0.0.0/8 (loopback subnet)
-      && (address.to_v4().to_ulong() & 0xff000000) == 0x7f000000))
+      && (address.to_v4().to_bytes()[0] == 127)))
         return true;
 
     const string strAddress = address.to_string();
@@ -585,7 +599,7 @@ void StartRPCThreads()
         (gArgs.GetArg("-rpcuser", "") == gArgs.GetArg("-rpcpassword", ""))))
     {
         unsigned char rand_pwd[32];
-        GetRandBytes(rand_pwd, sizeof(rand_pwd));
+        GetRandBytes({rand_pwd, sizeof(rand_pwd)});
         string strWhatAmI = "To use gridcoind";
         if (gArgs.IsArgSet("-server"))
             strWhatAmI = strprintf(_("To use the %s option"), "\"-server\"");
@@ -651,7 +665,7 @@ void StartRPCThreads()
         acceptor->set_option(boost::asio::ip::v6_only(loopback), v6_only_error);
 
         acceptor->bind(endpoint);
-        acceptor->listen(socket_base::max_connections);
+        acceptor->listen(socket_base::max_listen_connections);
 
         RPCListen(acceptor, *rpc_ssl_context, fUseSSL);
 
@@ -674,7 +688,7 @@ void StartRPCThreads()
             acceptor->open(endpoint.protocol());
             acceptor->set_option(boost::asio::ip::tcp::acceptor::reuse_address(true));
             acceptor->bind(endpoint);
-            acceptor->listen(socket_base::max_connections);
+            acceptor->listen(socket_base::max_listen_connections);
 
             RPCListen(acceptor, *rpc_ssl_context, fUseSSL);
 
@@ -922,7 +936,7 @@ std::vector<std::string> CRPCTable::listCommands() const
                     boost::bind(&commandMap::value_type::first,boost::placeholders::_1) );
     // remove deprecated commands from autocomplete
     for(auto &command: DEPRECATED_RPCS) {
-        std::remove(commandList.begin(), commandList.end(), command);
+        commandList.erase(std::remove(commandList.begin(), commandList.end(), command), commandList.end());
     }
     return commandList;
 }
