@@ -12,7 +12,7 @@ export LC_ALL=C
 EXIT_CODE=0
 OUTPUT=$(git ls-files --full-name -- "*.[cC][pP][pP]" "*.[hH]" "*.[pP][yY]" "*.[sS][hH]" | \
     grep -vE '^[a-z0-9_./-]+$' | \
-    grep -vE '^src/(secp256k1/|univalue/|test/fuzz/FuzzedDataProvider.h)')
+    grep -vE '^src/(secp256k1/|univalue/|bdb53/|test/fuzz/FuzzedDataProvider.h)')
 
 if [[ ${OUTPUT} != "" ]]; then
     echo "Use only lowercase alphanumerics (a-z0-9), underscores (_), hyphens (-) and dots (.)"
